/*= Rohde & Schwarz FSEx Spectrum Analyzer ==================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __RSFSEX_HEADER
#define __RSFSEX_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= RSIB interface support ==================================================*/
/*                                                                           */
/* The RSIB interface is a R&S defined protocol for remote control of R&S    */
/* spectrum and network analyzers. In addition to the standard VISA          */
/* attributes, the RSIB passport supports the following manufacturer specific*/
/* attributes:                                                               */
/*                                                                           */
/*****************************************************************************/
#ifndef __RSVIRSIB_H__

#define RS_ATTR_RSIB_SRE     (0x3FFC0001UL)     /* Switch a device to local or remote */
#define RS_ATTR_RSIB_LOC     (0x3FFC0002UL)     /* Switch a device temporarily to local */
#define RS_ATTR_RSIB_VER     (0x3FFC0003UL)     /* Passport Release Version */

#endif /* __RSVIRSIB_H__ */

/*****************************************************************************/
/*= Multiplatform support defines ===========================================*/
/*                                                                           */
/*  Note that improper platform preprocessor directive may cause unexpected  */
/*  behaviour of the driver functions.                                       */
/*                                                                           */
/*****************************************************************************/
#if defined(_NI_unix_) || defined(_NI_sparc_)
#define CLOCKS_PER_SEC 1000000
#elif defined(_NI_mswin16_) || defined(_NI_mswin32_) || defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__)
#define CLOCKS_PER_SEC 1000
#elif defined(_NI_mac_)
#define CLOCKS_PER_SEC 1
#else
#error Undefined Platform. You need to add one of the
#error following to your compiler defines:
#error     Platform                      Preprocessor directive
#error Microsoft Windows 3.1           #define _NI_mswin16_
#error Windows 95/NT                   #define _NI_mswin32_
#error Solaris 1                       #define _NI_sparc_       1
#error Solaris 2                       #define _NI_sparc_       2
#error Mackintosh                      #define _NI_mac_
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)
#define VI_ERROR_INSTR_PARAMETER16              (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_INSTR_PARAMETER17              (_VI_ERROR+0x3FFC0811L)

/*****************************************************************************/
/*======== Instrument Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define RSFSEX_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSFSEX_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSFSEX_ERROR_INSTRUMENT_CONFLICT        (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSFSEX_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE  (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSFSEX_ERROR_INSTRUMENT_PRESELECTOR     (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL      (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSFSEX_ERROR_INSTRUMENT_IQ_OVERLOAD     (VI_ERROR_INSTR_OFFSET + 0xF6L)
        
/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rsfsex_init (ViRsrc resourceName, ViBoolean IDQuery,
                ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rsfsex_appReadSpectrum (ViSession instrSession,
                ViInt32 measurementMode,
                ViInt32 frequencyParameter,
                ViReal64 startFrequencyHz,
                ViReal64 stopFrequencyHz,
                ViInt32 sourceTrace, ViPInt32 no_ofPoints,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_appReadScan (ViSession instrSession,
                ViBoolean measurementMode,
                ViReal64 receiverFrequencyHz,
                ViReal64 stepWidthHz, ViPInt32 no_ofPoints,
                ViChar _VI_FAR statusData[],
                ViPInt32 traceStatus,
                ViReal64 _VI_FAR results_ofTrace1[],
                ViReal64 _VI_FAR results_ofTrace2[],
                ViReal64 _VI_FAR results_ofTrace3[],
                ViReal64 _VI_FAR results_ofTrace4[]);
ViStatus _VI_FUNC rsfsex_appReadReceiver (ViSession instrSession,
                ViBoolean measurementMode,
                ViPReal64 firstDetector,
                ViPReal64 secondDetector,
                ViPReal64 thirdDetector,
                ViPReal64 fourthDetector);
ViStatus _VI_FUNC rsfsex_confStartStopFrq (ViSession instrSession,
                ViInt32 window,
                ViInt32 frequencyParameter,
                ViReal64 startFrequencyHz,
                ViReal64 stopFrequencyHz);
ViStatus _VI_FUNC rsfsex_confSpanCenterFrq (ViSession instrSession,
                ViInt32 window,
                ViInt32 frequencyParameter,
                ViReal64 frequencySpanHz,
                ViReal64 centerFrequencyHz);
ViStatus _VI_FUNC rsfsex_confFreqOffset (ViSession instrSession, ViInt32 window,
                ViReal64 frequencyOffsetHz);
ViStatus _VI_FUNC rsfsex_confFreqLink (ViSession instrSession, ViInt32 window,
                ViInt32 frequencyParameter,
                ViInt32 linkParameter);
ViStatus _VI_FUNC rsfsex_confFreqMode (ViSession instrSession, ViInt32 window,
                ViInt32 frequencyMode);
ViStatus _VI_FUNC rsfsex_confRefLevel (ViSession instrSession, ViInt32 window,
                ViReal64 referenceLevelValue);
ViStatus _VI_FUNC rsfsex_confRefLevelOpt (ViSession instrSession,
                ViInt32 window,
                ViInt32 referenceLevelFunctionMode,
                ViReal64 maxLevelValue,
                ViReal64 referenceLevelOffset_dB,
                ViInt32 unit);
ViStatus _VI_FUNC rsfsex_confLevelRange (ViSession instrSession, ViInt32 window,
                ViInt32 levelRange,
                ViReal64 logManualValuedB);
ViStatus _VI_FUNC rsfsex_confMarkState (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViBoolean markerState);
ViStatus _VI_FUNC rsfsex_confMarkPosition (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViReal64 markerPosition);
ViStatus _VI_FUNC rsfsex_confMarkOpt (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 trace,
                ViBoolean deleteAllMkrs);
ViStatus _VI_FUNC rsfsex_confDeltaMarkState (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViBoolean markerState);
ViStatus _VI_FUNC rsfsex_confDeltaMarkPosition (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViReal64 markerPosition);
ViStatus _VI_FUNC rsfsex_confDeltaMarkOpt (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 trace, ViBoolean deleteAllMkrs,
                ViBoolean deltaMarker);
ViStatus _VI_FUNC rsfsex_confSumMark (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 summMkrFunction,
                ViBoolean stateSwitch);
ViStatus _VI_FUNC rsfsex_confDLines (ViSession instrSession, ViInt32 window,
                ViInt32 lineType, ViBoolean lineNo,
                ViInt32 lineOperationSwitch,
                ViReal64 linePositionValue);
ViStatus _VI_FUNC rsfsex_confLimitLineState (ViSession instrSession,
                ViInt32 window, ViInt32 limitLineNo,
                ViInt32 limitLineOperation,
                ViString limitLineName);
ViStatus _VI_FUNC rsfsex_confLimitLineParam (ViSession instrSession,
                ViInt32 window, ViInt32 traceNumber,
                ViInt32 limitLineNo,
                ViString limitLineName,
                ViString comment, ViBoolean spacing,
                ViBoolean modeX, ViBoolean modeY,
                ViBoolean ctrlUnit, ViBoolean domain,
                ViBoolean lineParameter, ViInt32 units,
                ViInt32 no_ofValues,
                ViReal64 _VI_FAR xaxisValues[],
                ViReal64 _VI_FAR yaxisValues[],
                ViReal64 margin);
ViStatus _VI_FUNC rsfsex_confLimitLineCat (ViSession instrSession,
                ViPInt32 number_of_limits,
                ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsfsex_confBaseLine (ViSession instrSession, ViInt32 window,
                ViBoolean thresholdState,
                ViReal64 linePositionValue);
ViStatus _VI_FUNC rsfsex_confTrace (ViSession instrSession, ViInt32 window,
                ViInt32 traceNumber, ViInt32 traceMode);
ViStatus _VI_FUNC rsfsex_confTraceAveMethod (ViSession instrSession,
                ViInt32 window,
                ViInt32 averagingMethod);
ViStatus _VI_FUNC rsfsex_confFeedControl (ViSession instrSession,
                ViBoolean feedControl);
ViStatus _VI_FUNC rsfsex_confTraceExp (ViSession instrSession, ViBoolean append);
ViStatus _VI_FUNC rsfsex_confTraceDSep (ViSession instrSession,
                ViBoolean separator);
ViStatus _VI_FUNC rsfsex_confTraceHeader (ViSession instrSession,
                ViBoolean header);
ViStatus _VI_FUNC rsfsex_confTraceComment (ViSession instrSession,
                ViString commentString);
ViStatus _VI_FUNC rsfsex_confTraceIQState (ViSession instrSession,
                ViBoolean traceState);
ViStatus _VI_FUNC rsfsex_confTraceIQ (ViSession instrSession,
                ViReal64 sampleRateHz, ViInt32 triggerMode,
                ViBoolean triggerSlope,
                ViReal64 triggerOffsets,
                ViReal64 recordLengths);
ViStatus _VI_FUNC rsfsex_confResbw (ViSession instrSession, ViInt32 window,
                ViReal64 bwValueHz);
ViStatus _VI_FUNC rsfsex_confResbwType (ViSession instrSession, ViInt32 window,
                ViInt32 resBWType);
ViStatus _VI_FUNC rsfsex_confCoup (ViSession instrSession, ViInt32 window,
                ViInt32 bandwidthOperation, ViInt32 bandwidth,
                ViInt32 resolutionMode, ViInt32 bandwidthPLL,
                ViReal64 ratio);
ViStatus _VI_FUNC rsfsex_confSweep (ViSession instrSession, ViInt32 window,
                ViInt32 sweep, ViInt32 sweepCountValue);
ViStatus _VI_FUNC rsfsex_confSweepTime (ViSession instrSession, ViInt32 window,
                ViReal64 sweepTime);
ViStatus _VI_FUNC rsfsex_confTrg (ViSession instrSession, ViInt32 window,
                ViInt32 trigger, ViReal64 triggerValue,
                ViBoolean triggerSlope);
ViStatus _VI_FUNC rsfsex_confTrgDelay (ViSession instrSession, ViInt32 window,
                ViReal64 triggerValues);
ViStatus _VI_FUNC rsfsex_confSweepSpac (ViSession instrSession, ViInt32 window,
                ViInt32 sweepSpacingMode);
ViStatus _VI_FUNC rsfsex_confRFInAtt (ViSession instrSession, ViInt32 window,
                ViReal64 manualAttenuatorValuedB);
ViStatus _VI_FUNC rsfsex_confRFInAttAuto (ViSession instrSession,
                ViInt32 window, ViInt32 RFAttenuation);
ViStatus _VI_FUNC rsfsex_confRFInAttStep (ViSession instrSession,
                ViInt32 window,
                ViInt32 attenuatorStepsize);
ViStatus _VI_FUNC rsfsex_confRFInImp (ViSession instrSession, ViInt32 window,
                ViInt32 inputImpedance);
ViStatus _VI_FUNC rsfsex_confRFInputCoupling (ViSession instrSession,
                ViInt32 window, ViBoolean coupling);
ViStatus _VI_FUNC rsfsex_confRFInput (ViSession instrSession, ViInt32 window,
                ViBoolean selectInput);
ViStatus _VI_FUNC rsfsex_confRFInputGain (ViSession instrSession,
                ViInt32 window,
                ViBoolean autoPreamplifier,
                ViReal64 inputGaindB);
ViStatus _VI_FUNC rsfsex_confMixerLev (ViSession instrSession, ViInt32 window,
                ViReal64 mixerLeveldBm);
ViStatus _VI_FUNC rsfsex_confExtMixBLOn (ViSession instrSession, ViInt32 window,
                ViInt32 band, ViInt32 harmonicType,
                ViBoolean ports,
                ViBoolean conversionLossTableUsed,
                ViString conversionLossTableName,
                ViReal64 conversionLossLowdB,
                ViReal64 conversionLossHighdB,
                ViBoolean biasState, ViReal64 biasmA);
ViStatus _VI_FUNC rsfsex_confExtMixBLOff (ViSession instrSession,
                ViInt32 window, ViBoolean ports,
                ViInt32 harmonicOrder,
                ViReal64 conversionLossdB,
                ViBoolean biasState, ViReal64 biasmA);
ViStatus _VI_FUNC rsfsex_confExtMix (ViSession instrSession, ViInt32 window,
                ViBoolean externalMixerState);
ViStatus _VI_FUNC rsfsex_confExtMixSignal (ViSession instrSession,
                ViInt32 window, ViInt32 signalID,
                ViReal64 autoIDThresholddB);
ViStatus _VI_FUNC rsfsex_confDefConvLoss (ViSession instrSession,
                ViInt32 window);
ViStatus _VI_FUNC rsfsex_confExtMixLossTab (ViSession instrSession,
                ViInt32 window, ViString tableName,
                ViString mixerType,
                ViString serialNumber, ViInt32 band,
                ViInt32 harmonicType, ViReal64 biasmA,
                ViString comment, ViBoolean ports,
                ViInt32 numberOfValues,
                ViReal64 _VI_FAR frequencyValuesHz[],
                ViReal64 _VI_FAR conversionLossValuesdB[]);
ViStatus _VI_FUNC rsfsex_confExtMixLossTabDelete (ViSession instrSession,
                ViInt32 window,
                ViString tableName);
ViStatus _VI_FUNC rsfsex_confExtMixLossTabCat (ViSession instrSession,
                ViInt32 window,
                ViPInt32 nb_of_tables,
                ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsfsex_confPreselState (ViSession instrSession,
                ViInt32 window,
                ViBoolean preselectorState);
ViStatus _VI_FUNC rsfsex_confDisplayMode (ViSession instrSession,
                ViBoolean displayFormat);
ViStatus _VI_FUNC rsfsex_confScreenCpl (ViSession instrSession,
                ViBoolean coupling);
ViStatus _VI_FUNC rsfsex_confDisplayControl (ViSession instrSession,
                ViBoolean frequency, ViBoolean logo,
                ViBoolean time,
                ViBoolean displayComment);
ViStatus _VI_FUNC rsfsex_confDisplayComment (ViSession instrSession,
                ViString commentString);
ViStatus _VI_FUNC rsfsex_confDisplayParams (ViSession instrSession,
                ViInt32 displayParameter,
                ViInt32 colorMap,
                ViInt32 predefinedColors, ViReal64 TINT,
                ViReal64 SATURATION,
                ViReal64 BRIGHTNESS);
ViStatus _VI_FUNC rsfsex_confDisplayUpdate (ViSession instrSession,
                ViBoolean displayUpdate);
ViStatus _VI_FUNC rsfsex_confDisplaySave (ViSession instrSession,
                ViBoolean screenSaver,
                ViInt32 holdoffTime);
ViStatus _VI_FUNC rsfsex_confTransducer (ViSession instrSession,
                ViInt32 transducerOperation,
                ViString transducerName,
                ViBoolean transducerState);
ViStatus _VI_FUNC rsfsex_confTransducerGet (ViSession instrSession,
                ViInt32 transducerOperation,
                ViChar _VI_FAR activeTransducer[]);
ViStatus _VI_FUNC rsfsex_confTransducerDef (ViSession instrSession,
                ViString transducerName,
                ViBoolean transducerScaling,
                ViInt32 transducerFactorUnit,
                ViString transducerComment,
                ViInt32 no_ofTestPoints,
                ViReal64 _VI_FAR frequencyData[],
                ViReal64 _VI_FAR levelData[]);
ViStatus _VI_FUNC rsfsex_confTransducerSetDef (ViSession instrSession,
                ViString transducerSetName,
                ViInt32 transducerSetUnit,
                ViString transducerSetComment,
                ViBoolean sweepBreak,
                ViInt32 no_ofRanges,
                ViString transducerNames,
                ViReal64 _VI_FAR rangeStartFrequencies[],
                ViReal64 _VI_FAR rangeStopFrequencies[]);
ViStatus _VI_FUNC rsfsex_confTransducerCat (ViSession instrSession,
                ViInt32 transducerOperation,
                ViPInt32 number_ofFiles,
                ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsfsex_confReferenceOsc (ViSession instrSession,
                ViBoolean source,
                ViInt32 externalFrequency);
ViStatus _VI_FUNC rsfsex_confSystemTime (ViSession instrSession,
                ViBoolean timeDate, ViInt32 hour,
                ViInt32 minute, ViInt32 second,
                ViInt32 day, ViInt32 month, ViInt32 year);
ViStatus _VI_FUNC rsfsex_confHCOpt (ViSession instrSession, ViInt32 window,
                ViInt32 output, ViInt32 quadrant,
                ViBoolean color, ViBoolean changeTraceColor);
ViStatus _VI_FUNC rsfsex_confHCComment (ViSession instrSession,
                ViString screenTitle,
                ViString firstScreenComment,
                ViString secondScreenComment);
ViStatus _VI_FUNC rsfsex_confHCDevice (ViSession instrSession,
                ViInt32 deviceNumber, ViInt32 dataFormat,
                ViInt32 destination, ViInt32 GPIBAddress,
                ViBoolean preset, ViBoolean formFeed,
                ViBoolean paperFeed, ViBoolean resolution,
                ViBoolean pageOrientation);
ViStatus _VI_FUNC rsfsex_confNTHCDevice (ViSession instrSession,
                ViInt32 deviceNumber, ViInt32 dataFormat,
                ViInt32 destination);
ViStatus _VI_FUNC rsfsex_confGetPrinterList (ViSession instrSession,
                ViChar _VI_FAR printerList[]);
ViStatus _VI_FUNC rsfsex_confSetPrinter (ViSession instrSession,
                ViInt32 deviceNumber, ViString printerName);
ViStatus _VI_FUNC rsfsex_confSAMMarkDemod (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViReal64 markerStopTimes,
                ViBoolean demodulationState,
                ViBoolean modulationType,
                ViReal64 speakerVolumePerc);
ViStatus _VI_FUNC rsfsex_confSAMMarkFreqCnt (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 counterResolution,
                ViBoolean signalCounterState);
ViStatus _VI_FUNC rsfsex_confSAMMarkNoise (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViBoolean noiseMeasurementState);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanChannels (ViSession instrSession,
                ViInt32 window,
                ViInt32 numberOfAdjacentChannels);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanStandard (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViInt32 ACPStandard);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanOpt (ViSession instrSession,
                ViInt32 window,
                ViInt32 numberOfAdjacentChannels,
                ViReal64 CHBandwidthHz,
                ViReal64 ADJBandwidthHz,
                ViReal64 ADJChannelSpacingHz,
                ViReal64 ALT1BandwidthHz,
                ViReal64 ALT1ChannelSpacingHz,
                ViReal64 ALT2BandwidthHz,
                ViReal64 ALT2ChannelSpacingHz);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanSet (ViSession instrSession,
                ViInt32 window,
                ViBoolean CPACPMode);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowOccPowBW (ViSession instrSession,
                ViInt32 window,
                ViReal64 powerBandwidthPerc);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowMeas (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 channelPowerType,
                ViBoolean channelPowerFunctionMode);
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowLim (ViSession instrSession,
                ViInt32 window,
                ViInt32 numberOfAdjacentChannels,
                ViReal64 ADJLowLimitdB,
                ViReal64 ALT1LowLimitdB,
                ViReal64 ALT2LowLimitdB,
                ViReal64 ADJHighLimitdB,
                ViReal64 ALT1HighLimitdB,
                ViReal64 ALT2HighLimitdB,
                ViBoolean ADJLimitState,
                ViBoolean ALT1LimitState,
                ViBoolean ALT2LimitState);
ViStatus _VI_FUNC rsfsex_confSAMDeltaMarkFixRef (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViBoolean referenceFixed);
ViStatus _VI_FUNC rsfsex_confSAMDeltaMarkFixRefPoint (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViInt32 referencePointSel,
                ViReal64 refPointValue);
ViStatus _VI_FUNC rsfsex_confSAMMarkPhaseNoise (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViBoolean phaseNoiseMeasurementState);
ViStatus _VI_FUNC rsfsex_confSAMMarkSearchParam (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViReal64 peakExcursiondB,
                ViBoolean excludeLO,
                ViBoolean searchLimit);
ViStatus _VI_FUNC rsfsex_confSAMMarkSearchNdB (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 levelFunction,
                ViReal64 n_dBDownValuedB);
ViStatus _VI_FUNC rsfsex_confSAMDetector (ViSession instrSession,
                ViInt32 traceNumber,
                ViInt32 traceDetector);
ViStatus _VI_FUNC rsfsex_confSAMTraceMath (ViSession instrSession,
                ViInt32 window, ViInt32 traceNumber,
                ViBoolean mathState,
                ViString mathExpression);
ViStatus _VI_FUNC rsfsex_confSAMVibw (ViSession instrSession, ViInt32 window,
                ViReal64 bwValueHz);
ViStatus _VI_FUNC rsfsex_confSAMGateSet (ViSession instrSession, ViInt32 window,
                ViBoolean gateSweep, ViReal64 gateLevelV,
                ViBoolean gateMode, ViBoolean gatePolarity,
                ViReal64 gateDelays, ViReal64 gateLengths,
                ViBoolean gateSource);
ViStatus _VI_FUNC rsfsex_confSAMGapSweep (ViSession instrSession,
                ViInt32 window, ViBoolean gapSweep,
                ViReal64 preTriggers, ViReal64 gapLengths,
                ViReal64 trgToGapTimes);
ViStatus _VI_FUNC rsfsex_confAFDemodMode (ViSession instrSession,
                ViInt32 window, ViInt32 demodulationMode);
ViStatus _VI_FUNC rsfsex_confVSAMDigiSTD (ViSession instrSession,
                ViInt32 window, ViInt32 digitalStandards);
ViStatus _VI_FUNC rsfsex_confVSAMDigiDemod (ViSession instrSession,
                ViInt32 window,
                ViInt32 demodulationFormat);
ViStatus _VI_FUNC rsfsex_confVSAMDigiDemodParam (ViSession instrSession,
                ViInt32 window,
                ViInt32 measurementFilter,
                ViInt32 referenceFilter,
                ViReal64 symbolRateHz,
                ViReal64 alphaBt);
ViStatus _VI_FUNC rsfsex_confVSAMDigiDemodParamDef (ViSession instrSession,
                ViInt32 window,
                ViBoolean normalize,
                ViBoolean sideBand,
                ViReal64 FSKRefDeviationHz);
ViStatus _VI_FUNC rsfsex_confVSAMDigiResultParam (ViSession instrSession,
                ViInt32 window, ViInt32 operation,
                ViInt32 operationValue);
ViStatus _VI_FUNC rsfsex_confVSAMDigiResult (ViSession instrSession,
                ViInt32 window, ViInt32 format);
ViStatus _VI_FUNC rsfsex_confVSAMADemodParam (ViSession instrSession,
                ViInt32 window,
                ViInt32 demodulationParameter,
                ViBoolean AFCoupling,
                ViBoolean sideBand,
                ViBoolean realTime);
ViStatus _VI_FUNC rsfsex_confVSAMDemodFilt (ViSession instrSession,
                ViInt32 window, ViInt32 filterType,
                ViBoolean filterState,
                ViInt32 filterFrequency,
                ViInt32 AMFMDeemphasisValue,
                ViBoolean deemphasisDisplay);
ViStatus _VI_FUNC rsfsex_confVSAMDemodBW (ViSession instrSession,
                ViInt32 window,
                ViReal64 demodulationBandwidthHz);
ViStatus _VI_FUNC rsfsex_confVSAMDemodSq (ViSession instrSession,
                ViInt32 window,
                ViInt32 demodulationParameter,
                ViBoolean squelchState,
                ViReal64 parameterValue);
ViStatus _VI_FUNC rsfsex_confVSAMSumSet (ViSession instrSession, ViInt32 window,
                ViInt32 summaryParameter,
                ViBoolean averageHoldSINAD,
                ViBoolean measurementIndication,
                ViReal64 referenceValue,
                ViBoolean summaryTime);
ViStatus _VI_FUNC rsfsex_confVSAMSumSetUnits (ViSession instrSession,
                ViInt32 window, ViBoolean markerUnits);
ViStatus _VI_FUNC rsfsex_confVSAMDigiTrg (ViSession instrSession,
                ViInt32 window, ViBoolean findBurst,
                ViBoolean findSync);
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqOffset (ViSession instrSession,
                ViInt32 window, ViInt32 syncOffset);
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeq (ViSession instrSession,
                ViInt32 window, ViString syncPattern);
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqSel (ViSession instrSession,
                ViInt32 window, ViInt32 operation,
                ViString patternName, ViString comment,
                ViString syncPattern);
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqCat (ViSession instrSession,
                ViInt32 window, ViPInt32 nb_of_files,
                ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqMOnly (ViSession instrSession,
                ViInt32 window, ViBoolean measOnly);
ViStatus _VI_FUNC rsfsex_confVSAMDemodMode (ViSession instrSession,
                ViInt32 window, ViInt32 operatingMode);
ViStatus _VI_FUNC rsfsex_confVSAMDisp (ViSession instrSession, ViInt32 window,
                ViInt32 refValueOperation,
                ViReal64 refValueX, ViReal64 refValueY,
                ViReal64 refValuePosition,
                ViReal64 y_perDivision);
ViStatus _VI_FUNC rsfsex_confVSAMDispScalingMode (ViSession instrSession,
                ViInt32 window,
                ViBoolean scalingMode);
ViStatus _VI_FUNC rsfsex_confVSAMarkCoupled (ViSession instrSession,
                ViInt32 window, ViBoolean couplingMode);
ViStatus _VI_FUNC rsfsex_confTrackSrc (ViSession instrSession, ViInt32 window,
                ViInt32 setSourceValue, ViReal64 sourceValue);
ViStatus _VI_FUNC rsfsex_confTrackDisp (ViSession instrSession, ViInt32 window,
                ViReal64 refValuePosition,
                ViReal64 refValue);
ViStatus _VI_FUNC rsfsex_confTrackModulation (ViSession instrSession,
                ViInt32 window, ViInt32 modulation,
                ViBoolean modState);
ViStatus _VI_FUNC rsfsex_confTVTrgSeq (ViSession instrSession, ViInt32 window,
                ViBoolean syncType, ViInt32 verticalSync,
                ViInt32 horizontalSyncValue,
                ViBoolean videoPolarity,
                ViBoolean lineSystem);
ViStatus _VI_FUNC rsfsex_confTVPSOffset (ViSession instrSession, ViInt32 window,
                ViReal64 offsetValueHz);
ViStatus _VI_FUNC rsfsex_confMSModType (ViSession instrSession,
                ViBoolean modulationType);
ViStatus _VI_FUNC rsfsex_confBTSModType (ViSession instrSession,
                ViBoolean modulationType);
ViStatus _VI_FUNC rsfsex_confGSMExtAttn (ViSession instrSession,
                ViReal64 externalAttndB);
ViStatus _VI_FUNC rsfsex_confBTSPower (ViSession instrSession, ViInt32 BTSPower,
                ViReal64 powerValue);
ViStatus _VI_FUNC rsfsex_confMSPower (ViSession instrSession, ViInt32 MSPower,
                ViReal64 powerValue);
ViStatus _VI_FUNC rsfsex_confMSSmall (ViSession instrSession, ViBoolean limits);
ViStatus _VI_FUNC rsfsex_confMSPowerLline (ViSession instrSession,
                ViReal64 refPowerValue);
ViStatus _VI_FUNC rsfsex_confBTSPowerLline (ViSession instrSession,
                ViReal64 refPowerValue);
ViStatus _VI_FUNC rsfsex_confMSErrLim (ViSession instrSession,
                ViInt32 errorLimit, ViReal64 errorLimitValue);
ViStatus _VI_FUNC rsfsex_confBTSErrLim (ViSession instrSession,
                ViInt32 errorLimit,
                ViReal64 errorLimitValue);
ViStatus _VI_FUNC rsfsex_confMSErrLimUser (ViSession instrSession,
                ViBoolean limits);
ViStatus _VI_FUNC rsfsex_confBTSErrLimUser (ViSession instrSession,
                ViBoolean limits);
ViStatus _VI_FUNC rsfsex_confGSMSpurRange (ViSession instrSession,
                ViInt32 spuriousParameter);
ViStatus _VI_FUNC rsfsex_confGSMSpurEmi (ViSession instrSession,
                ViBoolean antenna);
ViStatus _VI_FUNC rsfsex_confGSMSpurStep (ViSession instrSession,
                ViInt32 subbandNumber,
                ViBoolean measurementState);
ViStatus _VI_FUNC rsfsex_confMSSFH (ViSession instrSession, ViBoolean MSSFH);
ViStatus _VI_FUNC rsfsex_confBTSSFH (ViSession instrSession, ViBoolean BTSSFH);
ViStatus _VI_FUNC rsfsex_confBTSCositing (ViSession instrSession,
                ViBoolean cositing);
ViStatus _VI_FUNC rsfsex_confGSMNoCnt (ViSession instrSession,
                ViInt32 countParameter,
                ViInt32 number_ofCounts);
ViStatus _VI_FUNC rsfsex_confGSMPowCond (ViSession instrSession,
                ViBoolean PWRMeasConditon);
ViStatus _VI_FUNC rsfsex_confGSMPFerCond (ViSession instrSession,
                ViBoolean conditions);
ViStatus _VI_FUNC rsfsex_confGSMBurstRef (ViSession instrSession,
                ViBoolean burstReferenceAuto);
ViStatus _VI_FUNC rsfsex_confGSMModRange (ViSession instrSession,
                ViInt32 modulationRange);
ViStatus _VI_FUNC rsfsex_confGSMRXBandGain (ViSession instrSession,
                ViReal64 RXBandGaindB);
ViStatus _VI_FUNC rsfsex_confGSMTXGate (ViSession instrSession,
                ViBoolean gatingState);
ViStatus _VI_FUNC rsfsex_confGSMSyncSrc (ViSession instrSession,
                ViBoolean syncToMidamble);
ViStatus _VI_FUNC rsfsex_confMSSweeptime (ViSession instrSession,
                ViBoolean sweepTime);
ViStatus _VI_FUNC rsfsex_confBTSSweeptime (ViSession instrSession,
                ViBoolean sweepTime);
ViStatus _VI_FUNC rsfsex_confBTSStationType (ViSession instrSession,
                ViInt32 BTSType);
ViStatus _VI_FUNC rsfsex_confGSMCondition (ViSession instrSession,
                ViBoolean conditions);
ViStatus _VI_FUNC rsfsex_confGSMMeasBW (ViSession instrSession,
                ViInt32 measurementBandwidth);
ViStatus _VI_FUNC rsfsex_confRECInAttAuto (ViSession instrSession,
                ViInt32 window, ViBoolean attenuatorMode);
ViStatus _VI_FUNC rsfsex_confRECFreq (ViSession instrSession,
                ViReal64 receiverFrequencyHz,
                ViReal64 stepWidthHz);
ViStatus _VI_FUNC rsfsex_confRECCoupling (ViSession instrSession,
                ViBoolean markerTrack,
                ViBoolean settingsCoupled);
ViStatus _VI_FUNC rsfsex_confRECDetector (ViSession instrSession,
                ViBoolean maxPeakDetector,
                ViBoolean minPeakDetector,
                ViBoolean averageDetector,
                ViBoolean RMSDetector,
                ViBoolean ACVideoDetector,
                ViBoolean QPEakDetector,
                ViBoolean QPEakRBWCoupling);
ViStatus _VI_FUNC rsfsex_confRECYAxesRange (ViSession instrSession,
                ViInt32 window, ViBoolean yaxesMode,
                ViReal64 yaxesValue);
ViStatus _VI_FUNC rsfsex_confRECScanNoRanges (ViSession instrSession,
                ViInt32 no_ofRanges);
ViStatus _VI_FUNC rsfsex_confRECScanRange (ViSession instrSession,
                ViInt32 rangeNo,
                ViReal64 startFrequencyHz,
                ViReal64 stopFrequencyHz,
                ViReal64 stepWidth,
                ViReal64 IFBandwidthHz,
                ViReal64 measurementTimes,
                ViBoolean autoPreamplifier,
                ViReal64 inputGaindB,
                ViBoolean autoRanging,
                ViReal64 manualAttenuationdB,
                ViBoolean selectInput, ViInt32 RESERVED);
ViStatus _VI_FUNC rsfsex_confRECSweep (ViSession instrSession, ViInt32 window,
                ViBoolean sweepMode);
ViStatus _VI_FUNC rsfsex_confCDPMeas (ViSession instrSession,
                ViInt32 CDPMeasurement);
ViStatus _VI_FUNC rsfsex_confWCDPMeas (ViSession instrSession,
                ViInt32 WCDPMeasurement);
ViStatus _VI_FUNC rsfsex_confWCDPMSMeas (ViSession instrSession,
                ViInt32 WCDPMeasurement);
ViStatus _VI_FUNC rsfsex_confCDPMeasMode (ViSession instrSession,
                ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsex_confWCDPMeasMode (ViSession instrSession,
                ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsex_confCDPSetStd (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_confCDPPNOffset (ViSession instrSession,
                ViInt32 offset);
ViStatus _VI_FUNC rsfsex_confCDPICT (ViSession instrSession,
                ViReal64 tresholdValuedB);
ViStatus _VI_FUNC rsfsex_confCDPSBand (ViSession instrSession,
                ViBoolean sideBand);
ViStatus _VI_FUNC rsfsex_confCDPMeasPeriod (ViSession instrSession,
                ViBoolean autoMode,
                ViInt32 manualSettings);
ViStatus _VI_FUNC rsfsex_confCDPFastMode (ViSession instrSession,
                ViBoolean fastMode);
ViStatus _VI_FUNC rsfsex_confCDPInpChan (ViSession instrSession,
                ViInt32 CDMAStandard, ViInt32 inputChannel);
ViStatus _VI_FUNC rsfsex_confCDPSFactor (ViSession instrSession,
                ViInt32 spreadingFactor);
ViStatus _VI_FUNC rsfsex_confCDPCodeNum (ViSession instrSession,
                ViInt32 codeNumber);
ViStatus _VI_FUNC rsfsex_confCDPSlot (ViSession instrSession, ViInt32 CPICHSlot);
ViStatus _VI_FUNC rsfsex_confCDPLCode (ViSession instrSession,
                ViInt32 scramblingCode);
ViStatus _VI_FUNC rsfsex_confCDPNormalize (ViSession instrSession,
                ViBoolean IQOffset);
ViStatus _VI_FUNC rsfsex_confCDPQInvert (ViSession instrSession,
                ViBoolean QInvert);
ViStatus _VI_FUNC rsfsex_confCDPPref (ViSession instrSession,
                ViBoolean preference);
ViStatus _VI_FUNC rsfsex_confCDPSyncType (ViSession instrSession,
                ViBoolean syncType);
ViStatus _VI_FUNC rsfsex_confCDPSigMap (ViSession instrSession,
                ViBoolean signalMapping);
ViStatus _VI_FUNC rsfsex_confCDPAntennaType (ViSession instrSession,
                ViInt32 antennaMode);
ViStatus _VI_FUNC rsfsex_confWCDPChTable (ViSession instrSession,
                ViBoolean channelTable);
ViStatus _VI_FUNC rsfsex_confWCDPChTableFile (ViSession instrSession,
                ViString channelTableFile);
ViStatus _VI_FUNC rsfsex_confWCDPChTableName (ViSession instrSession,
                ViString channelTableName);
ViStatus _VI_FUNC rsfsex_confWCDPChTableCopy (ViSession instrSession,
                ViString channelTableName);
ViStatus _VI_FUNC rsfsex_confWCDPChTableDelete (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_confWCDPChTableRestore (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_confWCDPChTableComment (ViSession instrSession,
                ViString channelTableComment);
ViStatus _VI_FUNC rsfsex_confWCDPChTableData (ViSession instrSession,
                ViInt32 _VI_FAR codeClass[],
                ViInt32 _VI_FAR codeNumber[],
                ViInt32 _VI_FAR useTFCI[],
                ViInt32 _VI_FAR timingOffset[],
                ViInt32 _VI_FAR pilotLength[],
                ViInt32 _VI_FAR pitch[],
                ViInt32 _VI_FAR status[],
                ViReal64 _VI_FAR CDPRelative[],
                ViInt32 num_ofElements);
ViStatus _VI_FUNC rsfsex_confWCDPChTableCatalog (ViSession instrSession,
                ViPInt32 number_ofChannelTables,
                ViInt32 bufferSize,
                ViChar _VI_FAR channelTablesList[]);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTable (ViSession instrSession,
                ViBoolean channelTable);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableFile (ViSession instrSession,
                ViString channelTableFile);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableName (ViSession instrSession,
                ViString channelTableName);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableCopy (ViSession instrSession,
                ViString channelTableName);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableDelete (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableComment (ViSession instrSession,
                ViString channelTableComment);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableData (ViSession instrSession,
                ViInt32 codeClass,
                ViInt32 pilotLength,
                ViInt32 number_ofActiveChannels);
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableCatalog (ViSession instrSession,
                ViPInt32 number_ofChannelTables,
                ViInt32 bufferSize,
                ViChar _VI_FAR channelTablesList[]);
ViStatus _VI_FUNC rsfsex_confStatMeasSamples (ViSession instrSession,
                ViInt32 number_ofSamples);
ViStatus _VI_FUNC rsfsex_confStatMeasScal (ViSession instrSession,
                ViReal64 lowerLimit, ViReal64 upperLimit);
ViStatus _VI_FUNC rsfsex_confStatPercentMkr (ViSession instrSession,
                ViReal64 probability);
ViStatus _VI_FUNC rsfsex_confCDPNomPwr (ViSession instrSession,
                ViReal64 nominalPowerdBm);
ViStatus _VI_FUNC rsfsex_confCDPLimStd (ViSession instrSession,
                ViBoolean standardLimits);
ViStatus _VI_FUNC rsfsex_confCDPLimCheck (ViSession instrSession,
                ViBoolean limitChecking);
ViStatus _VI_FUNC rsfsex_confCDPUsrLimits (ViSession instrSession,
                ViBoolean lowerUpperLimits,
                ViReal64 totalPWRTolerance,
                ViReal64 pilotPWRRatio,
                ViReal64 pilotTimeAligment,
                ViReal64 frequencyError,
                ViReal64 CHTimeError,
                ViReal64 CHPhaseError,
                ViReal64 inactiveCHPWRRatio);
ViStatus _VI_FUNC rsfsex_confSEMLimitLine (ViSession instrSession,
                ViInt32 measMode, ViReal64 expectedPower);
ViStatus _VI_FUNC rsfsex_actMarkSearch (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 searchMode);
ViStatus _VI_FUNC rsfsex_actDMarkSearch (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 searchMode);
ViStatus _VI_FUNC rsfsex_actMarkTo (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 mkrFunction,
                ViInt32 trace);
ViStatus _VI_FUNC rsfsex_actDMarkTo (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 trace);
ViStatus _VI_FUNC rsfsex_actMarkDeltaValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 deltaMarker,
                ViPReal64 _Real_DeltaMarkerValue,
                ViPReal64 _Imaginary_DeltaMarkerValue);
ViStatus _VI_FUNC rsfsex_actMarkValue (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber,
                ViPReal64 realMarkerValue,
                ViPReal64 imaginaryMarkerValue);
ViStatus _VI_FUNC rsfsex_actSetLimitLinesOffset (ViSession instrSession,
                ViInt32 window, ViReal64 XOffset,
                ViReal64 YOffset);
ViStatus _VI_FUNC rsfsex_actLimitCheck (ViSession instrSession, ViInt32 window,
                ViInt32 limitLineNo, ViPInt32 checkResult);
ViStatus _VI_FUNC rsfsex_actLimitLinesAct (ViSession instrSession,
                ViInt32 bufferSize,
                ViChar _VI_FAR limitLineList[]);
ViStatus _VI_FUNC rsfsex_actSendTrg (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actSendTrgWopc (ViSession instrSession,
                ViInt32 timeoutms);
ViStatus _VI_FUNC rsfsex_actAbort (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actCalibration (ViSession instrSession,
                ViInt32 calibrationType, ViInt32 timeoutms,
                ViPInt32 calibrationResult);
ViStatus _VI_FUNC rsfsex_actCalCorr (ViSession instrSession,
                ViBoolean calibrationData);
ViStatus _VI_FUNC rsfsex_actServiceSource (ViSession instrSession,
                ViBoolean signalSource,
                ViBoolean noiseSource);
ViStatus _VI_FUNC rsfsex_actHCopy (ViSession instrSession, ViInt32 deviceNumber);
ViStatus _VI_FUNC rsfsex_actGetSystemTime (ViSession instrSession,
                ViBoolean timeDate, ViPInt32 hour,
                ViPInt32 minute, ViPInt32 second,
                ViPInt32 day, ViPInt32 month,
                ViPInt32 year);
ViStatus _VI_FUNC rsfsex_actMemOp (ViSession instrSession,
                ViInt32 operation_to_bePerformed,
                ViString source, ViString destination);
ViStatus _VI_FUNC rsfsex_actMemSel (ViSession instrSession,
                ViInt32 itemSelector, ViBoolean itemState);
ViStatus _VI_FUNC rsfsex_actSAMMode (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsfsex_actSAMMarkCntValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViPReal64 markerFrequency);
ViStatus _VI_FUNC rsfsex_actSAMMarkNdBDValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViBoolean n_dBDownQuery,
                ViReal64 _VI_FAR returnedValue[]);
ViStatus _VI_FUNC rsfsex_actSAMMarkNoiseValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViPReal64 noiseResult);
ViStatus _VI_FUNC rsfsex_actSAMPhaseNoiseResult (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViPReal64 noiseResult);
ViStatus _VI_FUNC rsfsex_actSAMMarkShapeValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViBoolean shapeFactorQuery,
                ViReal64 _VI_FAR shapeFactorValues[]);
ViStatus _VI_FUNC rsfsex_actSAMMarkPowerValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 channelPowerType,
                ViReal64 _VI_FAR powerValue[]);
ViStatus _VI_FUNC rsfsex_actSAMMarkChPowToRef (ViSession instrSession,
                ViInt32 window);
ViStatus _VI_FUNC rsfsex_actSAMCPSet (ViSession instrSession, ViInt32 window,
                ViInt32 channelPowerType);
ViStatus _VI_FUNC rsfsex_actSAMCPAdjust (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsfsex_actSAMACPLimitCheckState (ViSession instrSession,
                ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsfsex_actSAMACPLimitCheck (ViSession instrSession,
                ViInt32 window, ViInt32 ACPResult,
                ViPInt32 firstResult,
                ViPInt32 secondResult);
ViStatus _VI_FUNC rsfsex_actSAMCopyTrace (ViSession instrSession,
                ViInt32 sourceTrace,
                ViInt32 destinationTrace);
ViStatus _VI_FUNC rsfsex_actVSAMMode (ViSession instrSession, ViInt32 window,
                ViBoolean setMode);
ViStatus _VI_FUNC rsfsex_actVSAMSumRef (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsfsex_actVSAMMarkerADemod (ViSession instrSession,
                ViInt32 window,
                ViInt32 modulationType,
                ViInt32 parameterToRead,
                ViPReal64 measuredValue);
ViStatus _VI_FUNC rsfsex_actVSAMMarkerDDemod (ViSession instrSession,
                ViInt32 window,
                ViInt32 parameterToRead,
                ViPReal64 measuredValue);
ViStatus _VI_FUNC rsfsex_actVSAMMarkerSumValue (ViSession instrSession,
                ViInt32 window,
                ViInt32 markerNumber,
                ViInt32 summaryMarker,
                ViPReal64 measuredValue);
ViStatus _VI_FUNC rsfsex_actTrackMode (ViSession instrSession, ViInt32 window,
                ViBoolean setMode);
ViStatus _VI_FUNC rsfsex_actTrackCorrState (ViSession instrSession,
                ViInt32 window, ViBoolean corrState);
ViStatus _VI_FUNC rsfsex_actTrackCorr (ViSession instrSession, ViInt32 window,
                ViInt32 sourceCalibration, ViInt32 timeoutms);
ViStatus _VI_FUNC rsfsex_actTVMode (ViSession instrSession, ViInt32 window,
                ViBoolean setMode);
ViStatus _VI_FUNC rsfsex_actTVTriggerSrc (ViSession instrSession,
                ViInt32 window);
ViStatus _VI_FUNC rsfsex_actGSMBTSMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actGSMMSMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actBTSARFCN (ViSession instrSession,
                ViBoolean ARFCNMode, ViInt32 ARFCNValue);
ViStatus _VI_FUNC rsfsex_actMSARFCN (ViSession instrSession,
                ViBoolean ARFCNMode, ViInt32 ARFCNValue);
ViStatus _VI_FUNC rsfsex_actBTSChannel (ViSession instrSession,
                ViBoolean slotMode, ViInt32 slotNumber,
                ViBoolean TSCMode, ViInt32 TSCNumber);
ViStatus _VI_FUNC rsfsex_actMSChannel (ViSession instrSession, ViInt32 midamble);
ViStatus _VI_FUNC rsfsex_actGSMTrgAdj (ViSession instrSession,
                ViInt32 triggerAdjust,
                ViReal64 frameSlotValue);
ViStatus _VI_FUNC rsfsex_actBTSNetwork (ViSession instrSession,
                ViInt32 networkType);
ViStatus _VI_FUNC rsfsex_actMSNetwork (ViSession instrSession,
                ViInt32 networkType);
ViStatus _VI_FUNC rsfsex_actBTSSupp (ViSession instrSession,
                ViBoolean suppressionState);
ViStatus _VI_FUNC rsfsex_actGSMBurstSection (ViSession instrSession,
                ViInt32 burstSection);
ViStatus _VI_FUNC rsfsex_actMSSingleMeas (ViSession instrSession,
                ViBoolean singleMeasurement);
ViStatus _VI_FUNC rsfsex_actBTSSingleMeas (ViSession instrSession,
                ViBoolean singleMeasurement);
ViStatus _VI_FUNC rsfsex_actMSClrSingleRes (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actBTSClrSingleRes (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actMSPowerCpl (ViSession instrSession,
                ViBoolean limit_Power_Coupled);
ViStatus _VI_FUNC rsfsex_actBTSPowerCpl (ViSession instrSession,
                ViBoolean limit_Power_Coupled);
ViStatus _VI_FUNC rsfsex_actGSMModAccuracy (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actGSMBurstLimit (ViSession instrSession,
                ViInt32 burstCheck,
                ViPInt32 measuredValue);
ViStatus _VI_FUNC rsfsex_actGSMSpectrumLimit (ViSession instrSession,
                ViInt32 spectrumMeasMode,
                ViInt32 modulationRange,
                ViPInt32 resultValue,
                ViPInt32 number_ofViolations);
ViStatus _VI_FUNC rsfsex_actGSMSpuriousLimit (ViSession instrSession,
                ViBoolean spuriousResult,
                ViInt32 spuriousParameter,
                ViPInt32 resultValue,
                ViPInt32 number_ofViolations);
ViStatus _VI_FUNC rsfsex_actGSMBurstMeasMode (ViSession instrSession,
                ViInt32 measurementMode);
ViStatus _VI_FUNC rsfsex_actGSMSpectMeasMode (ViSession instrSession,
                ViBoolean measurementMode);
ViStatus _VI_FUNC rsfsex_actGSMSpurMeasMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actRECMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actRECRunScan (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actRECHoldScan (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actRECStopScan (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actRECInitSweep (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actRECContSweep (ViSession instrSession,
                ViInt32 window);
ViStatus _VI_FUNC rsfsex_actCDPMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actWCDPMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actWCDPMSMode (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_actCDPAutoAdj (ViSession instrSession,
                ViInt32 time_out_ms);
ViStatus _VI_FUNC rsfsex_actCDPMarkTo (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 mkrFunction);
ViStatus _VI_FUNC rsfsex_actCDPMarkMeas (ViSession instrSession, ViInt32 window,
                ViInt32 markerNumber, ViInt32 measurement,
                ViReal64 _VI_FAR measurementResult[],
                ViPInt32 measurementResultCount);
ViStatus _VI_FUNC rsfsex_actWCDPMarkMeas (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 measurement,
                ViPReal64 measurementResult);
ViStatus _VI_FUNC rsfsex_actWCDPMSMarkMeas (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViInt32 measurement,
                ViPReal64 measurementResult);
ViStatus _VI_FUNC rsfsex_actCDPMarkCrest (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViPReal64 measurementResult);
ViStatus _VI_FUNC rsfsex_dataReadTrace (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 no_ofPoints,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_dataReadSymbol (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 no_ofPoints,
                ViChar _VI_FAR symbolData[]);
ViStatus _VI_FUNC rsfsex_dataWriteTrace (ViSession instrSession,
                ViInt32 destinationTrace,
                ViInt32 no_ofPoints,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_dataWriteSymbol (ViSession instrSession,
                ViInt32 destinationTrace,
                ViInt32 no_ofPoints, ViString symbolData);
ViStatus _VI_FUNC rsfsex_dataReadTraceIQ (ViSession instrSession,
                ViInt32 bufferSize, ViPInt32 no_ofPoints,
                ViReal64 _VI_FAR realParts_I[],
                ViReal64 _VI_FAR imaginaryParts_Q[],
                ViPReal64 meanSignalPower,
                ViPReal64 peakSignalPower);
ViStatus _VI_FUNC rsfsex_dataReadTraceCdmaOne (ViSession instrSession,
                ViInt32 sourceTrace,
                ViPInt32 no_ofValues,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_dataReadTraceWCDMA (ViSession instrSession,
                ViInt32 sourceTrace,
                ViPInt32 no_ofValues,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_dataReadABIT (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 no_ofValues,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_dataReadTraceWCDP (ViSession instrSession,
                ViInt32 sourceTrace,
                ViPInt32 no_ofValues,
                ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsfsex_dataReadReceiver (ViSession instrSession,
                ViPReal64 firstDetector,
                ViPReal64 secondDetector,
                ViPReal64 thirdDetector,
                ViPReal64 fourthDetector);
ViStatus _VI_FUNC rsfsex_dataReadScan (ViSession instrSession,
                ViPInt32 no_ofPoints,
                ViChar _VI_FAR statusData[],
                ViPInt32 traceStatus,
                ViReal64 _VI_FAR results_ofTrace1[],
                ViReal64 _VI_FAR results_ofTrace2[],
                ViReal64 _VI_FAR results_ofTrace3[],
                ViReal64 _VI_FAR results_ofTrace4[]);
ViStatus _VI_FUNC rsfsex_dataReadStatus (ViSession instrSession,
                ViPInt32 no_ofPoints,
                ViChar _VI_FAR statusData[]);
ViStatus _VI_FUNC rsfsex_dataReadBurst (ViSession instrSession,
                ViBoolean phaseFrequencyError,
                ViBoolean resultType, ViBoolean measResult,
                ViPReal64 measuredValue);
ViStatus _VI_FUNC rsfsex_dataReadBurstStatus (ViSession instrSession,
                ViBoolean phaseFrequencyError,
                ViBoolean resultType,
                ViPInt32 statusValue);
ViStatus _VI_FUNC rsfsex_dataReadBurstMACC (ViSession instrSession,
                ViInt32 MACCMeasurement,
                ViPInt32 status, ViPReal64 average,
                ViPReal64 maximum);
ViStatus _VI_FUNC rsfsex_dataReadBurstRef (ViSession instrSession,
                ViPReal64 referenceLevel);
ViStatus _VI_FUNC rsfsex_dataReadPower (ViSession instrSession,
                ViInt32 powerMeasMode,
                ViPReal64 staticPowerCtrl,
                ViPReal64 dynamicPowerCtrl,
                ViPReal64 ratedLevel, ViPReal64 actLevel,
                ViPReal64 delta, ViPInt32 status);
ViStatus _VI_FUNC rsfsex_dataReadPowerInd (ViSession instrSession,
                ViInt32 powerMeasMode,
                ViReal64 _VI_FAR staticPowerCtrl[],
                ViReal64 _VI_FAR dynamicPowerCtrl[],
                ViReal64 _VI_FAR ratedLevel[],
                ViReal64 _VI_FAR actLevel[],
                ViReal64 _VI_FAR RBW[],
                ViInt32 _VI_FAR ARFCN[],
                ViReal64 _VI_FAR CF[],
                ViReal64 _VI_FAR attenuation[],
                ViInt32 _VI_FAR no_ofBursts[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_dataReadSpectrum (ViSession instrSession,
                ViBoolean spectrumMeasMode,
                ViInt32 _VI_FAR index[],
                ViReal64 _VI_FAR startFrequencies[],
                ViReal64 _VI_FAR stopFrequencies[],
                ViReal64 _VI_FAR levels[],
                ViReal64 _VI_FAR limits[],
                ViInt32 _VI_FAR absRel[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_dataReadSpurious (ViSession instrSession,
                ViInt32 _VI_FAR index[],
                ViReal64 _VI_FAR startFrequencies[],
                ViReal64 _VI_FAR stopFrequencies[],
                ViReal64 _VI_FAR levels[],
                ViReal64 _VI_FAR limits[],
                ViInt32 _VI_FAR absRel[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_dataFetchBurst (ViSession instrSession,
                ViBoolean phaseFrequencyError,
                ViBoolean resultType, ViBoolean measResult,
                ViPReal64 measuredValue);
ViStatus _VI_FUNC rsfsex_dataFetchBurstStatus (ViSession instrSession,
                ViBoolean phaseFrequencyError,
                ViBoolean resultType,
                ViPInt32 statusValue);
ViStatus _VI_FUNC rsfsex_dataFetchBurstMACC (ViSession instrSession,
                ViInt32 MACCMeasurement,
                ViPInt32 status, ViPReal64 average,
                ViPReal64 maximum);
ViStatus _VI_FUNC rsfsex_dataFetchPower (ViSession instrSession,
                ViBoolean resultMode,
                ViReal64 _VI_FAR staticPowerCtrl[],
                ViReal64 _VI_FAR dynamicPowerCtrl[],
                ViReal64 _VI_FAR ratedLevel[],
                ViReal64 _VI_FAR actLevel[],
                ViReal64 _VI_FAR delta[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_dataFetchPowerInd (ViSession instrSession,
                ViBoolean resultMode,
                ViReal64 _VI_FAR staticPowerCtrl[],
                ViReal64 _VI_FAR dynamicPowerCtrl[],
                ViReal64 _VI_FAR ratedLevel[],
                ViReal64 _VI_FAR actLevel[],
                ViReal64 _VI_FAR RBW[],
                ViInt32 _VI_FAR ARFCN[],
                ViReal64 _VI_FAR CF[],
                ViReal64 _VI_FAR attenuation[],
                ViInt32 _VI_FAR no_ofBursts[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_dataFetchSpectrum (ViSession instrSession,
                ViBoolean spectrumMeasMode,
                ViInt32 modulationRange,
                ViInt32 _VI_FAR index[],
                ViReal64 _VI_FAR startFrequencies[],
                ViReal64 _VI_FAR stopFrequencies[],
                ViReal64 _VI_FAR levels[],
                ViReal64 _VI_FAR limits[],
                ViInt32 _VI_FAR absRel[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_dataFetchSpectrumRef (ViSession instrSession,
                ViBoolean spectrumMeasMode,
                ViPReal64 measuredLevel,
                ViPReal64 correctedLevel,
                ViPReal64 bandwidth);
ViStatus _VI_FUNC rsfsex_dataFetchPTemRef (ViSession instrSession,
                ViPReal64 measuredLevel,
                ViPReal64 correctedLevel,
                ViPReal64 bandwidth);
ViStatus _VI_FUNC rsfsex_dataFetchSpurious (ViSession instrSession,
                ViInt32 spuriousParameter,
                ViInt32 _VI_FAR index[],
                ViReal64 _VI_FAR startFrequencies[],
                ViReal64 _VI_FAR stopFrequencies[],
                ViReal64 _VI_FAR levels[],
                ViReal64 _VI_FAR limits[],
                ViInt32 _VI_FAR absRel[],
                ViInt32 _VI_FAR status[],
                ViPInt32 num_ofResults);
ViStatus _VI_FUNC rsfsex_OPTList (ViSession instrSession,
                ViChar _VI_FAR optionsList[],
                ViChar _VI_FAR instrumentVersion[]);
ViStatus _VI_FUNC rsfsex_setPresetCompatibility (ViSession instrSession,
                ViInt32 compatibility);
ViStatus _VI_FUNC rsfsex_firmwareUpdate (ViSession instrSession,
                ViString setDirectory);
ViStatus _VI_FUNC rsfsex_setStatusRegister (ViSession instrSession,
                ViInt32 registerOperation,
                ViInt32 questionableRegister,
                ViInt32 enable, ViInt32 PTransition,
                ViInt32 NTransition);
ViStatus _VI_FUNC rsfsex_getStatusRegister (ViSession instrSession,
                ViInt32 statusRegistersQuery,
                ViPInt32 registerValue);
ViStatus _VI_FUNC rsfsex_errorCheckState (ViSession instrSession,
                ViBoolean state);
ViStatus _VI_FUNC rsfsex_writeInstrData (ViSession instrSession,
                ViString writeBuffer);
ViStatus _VI_FUNC rsfsex_readInstrData (ViSession instrSession,
                ViInt32 numberBytesToRead,
                ViChar _VI_FAR readBuffer[],
                ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsfsex_reset (ViSession instrSession);
ViStatus _VI_FUNC rsfsex_self_test (ViSession instrSession,
                ViPInt32 selfTestResult,
                ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsfsex_error_query (ViSession instrSession,
                ViPInt32 errorCode,
                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsfsex_error_message (ViSession instrSession,
                ViStatus statusCode,
                ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsfsex_revision_query (ViSession instrSession,
                ViChar _VI_FAR instrumentDriverRevision[],
                ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsfsex_close (ViSession instrSession);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
