#include <ansi_c.h>
#include <utility.h>
#include <formatio.h>
#include <stdlib.h>
#include <userint.h>
#include "rsfsex.h"
#include "rsfsexu.h"

/*= Global Variable Definitions =============================================*/
long points = 250000;
int uirCode, trace;
double mkrFreq;
long panelHandle[10];
unsigned long instrHandle;
static double data[250000];
ViStatus uirErr;

/*=================== Utility Function Declarations =========================*/
long abortApplication (void);

/*= Message Arrays ==========================================================*/
static char *initCtrlsHelpStr[] = { "This control specifies the interface and address of the device\n"
                                    "that is to be initialized (Instrument Descriptor). The exact\n"
                                    "grammar to be used in this control is shown in the note below.\n\n"
                                    "Default Value: GPIB::20\n\n"
                                    "Notes:\n\n"
                                    "(1) Based on the Instrument Descriptor, this operation\n"
                                    "establishes a communication session with a device.  The grammar\n"
                                    "for the Instrument Descriptor is shown below.  Optional\n"
                                    "parameters are shown in square brackets ([]).\n\n"
                                    "Interface   Grammar\n"
                                    "------------------------------------------------------\n"
                                    "Serial      ASRL<port>[::INSTR]\n"
                                    "GPIB        GPIB[board]::primary address[::secondary address]\n"
                                    "            [::INSTR]\n"
                                    "RSIB        RSIB::remote_host::INSTR\n\n"
                                    "The ASRL keyword is used for serial interface.\n"
                                    "The GPIB keyword is used for GPIB interface.\n"
                                    "The RSIB keyword is used for RSIB interface.\n\n"
                                    "Examples:\n"
                                    "(1) Serial - ASRL1\n"
                                    "(2) GPIB   - GPIB::20\n"
                                    "(3) RSIB   - RSIB::192.168.1.33::INSTR\n\n"
                                    "The default value for optional parameters are shown below.\n\n"
                                    "Optional Parameter          Default Value\n"
                                    "-----------------------------------------\n"
                                    "board                       0\n"
                                    "secondary address           none - 31\n\n"
                                    "Note:\n\n"
                                    "(1) Parameters of the serial interface, you must set via T&M\n"
                                    "Expolrer before you call initialize function. Default values are\n"
                                    "Baud Rate: 9600, Data Bits: 8, Parity: None, Stop Bits: 1 and\n"
                                    "Flow Control: None",

                                    "This control specifies if an ID Query is sent to the\n"
                                    "instrument during the initialization procedure.\n\n"
                                    "Valid Range:\n"
                                    "0 - Skip Query\n"
                                    "1 - Do Query (Default Value)",
                                    
                                    "This control specifies if the instrument is to be reset to its\n"
                                    "power-on settings during the initialization procedure.\n\n"
                                    "Valid Range:\n"
                                    "0 - Don't Reset\n"
                                    "1 - Reset Device (Default Value)"};  
        
static char *configCtrlsHelpStr[] = {
                                    "This control sets the measurement mode.\n\n"
                                    "Valid Range:\n"
                                    "1 - Continual Measurement (Default Value)\n"
                                    "2 - Single Measurement\n\n"
                                    "Notes:\n\n"
                                    "(1) Continual Measurement:\n"
                                    "Sets the continual sweeping.\n\n"
                                    "(2) Single Measurement:\n"
                                    "Sets the single sweeping and immediately sweeps.",
                                    
                                    "Specifies which parameter will be set.\n\n"
                                    "Valid Range:\n"
                                    "0 - Start And Stop (Default Value)\n"
                                    "1 - Start Only\n"
                                    "2 - Stop Only",
                                    
                                    "This control sets the source trace data\n"
                                    "to be readed from the instrument.\n\n"
                                    "Valid Range:\n"
                                    "0 - Trace 1 (Default Value)\n"
                                    "1 - Trace 2\n"
                                    "2 - Trace 3\n"
                                    "3 - Trace 4\n",

                                    "Sets Y scale of displayed data.\n\n"
                                    "Valid Range:\n"
                                    "0 - Fixed\n"
                                    "1 - Auto (Default Value)",

                                    "Sets the start frequency of the analyzer.\n\n"
                                    "Valid Range: 0.0 to 40.0 GHz\n"
                                    "Default Value: 80.0 MHz",

                                    "Sets the stop frequency of the analyzer.\n\n"
                                    "Valid Range: 0.0 to 40.0 GHz\n"
                                    "Default Value: 110.0 MHz"
                                    };
                                    
static char backgroundPnlHelpStr[] = {"This is a simple demo program using\n"
                                    "the Rohde&Schwarz Spectrum Analyzer FSxx Series\n"
                                    "instrument driver provided in the package.\n"};
                           
static char initPnlHelpStr[] =     {"This panel performs the following initialization actions:\n\n"
                                    "- Opens a instrument session.\n\n"
                                    "- Performs an identification query on the Instrument.\n\n"
                                    "- Sends initialization commands to the instrument that set any\n"
                                    "necessary programmatic variables to the state necessary\n"
                                    "for the operation of the instrument driver."};

static char configPnlHelpStr[] = {"This panel configures the instrument."};

static char measPnlHelpStr[] =   {"This panel displays the measured values.\n"
                                    "Configuration of the instrument is not\n"
                                    "possible with this panel. Press the\n"
                                    "\"Configure\" button to return to\n"
                                    "the configuration panel."};

/*= Main Function ===========================================================*/

void main ()
{
    /* Load panels.*/
    panelHandle[BCKGRND] = LoadPanel (panelHandle[BCKGRND], "rsfsexu.uir", BCKGRND);
    panelHandle[MEAS] = LoadPanel (panelHandle[BCKGRND], "rsfsexu.uir", MEAS);
    panelHandle[CONFIG] = LoadPanel (panelHandle[BCKGRND], "rsfsexu.uir", CONFIG); 
    panelHandle[INIT] = LoadPanel (panelHandle[BCKGRND], "rsfsexu.uir", INIT);
    /* Display panels.*/
    DisplayPanel (panelHandle[BCKGRND]);
    DisplayPanel (panelHandle[INIT]);
    SetSleepPolicy (VAL_SLEEP_MORE);
    /* Initial settings.*/
    SuspendTimerCallbacks ();
    uirCode = RunUserInterface ();
}   

/*===========================================================================*/
/* Function: Initialize Instrument                                           */
/* Purpose:  This is a callback function of the Continue button on the       */
/*           Initialize panel. It initializes the instrument and switches to */
/*           the panel Configure.                                            */
/*===========================================================================*/
int CVICALLBACK initInstrument (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
     
    ViChar instrDescr[256], errorMessage[256], errBuffer[256];
    ViInt16 response, rst, id;

    switch (event) {
        case EVENT_COMMIT:
            SetWaitCursor(0);
            GetCtrlVal (panelHandle[INIT], INIT_ADDRESS, instrDescr);
            GetCtrlVal (panelHandle[INIT], INIT_ID, &id);
            GetCtrlVal (panelHandle[INIT], INIT_RST, &rst);
            SetWaitCursor(1);
            if ((uirErr = rsfsex_init (instrDescr, id, rst, &instrHandle)) < 0 ) {
                rsfsex_error_message(VI_NULL, uirErr, errorMessage);
                Fmt (errBuffer, "%s<Initialization Error:\n\n%s\n\nCheck your "
                        "connections and make sure you have defined right instrument descriptor.",
                         errorMessage);
                MessagePopup ("ERROR!", errBuffer);
                SetWaitCursor(0);
                return(0);   
            }
            /* Set analyzer mode if reset is TRUE for ESI series. */
            if (rst) {
                if ((uirErr = rsfsex_actSAMMode (instrHandle, 1)) < 0) {
                    if (uirErr >= 0xBFFF0000) {
                        abortApplication ();    
                    }
                    else {
                        SetWaitCursor(0);
                        rsfsex_error_message (VI_NULL, uirErr, errorMessage);
                        MessagePopup ("Error", errorMessage);
                        return 0;
                    }   
                }
            }
            SetWaitCursor(0);
            HidePanel (panelHandle[INIT]);
            DisplayPanel (panelHandle[CONFIG]);
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Help","This button causes the instrument to be initialized.");
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Configure Measurement                                           */
/* Purpose:  This is a callback function of the Continue button on the       */
/*           Configure panel (configure & measure).                          */
/*===========================================================================*/
int CVICALLBACK configMeasurement (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    char errMsg[256];
    int cnt, mode, freqParam, range, tmp;
    double startFrq, stopFrq;

    switch (event) {
        case EVENT_COMMIT:
            if (panel == panelHandle[CONFIG]) {
                SetCtrlAttribute (panelHandle[MEAS], MEAS_TEXTMSG, ATTR_VISIBLE, 1);
                SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 0);
                SetWaitCursor(0);
                HidePanel (panelHandle[CONFIG]);
                DisplayPanel (panelHandle[MEAS]);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_MEAS_MODE, &mode);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_FREQ_PARAM, &freqParam);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_TRACE, &trace);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_START, &startFrq);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_STOP, &stopFrq);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_MEAS_RANGE, &range);
                if (range == 0)
                    SetAxisScalingMode (panelHandle[MEAS], MEAS_GRAPH, VAL_LEFT_YAXIS,
                        VAL_MANUAL, -100.0, 0.0);
                else
                    SetAxisScalingMode (panelHandle[MEAS], MEAS_GRAPH, VAL_LEFT_YAXIS,
                        VAL_AUTOSCALE, -1.0, 1.0);
                SetCtrlVal (panelHandle[MEAS], MEAS_LF, startFrq);
                SetCtrlVal (panelHandle[MEAS], MEAS_HF, stopFrq);
                SetWaitCursor(1);
                /* Measurement ranges. */               
                if ((uirErr = rsfsex_appReadSpectrum (instrHandle, mode, freqParam,
                    startFrq*1e6, stopFrq*1e6, trace, &points, data)) < 0) {
                    if (uirErr >= 0xBFFF0000) {
                        abortApplication ();    
                    }
                    else {
                        SetWaitCursor(0);
                        rsfsex_error_message (VI_NULL, uirErr, errMsg);
                        MessagePopup ("Error", errMsg);
                        return 0;
                    }   
                }
                /* Measurement mode. */
                if ((uirErr = rsfsex_appReadSpectrum (instrHandle, 0, freqParam,
                    startFrq*1e6, stopFrq*1e6, trace, &points, data)) < 0) {
                    if (uirErr >= 0xBFFF0000) {
                        abortApplication ();    
                    }
                    else {
                        SetWaitCursor(0);
                        rsfsex_error_message (VI_NULL, uirErr, errMsg);
                        MessagePopup ("Error", errMsg);
                        return 0;
                    }   
                }
                /* Allows to Plot data. */
                SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 1);
                SetWaitCursor(0);
            }
            ResumeTimerCallbacks ();
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Help","This button will configure the instrument to take a measurement.");
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Upload Data                                                     */
/* Purpose:  This is a callback function driven by TIMER EVENTS.             */
/*===========================================================================*/
int  CVICALLBACK uploadData(int panel, int control, int event, void *callbackData,
                int eventData1, int eventData2)
{  
    double speakerVol;
    int mode;
    char errMsg[256];

    switch (event) {
        case EVENT_TIMER_TICK:
            if (panel == panelHandle[MEAS]) {
                SetCtrlAttribute (panelHandle[MEAS], MEAS_TEXTMSG, ATTR_VISIBLE, 1);
                /* Refresh data trace. */
                if ((uirErr = rsfsex_appReadSpectrum (instrHandle, 3, 0, 0.0,
                    1.0, trace, &points, data)) < 0) {
                    if (uirErr >= 0xBFFF0000) {
                        abortApplication ();    
                    }
                    else {
                        SetWaitCursor(0);
                        rsfsex_error_message (VI_NULL, uirErr, errMsg);
                        MessagePopup ("Error", errMsg);
                        return 0;
                    }
                }
                DeleteGraphPlot (panelHandle[MEAS], MEAS_GRAPH, -1, VAL_DELAYED_DRAW);
                PlotWaveform (panelHandle[MEAS], MEAS_GRAPH, data, points, VAL_DOUBLE,
                    1.0, 0.0, 0.0, 1.0, VAL_THIN_LINE, VAL_SIMPLE_DOT, VAL_SOLID, 1,
                    VAL_YELLOW);

                if (GetActivePanel () == panelHandle[CONFIG])
                    SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 0);
                GetCtrlVal (panelHandle[CONFIG], CONFIG_MEAS_MODE, &mode);
                if (mode == 2)
                    SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 0);
                SetCtrlAttribute (panelHandle[MEAS], MEAS_TEXTMSG, ATTR_VISIBLE, 0);
            }
        break;
    }
    
    return 0;
}

/*===========================================================================*/
/* Function: Cancel                                                          */
/* Purpose:  Called by the init panel this function pops up a confirmation   */
/*           dialog box and then quits the user interface, if desired.       */
/*===========================================================================*/
int CVICALLBACK Cancel (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    SetWaitCursor(0);
    switch (event) {
        case EVENT_COMMIT:
            SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 0);
            if ((ConfirmPopup ("Exit Application", 
                   "Are you sure you want to quit this application?")) == 1) {
                QuitUserInterface (uirCode);
            }
            SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 1);
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Control Help", "Closes the application.");
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Control Help                                                    */
/* Purpose:  This is a callback function of all controls that configure the  */
/*           instrument. On the right mouse-click on the control a help      */
/*           window describing its purpose is displayed.                     */
/*===========================================================================*/
int CVICALLBACK controlHelp (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{   
    SetWaitCursor(0);
    if (event == EVENT_RIGHT_CLICK) {
        SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 0);
        if (panel == panelHandle[INIT]) 
            MessagePopup ("Help", initCtrlsHelpStr[control-4]);
        if (panel == panelHandle[CONFIG]) 
            MessagePopup ("Help", configCtrlsHelpStr[control-4]);
        SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 1);
    }

    return 0;
}

/*===========================================================================*/
/* Function: Launch Configure Panel                                          */
/* Purpose:  This is a callback function of the button Configure on the      */
/*           panel Measure. It returns back to the Configuration panel to be */
/*           able to change configuration without having to re-run this      */
/*           program.                                                        */
/*===========================================================================*/
int CVICALLBACK launchConfig (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    SetWaitCursor(0);
    switch (event) {
        case EVENT_COMMIT:
            HidePanel (panelHandle[MEAS]);
            DisplayPanel (panelHandle[CONFIG]);
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Help","This button will recall the configuration panel.");
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Panel Help                                                      */
/* Purpose:  This is a callback function of the menu bar. It displays a help */
/*           window describing panel being used.                             */
/*===========================================================================*/
void CVICALLBACK panelHelp (int menuBar, int menuItem, void *callbackData,
        int panel)
{
    SetWaitCursor(0);
    if (panel == panelHandle[BCKGRND])
        MessagePopup ("Help", backgroundPnlHelpStr);
    if (panel == panelHandle[INIT])
        MessagePopup ("Help", initPnlHelpStr);
    if (panel == panelHandle[CONFIG])
        MessagePopup ("Help", configPnlHelpStr);
    if (panel == panelHandle[MEAS]) {
        MessagePopup ("Help", measPnlHelpStr);
    }    
    return;
}

/*===========================================================================*/
/* Function: Launch Close Panel                                              */
/* Purpose:  This is a callback function of the button Close on the          */
/*           panel Measure. It pops-up a panel that will close the           */
/*           instrument.                                                     */
/*===========================================================================*/
int CVICALLBACK launchClose (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    ViChar errorMessage[256], errBuffer[256];
    ViInt16 response;
    
    SetWaitCursor(0);
    switch (event) {
        case EVENT_COMMIT:
            SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 0);
            if ((ConfirmPopup ("Exit Application", "Are you sure you want to quit "
                    "this application?")) == 1) {
                if ((uirErr = rsfsex_close (instrHandle)) < 0) {
                    rsfsex_error_message(VI_NULL, uirErr, errorMessage);
                    Fmt (errBuffer, "%s<Application failed to close the "
                        "instrument.\n\n%s\n\nExiting Application.", errorMessage);
                    MessagePopup("ERROR!", errBuffer);
                }
                QuitUserInterface (uirCode);
                exit (-1);
            }
            SetCtrlAttribute (panelHandle[MEAS], MEAS_TIMER, ATTR_ENABLED, 1);
            break;
        case EVENT_RIGHT_CLICK:
            MessagePopup ("Help","This button will pop-up a panel to close the instrument.");
            break;
    }
    return 0;
}   

/*****************************************************************************/
long abortApplication (void)
{
    ViChar errorMessage[256], errBuffer[256];
    ViInt16 response;

    SetWaitCursor (0);
    rsfsex_error_message(VI_NULL, uirErr, errorMessage);
    Fmt (errBuffer,"%s<The following error caused the application to fail:\n\n%s\n\n"
        "Attempting to Close Instrument Driver and Exit Application", 
        errorMessage);
    MessagePopup("ERROR!, Application Failed", errBuffer);
    
    if ((uirErr = rsfsex_close (instrHandle)) < 0) {
        rsfsex_error_message(VI_NULL, uirErr, errorMessage);
        Fmt (errBuffer, "%s<Application failed to close the Instrument Driver.\n\n"
            "%s\n\nExiting Application.", errorMessage);
        MessagePopup("ERROR!",errBuffer);
    }
    else 
        MessagePopup("Application Aborted","Instrument Driver Closed, Exiting Application.");
        
    QuitUserInterface (uirCode);
    exit (-1);
    
    return 0;
}

/*= End =====================================================================*/
