/*= Rohde & Schwarz FSEx Spectrum Analyzer (VISA) ===========================*/
/* LabWindows/CVI 6.0 Instrument Driver                                      */
/* Original Release: January 2000                                            */
/* By: Martin Koutny                                                         */
/*                                                                           */
/* Should you have any technical questions please contact the hotline of     */
/* Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center             */
/*                                                                           */
/* e-mail: CustomerSupport@rsd.rohde-schwarz.com                             */
/*                                                                           */
/* Modification History:                                                     */
/*                                                                           */
/* 31. Rev 3.6.7 09/2007, CVI 8.0 by Jiri Kominek                            */
/*      - Fixed DLL - added missing function exports and type library        */
/*                                                                           */
/* 30. Rev 3.6.6 06/2006, CVI 7.0 by Werner Klotzsche                        */
/*      - Fixed for NT Software for NI Max  4.x                              */
/*        - not possible to set GPIB Repeat Addressing off                    */
/*        - not possible for Agilent VISA ( Attribut is missing)             */ 
/*                                                                           */   
/* 29. Rev 3.6.5 04/2005, CVI 7.0 by Martin Krcmar                           */
/*      - Code maitenance:                                                   */
/*       - I/O conversion specification fixed:                               */
/*          Input: "%le" for ViReal64, "%ld" for ViInt32, "%hu" for          */
/*                 ViBoolean                                                 */
/*          Output: "%.12f" for ViReal64, "%ld" for ViInt32, "%hu" for       */
/*                  ViBoolean                                                */
/*       - System locale are set to default "C"                              */
/*                                                                           */
/* 28. Rev 3.6.4 01/2004, CVI 7.0 by Jiri Kominek                            */
/*      Fixed function rsfsex_actSAMCPSet, missing adjust parameter          */
/*                                                                           */
/* 27. Rev 3.6.3 06/2003, CVI 6.0 by Martin Koutny                           */
/*      Drawback of Agilent VISA is patched by adding extra termination      */
/*        character "\n" to each command                                     */
/*                                                                           */
/* 26. Rev 3.6.2, 04/2003, CVI 6.0 by Martin Koutny                          */
/*      - documentation improvements                                         */
/*                                                                           */
/* 25. Rev 3.6.1, 02/2003, CVI 6.0 by JK                                     */
/*      - Fixed for use in earlier versions of VISA without TCPIP support    */
/*                                                                           */
/* 24. Rev 3.6, 01/2003, CVI 6.0 by MK                                       */
/*      - Included support for RSIB interface                                */
/*      - Read Trace I/Q Data (rsfsex_dataReadTraceIQ) is improved           */
/*      - Code cleanup - removed unreferenced variables                      */
/*                                                                           */
/* 23. Rev 3.5, 03/2002, CVI 6.0 by MK                                       */
/*      - Driver update                                                      */
/*          Added support for latest versions of firmware and for new        */
/*          options FSE-K30, FSE-K31 and FSIQ-K73.                           */
/*          - Changed functions:                                             */
/*              Channel Power Standard (confSAMMarkChPowChanStandard)        */
/*              BTS Power Settings (confBTSPower)                            */
/*              MS Power Settings (confMSPower)                              */
/*              GSM Spectrum Mod Range (confGSMModRange)                     */
/*              Configure WCDPower Measurement (confWCDPMeas)                */
/*              WCDP Measurement Mode (confWCDPMeasMode)                     */
/*              CDP Set to Standard (confCDPSetStd)                          */
/*              CDP Inactive Channel Treshold (confCDPICT)                   */
/*              CDP Side Band (confCDPSBand)                                 */
/*              CDP Fast Mode (confCDPFastMode)                              */
/*              CDP Spreading Factor (confCDPSFactor)                        */
/*              CDP Code Number (confCDPCodeNum)                             */
/*              CDP CPICH Slot (confCDPSlot)                                 */
/*              CDP Scrambling Code (confCDPLCode)                           */
/*              CDP Normalize (confCDPNormalize)                             */
/*              Memory Select Items (actMemSel)                              */
/*              BTS Set ARFCN (actBTSARFCN)                                  */
/*              MS Set ARFCN (actMSARFCN)                                    */
/*              BTS Default Settings (actBTSNetwork)                         */
/*              MS Default Settings (actMSNetwork)                           */
/*              Get Burst Limit Check (actGSMBurstLimit)                     */
/*              CDP Level Auto Adjust (actCDPAutoAdj)                        */
/*              CDP Marker To (actCDPMarkTo)                                 */
/*              Get CDP Crest Factor (actCDPMarkCrest)                       */
/*              Read WCDMA Trace Data (dataReadTraceWCDMA)                   */
/*              Read ABIT Stream Data (dataReadABIT)                         */
/*              Read Burst Power (dataReadPower)                             */
/*              Fetch Burst Power (dataFetchPower)                           */
/*          - New Functions:                                                 */
/*              Trace Averaging Method (confTraceAveMethod)                  */
/*              Trace ASCII Comment (confTraceComment)                       */
/*              Modulation Summary Units (confVSAMSumSetUnits)               */
/*              GSM Burst Phase Freq Condition (confGSMPFerCond)             */
/*              Configure WCDPower MS Meas (confWCDPMSMeas)                  */
/*              CDP Preference (confCDPPref)                                 */
/*              CDP Sync Type (confCDPSyncType)                              */
/*              CDP Signal Mapping (confCDPSigMap)                           */
/*              CDP Antenna Type (confCDPAntennaType)                        */
/*              WCDP Channel Table Name (confWCDPChTableName)                */
/*              WCDP Channel Table Copy (confWCDPChTableCopy)                */
/*              WCDP Channel Table Delete (confWCDPChTableDelete)            */
/*              WCDP Channel Table Restore (confWCDPChTableRestore)          */
/*              WCDP Channel Table Comment (confWCDPChTableComment)          */
/*              WCDP Channel Table Data (confWCDPChTableData)                */
/*              WCDP Channel Table Catalog (confWCDPChTableCatalog)          */
/*              WCDP MS Channel Table (confWCDPMSChTable)                    */
/*              WCDP MS Channel Table File (confWCDPMSChTableFile)           */
/*              WCDP MS Channel Table Name (confWCDPMSChTableName)           */
/*              WCDP MS Channel Table Copy (confWCDPMSChTableCopy)           */
/*              WCDP MS Channel Table Delete (confWCDPMSChTableDelete)       */
/*              WCDP MS Channel Table Comment (confWCDPMSChTableComment)     */
/*              WCDP MS Channel Table Data (confWCDPMSChTableData)           */
/*              WCDP MS Channel Table Catalog (confWCDPMSChTableCatalog)     */
/*              Stat Measurement Samples (confStatMeasSamples)               */
/*              Stat Measurement Scaling (confStatMeasScal)                  */
/*              Stat Percent Marker (confStatPercentMkr)                     */
/*              SEM Limit Line (confSEMLimitLine)                            */
/*              Get Activated Limit Lines (actLimitLinesAct)                 */
/*              WCDPower Mode (actWCDPMSMode)                                */
/*              Get WCDP MS Measurement (actWCDPMSMarkMeas)                  */
/*              Read WCDP Trace Data (dataReadTraceWCDP)                     */
/*              Read Burst Status Values (dataReadBurstStatus)               */
/*              Read Burst Power Individual (dataReadPowerInd)               */
/*              Fetch Burst Status Values (dataFetchBurstStatus)             */
/*              Fetch Burst Power Individual (dataFetchPowerInd)             */
/*              Fetch Spectrum Reference (dataFetchSpectrumRef)              */
/*              Fetch PTemplate Reference (dataFetchPTemRef)                 */
/*              Firmware Update (firmwareUpdate)                             */
/*                                                                           */
/* 22. Rev 3.44, 09/2001, CVI 5.5.1. by ZR                                   */
/*      - fixed rsfsex_confWCDPChTableFile                                   */
/*                                                                           */
/* 21. Rev 3.43, 07/2001, CVI 5.5.1, by ZR                                   */
/*      - fixed function rsfsex_dataReadTraceIQ (added overload error)       */
/*                                                                           */
/* 20. Rev 3.42, 06/2001, CVI 5.5.1, by ZR                                   */
/*      - fixed function rsfsex_confLimitLineParam                           */
/*                                                                           */
/* 19. Rev 3.41, 06/2001, CVI 5.5.1, by MK                                   */
/*      - Driver update - new functions                                      */
/*          Get WCDP Measurement (actWCDPMarkMeas)                           */
/*          WCDP Channel Table (confWCDPChTable)                             */
/*          WCDP Channel Table File (confWCDPChTableFile)                    */
/*          CDP Normalize (confCDPNormalize)                                 */
/*          CDP Q Invert (confCDPQInvert)                                    */
/*          Read ABIT Stream Data (dataReadABIT)                             */
/*                                                                           */
/* 18. Rev 3.4, 03/2001, CVI 5.5.1, by MK                                    */
/*      - Driver update                                                      */
/*          Added support for latest versions of firmware and for new options*/
/*          FSE-B13, FSE-K20, FSE-K21, FSIQ-B70, FSIQ-K71, and FSIQ-K72.     */
/*          - C code was improved according the ANSI C standards.            */
/*          - Multiplatform support was added.                               */
/*          - Changed functions:                                             */
/*              Channel Power Standard (confSAMMarkChPowChanStandard)        */
/*              Setup Transducer Def (confTransducerDef)                     */
/*              Setup Transducer Set Def (confTransducerSetDef)              */
/*              Reference Level Opt (confRefLevelOpt)                        */
/*              Digital Demod Parameters (confVSAMDigiDemodParam)            */
/*              Digital Standard (confVSAMDigiSTD)                           */
/*              Adjust Channel Power Settings (actSAMCPSet)                  */
/*              Function Trigger (confTrg)                                   */
/*              Digital Demod Parameters (confVSAMDigiDemodParam)            */
/*              Function External Mixer Band Lock Off (confExtMixBLOff)      */
/*              Memory Operations (actMemOp)                                 */
/*              Digital Sync Sequence (confVSAMDigiSeq)                      */
/*              Digital Sync Sequence Sel (confVSAMDigiSeqSel)               */
/*              GSM Set Ext Attenuator (confGSMExtAttn)                      */
/*              GSM Spurious Range (confGSMSpurRange)                        */
/*              Resolution BW (confResbw)                                    */
/*              GSM Number of Bursts (confGSMNoCnt)                          */
/*              Mixer Band Lock On (confExtMixBLOn)                          */
/*          - New Functions:                                                 */
/*              Default Conversion Loss (confDefConvLoss)                    */
/*              RF Input Attenuator Stepsize (confRFInAttStep)               */
/*              Display Screen Saver (confDisplaySave)                       */
/*              Base Line Clipping (confBaseLine)                            */
/*              Auto Adjust Channel Power Settings (actSAMCPAdjust)          */
/*              Trace ASCII Append (confTraceExp)                            */
/*              Trace ASCII Decimal Separator (confTraceDSep)                */
/*              Trace ASCII Header (confTraceHeader)                         */
/*              Digital Sync Sequence Catalog (confVSAMDigiSeqCat)           */
/*              Digital Sync Sequence Meas Only (confVSAMDigiSeqMOnly)       */
/*              Limit Lines Catalog (confLimitLineCat)                       */
/*              Conversion Loss Table Catalog (confExtMixLossTabCat)         */
/*              Get Active Transducer (confTransducerGet)                    */
/*              Get Transducer Catalog (confTransducerCat)                   */
/*              Read Trace I/Q Data (dataReadTraceIQ)                        */
/*              Trace I/Q Set (confTraceIQ)                                  */
/*              Trace I/Q State (confTraceIQState)                           */
/*              CDP Measurement Mode (confCDPMeasMode)                       */
/*              Read CdmaOne Trace Data (dataReadTraceCdmaOne)               */
/*              CDP Marker To (actCDPMarkTo)                                 */
/*              Get CDP Measurement (actCDPMarkMeas)                         */
/*              Get CDP Crest Factor (actCDPMarkCrest)                       */
/*              CDPower Measurement (confCDPMeas)                            */
/*              CDPower Mode (actCDPMode)                                    */
/*              CDP Set to Standard (confCDPSetStd)                          */
/*              CDP PN-Offset (Chips) (confCDPPNOffset)                      */
/*              CDP Inactive Channel Treshold (confCDPICT)                   */
/*              CDP Side Band (confCDPSBand)                                 */
/*              CDP Meas Period (confCDPMeasPeriod)                          */
/*              CDP Fast Mode (confCDPFastMode)                              */
/*              CDP Input Channel (confCDPInpChan)                           */
/*              CDP Level Auto Adjust (actCDPAutoAdj)                        */
/*              CDP Total Power Nominal (confCDPNomPwr)                      */
/*              CDP Limits Standard (confCDPLimStd)                          */
/*              CDP User Limits (confCDPUsrLimits)                           */
/*              CDP Limit Checking (confCDPLimCheck)                         */
/*              CDP Measurement Mode (confCDPMeasMode)                       */
/*              Read WCDMA Trace Data (dataReadTraceWCDMA)                   */
/*              Configure WCDPower Measurement (confWCDPMeas):               */
/*              WCDPower Mode (actWCDPMode)                                  */
/*              CDP Spreading Factor (confCDPSFactor)                        */
/*              CDP Code Number (confCDPCodeNum)                             */
/*              CDP CPICH Slot (confCDPSlot)                                 */
/*              CDP Scrambling Code (confCDPLCode)                           */
/*              GSM Burst Reference (confGSMBurstRef)                        */
/*              GSM Burst Reference Meas (dataReadBurstRef)                  */
/*              MS Single Measurement (actMSSingleMeas)                      */
/*              BTS Single Measurement (actBTSSingleMeas)                    */
/*              MS Clear Single Result (actMSClrSingleRes)                   */
/*              BTS Clear Single Result (actBTSClrSingleRes)                 */
/*              MS Limit (Power) Coupled (actMSPowerCpl)                     */
/*              BTS Limit (Power) Coupled (actBTSPowerCpl)                   */
/*              MS Limit Line Ref Power (confMSPowerLline)                   */
/*              BTS Limit Line Ref Power (confBTSPowerLline)                 */
/*              MS Sweeptime (confMSSweeptime)                               */
/*              BTS Sweeptime (confBTSSweeptime)                             */
/*              MS SHF (confMSSHF)                                           */
/*              MS Small (confMSSmall)                                       */
/*              GSM Spurious Emissions (confGSMSpurEmi)                      */
/*              GSM Set Spurious Step (confGSMSpurStep)                      */
/*              GSM TX Gate (confGSMTXGate)                                  */
/*              BTS Station Type (confBTSStationType)                        */
/*              MS Modulation Type (confMSModType)                           */
/*              BTS Modulation Type (confBTSModType)                         */
/*              GSM Modulation Accuracy (actGSMModAccuracy)                  */
/*              GSM Conditions (confGSMCondition)                            */
/*              MS Error Limits (confMSErrLim)                               */
/*              MS User Limits (confMSErrLimUser)                            */
/*              BTS Error Limits (confBTSErrLim)                             */
/*              BTS User Limits (confBTSErrLimUser)                          */
/*              Fetch Burst MACC Values (dataFetchBurstMACC)                 */
/*              Read Burst MACC Values (dataReadBurstMACC)                   */
/*              Set Preset Compatibility (setPresetCompatibility)            */
/*                                                                           */
/* 17. Rev 3.3, 10/2000, CVI 5.0.1, by Martin Koutny                         */
/*      - Driver maintenance - functionality not changed                     */
/*                                                                           */
/* 16. Rev 3.2, 05/2000, CVI 5.0.1, by Martin Koutny                         */
/*      - Driver recognizes FSIG 3 and FSIG 13                               */
/*                                                                           */
/* 15. Rev 3.1, 03/2000, CVI 5.0.1, by Martin Koutny                         */
/*      - Added RS-232 support                                               */
/*                                                                           */
/* 14. Rev 3.0, 01/2000, CVI 5.0.1, by Martin Koutny                         */
/*      - Added support for ESIB series                                       */
/*                                                                           */
/* 13. Rev 2.7, 08/1999, CVI 5.0.1, by Martin Koutny                         */
/*      - Last corrections for release version                               */
/*                                                                           */
/* 12. Rev 2.6, 08/1999, CVI 5.0.1, by Martin Koutny                         */
/*      - New function for status checking added - rsfsex_checkBeforeRead    */
/*      - All ViPChar types replaced by ViInt32 []types                      */
/*      - Made changes on instrument manufacturer's request                  */
/*                                                                           */
/* 11. Rev 2.59, 07/1999, CVI 5.0.1, by Martin Koutny                        */
/*      - Adds support for FSIQ models                                       */
/*                                                                           */
/* 10. Rev 2.58, 07/1999, CVI 5.0.1, by Martin Koutny                        */
/*      - change utility function names according VXI-PNP standard           */
/*        requirements                                                       */
/*      - made changes on instrument manufacturer's request                  */
/*                                                                           */
/*  9. Rev 2.57, 07/1999, CVI 5.0.1, by Martin Koutny                        */
/*                                                                           */
/*  8. Rev 2.56, 06/1999, CVI 5.0.1, by Martin Koutny                        */
/*      - changes in c, h, and fp files. Supports instrument firmware        */
/*        version "1.71".                                                    */
/*                                                                           */
/*  7. Rev 2.55, 05/1999, CVI 5.0.1, by Martin Koutny                        */
/*                                                                           */
/*  6. Rev 2.5, 05/1999, CVI 5.0.1, by Martin Koutny                         */
/*      - new function actSendTrgWopc, function rsfsex_actTrg renamed to     */
/*        rsfsex_confTrg                                                     */
/*                                                                           */
/*  5. Rev 2.45, 05/1999, CVI 5.0.1, by Martin Koutny                        */
/*      - additional window parameter -> confSpanCenterFrq,                  */
/*        rsfsex_confStartStopFrq, help for rsfsex_confScreenCpl changed.    */
/*                                                                           */
/*  4. Rev 2.4, 05/1999, CVI 5.0.1, by Martin Koutny                         */
/*      - General device settings related functions renamed to accept their  */
/*        position.                                                          */
/*                                                                           */
/*  3. Rev 2.3, 05/1999, CVI 5.0.1, by Martin Koutny                         */
/*      - Function tree changes                                              */
/*      - FP file changes - comments                                         */
/*                                                                           */
/*  2. Rev 2.2, 04/1999, CVI 5.0.1, by Martin Koutny                         */
/*      - driver debugging                                                   */
/*      - function tree:                                                     */
/*          order of functions changed                                       */
/*          some of functions renamed                                        */
/*      - new functions:                                                     */
/*          Adjust Channel Power Settings                                    */
/*          Limit Lines Parameters                                           */
/*          Set Limit Lines Offset                                           */
/*                                                                           */
/*  1. Rev 2.0, 03/1999, CVI 5.0.1, by Michal Harhaj                         */
/*      - driver completely rewritten (on instrument manufacturer's request) */
/*                                                                           */
/*===========================================================================*/

/*= INCLUDES ================================================================*/
#include <string.h>
#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <time.h>
#include <visa.h>
#include <locale.h> 
#include "rsfsex.h"

/*= DEFINES =================================================================*/
#define RSFSEX_REVISION     "Rev 3.6.7, 09/2007, CVI 7.0" /* Instrument driver revision */
#define BUFFER_SIZE         2048L                       /* File I/O buffer size */
#define BUFFER_SIZE_MEDIUM  4096L                       /* K10, K11 buffer size */
#define DATA_BUFFER_SIZE    126000L                     /* Data buffer size */
#define SCAN_BUFFER_SIZE    1500000L                    /* Scan data buffer size */

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS =====================================*/
/*****************************************************************************/
static ViString switchArr[] = {"OFF","ON"};
static ViString optionsList[] = {"FSE-B2","FSE-B3","FSE-B4","FSE-B5","FSE-B7",
                                 "FSE-B8","FSE-B9","FSE-B10","FSE-B11","FSE-B12",
                                 "FSE-B15","FSE-B16","FSE-B17","FSE-B18","FSE-B19",
                                 "FSE-B21","FSE-B22","FSE-B23","ESI-B1","FSE-B13",
                                 "FSE-K10","FSE-K11","FSE-K12","FSE-K20","FSE-K21",
                                 "FSIQB70","FSIQK71","FSIQK72","FSIQK73",VI_NULL};
static ViString instrVersionList[] = {"FSEA 20","FSEA 30","FSEB 20","FSEB 30",
                                 "FSEM 20","FSEM 21","FSEM 30","FSEM 31","FSEK 20",
                                 "FSEK 21","FSEK 30","FSEK 31","FSIQ 3","FSIQ 7",
                                 "FSIQ 26","ESI 7","ESI 26","ESI 40","FSE? 7",
                                 "FSE? 22","FSIG 3","FSIG 13","FSIQ 40","UNKNOWN",VI_NULL};
static ViString freqParameterArr[] = {"CENTER","SPAN","START","STOP"};
static ViString unitRefLevelArr[] = {"DBM","DBUV","DBUA","DBPW","VOLT","AMP","WATT",
                                     "DBMV","","DB","PCT","UNITLESS","DBUV_MHZ",
                                     "DBMV_MHZ","DBUA_MHZ","DBUV_MMHZ","DBUA_MMHZ"};
static ViString ySpaceArr[] = {"LOG","LIN","PERC"};
static ViString inpAttAutoModeArr[] = {"NORM","LNO","LDIS"};
static ViString mixBandArr[] = {"A","Q","U","V","E","W","F","D","G","Y","J"};
static ViString mixParityArr[] = {"EVEN","ODD","EODD"};
static ViString mixSigIDArr[] = {"OFF","ON","AUTO"};
static ViString counterResArr[] = {"0.1","1","10","100","1000","10000"};
static ViString chanPowTypeArr[] = {"CPOW","CN","CN0","ACP","OBW"};
static ViString ACPStandardArr[] = {"NONE","NADC","TETRA","PDC","PHS","CDPD","F8CD",
                                    "R8CD","F19C","R19C","FWCD","RWCD","FW3G",
                                    "RW3G","M2CD","D2CD","FO8C","RO8C","FO19CDMA",
                                    "RO19CDMA","TCDM"};
static ViString summMkrArr[] = {"RMS","MEAN","MAX","PPE","MPE","MIDD","PHOL","AVER","AOFF"};
static ViString mkrFunctionArr[] = {"CENT","CST","STAR","STOP","MST","REF","TRAC"};
static ViString mkrPosArr[] = {"MAX:PEAK","MAX:NEXT","MAX:LEFT","MAX:RIGH","MIN:PEAK",
                               "MIN:NEXT","MIN:LEFT","MIN:RIGH","MAX:APE"};
static ViString lineTypeArr[] = {"DLIN","FLIN","RLIN","THR","TLIN"};
static ViString unitArr[] = {"DBM","DBPW","WATT","DBUV","VOLT","DBUA","AMP","DB",
                             "DBUV_MHZ","DBUA_MHZ","DEG","RAD","S","HZ","PCT",
                             "UNITLESS"};
static ViString domainArr[] = {"FREQ","TIME"};
static ViString AMFMDeemphValArr[] = {"50E-6","75E-6","75E-5"};
static ViString modeArr[] = {"REL","ABS"};
static ViString ctrlUnitArr[] = {"S","SYM"};
static ViString traceModeArr[] = {"MODE WRIT","MODE VIEW","MODE AVER","STAT OFF",
                               "MODE MAXH","MODE MINH","MODE:HCON ON","MODE:HCON OFF",
                               "MODE:ANAL ON","MODE:ANAL OFF","MODE:HCON ON",
                               "MODE:HCON OFF"};
static ViString traceNamesArr[] = {"TRACE1","TRACE2","TRACE3","TRACE4"};
static ViString traceDetectorArr[] = {":AUTO ON",":AUTO OFF"," APE"," NEG",
                                      " POS"," SAMP"," RMS"," AVER"," QPE", " ACV"};
static ViString resModeArr[] = {" ANALOG"," DIGITAL",":FFT ON",":FFT OFF"};
static ViString bandwidthPLLArr[] = {"AUTO","HIGH","MED","LOW"};
static ViString gateModeArr[] = {"EDGE","LEV"};
static ViString gatePolarityArr[] = {"NEG","POS"};
static ViString gateSourceArr[] = {"RFP","EXT"};
static ViString displayFormatArr[] = {":DISP:FORM SINGLE",":DISP:FORM SPLIT"};
static ViString predefinedColorsArr[] = {"BLAC","BLUE","BROW","GRE","CYAN",
                                         "RED","MAG","YELL","WHIT","DGRAY","LGRAY",
                                         "LBLUE","LGREEN","LCY","LRED","LMAG"};
static ViString vectorModeArr[] = {"ADEM","DDEM"};
static ViString trdScalingArr[] = {"LOG","LIN"};
static ViString trdUnitArr[] = {"DB","DBM","DBMV","DBUV","DBUV/M","DBUA","DBUA/M","DBPW","DBPT"};
static ViString refSourceArr[] = {"INT","EXT"};
static ViString destinationArr[] = {"SYST:COMM:GPIB","SYST:COMM:SER1","SYST:COMM:SER2",
                                    "SYST:COMM:CENT","MMEM"};
static ViString dataFormatArr[] = {"HPGL","HPGL_LS","HP7470","HP7470LS","DESKJ","DESKJ_C",
                                   "DESKJ_C3","EPSON24","EPSON24C","PCL4","PCL4_C",
                                   "PCL4_C3","PCL5","LASERJ","POST","ESCP","WMF","PCX"};
static ViString destinationNTArr[] = {"MMEM","SYST:COMM:PRIN","SYST:COMM:CLIP"};
static ViString dataFormatNTArr[] = {"WMF","GDI","EWMF","BMP"};
static ViString digiSTDArr[] = {"GSM","TETRA","FNADC","RNADC","DCS1800","PCS1900","PHS",
                                "PDCUP","PDCDOWN","APCO25CQPSK","APCO25C4FM","CDPD","DECT",
                                "CT2","ERMES","MODACOM","PWT","TFTS","F16","F322","F324",
                                "F64","FQCDMA","RQCDMA","FWCDMA","RWCDMA","EDGE","FW3G",
                                "RW3G","CDMA2000"};
static ViString digitModArr[] = {":DDEM:FORM PSK;PSK:NST 2;FORM NORM",":DDEM:FORM QPSK;QPSK:FORM NORM",
                                ":DDEM:FORM QPSK;QPSK:FORM DIFF",":DDEM:FORM QPSK;QPSK:FORM DPI4",
                                ":DDEM:FORM QPSK;QPSK:FORM OFFS",":DDEM:FORM PSK;PSK:NST 8;FORM NORM",
                                ":DDEM:FORM PSK;PSK:NST 8;FORM DIFF",":DDEM:FORM MSK;MSK:FORM NORM",
                                ":DDEM:FORM MSK;MSK:FORM DIFF",":DDEM:FORM FSK;FSK:NST 2",
                                ":DDEM:FORM FSK;FSK:NST 4",":DDEM:FORM QAM;QAM:NST 16",
                                ":DDEM:FORM PSK;PSK:NST 8;FORM N3P"};
static ViString measFilterArr[] = {"OFF","RCOS","RRC","GAUS","B22","B25","B44","QFM",
                                   "QFR","QRM","QRR","A25F","EMES","EREF","FM95","FR95",
                                   "RM95","RR95"};
static ViString refFilterArr[] = {"RCOS","RRC","GAUS","B22","B25","B44","QFM",
                                   "QFR","QRM","QRR","A25F","EMES","EREF","FM95","FR95",
                                   "RM95","RR95"};
static ViString sideBandArr[] = {"NORM","INV"};
static ViString formArr[] = {"MAGN","PHAS","UPH","RIM","FREQ","IEYE","QEYE",
                             "TEYE","COMP","CONS", "FEYE"};
static ViString deemphasisLinkArr[] = {"AUD","DISP"};
static ViString AFCouplingArr[] = {"DC","AC"};
static ViString analogMeasResArr[] = {"TCAP","XTIM:DDEM:MEAS","XTIM:DDEM:REF",
                                      "XTIM:DDEM:ERR:MPH", "XTIM:DDEM:ERR:VECT",
                                      "XTIM:DDEM:SYMB","XTIM:AM","XTIM:FM",
                                      "XTIM:PM","XTIM:AMSummary","XTIM:FMSummary",
                                      "XTIM:PMSummary"};
static ViString measTimeArr[] = {"0.1","1.0"};
static ViString setSrcValueArr[] = {"POW:OFFS","POW","FREQ:OFFS"};
static ViString verticalSyncArr[] = {"ALL","EVEN","ODD"};
static ViString lineSystemArr[] = {"525","625"};
static ViString BTSPowerArr[] = {"CLAS","CLAS","CLAS","CLAS","STAT","DYN","EXP"};
static ViString spurParamArr[] = {"TXB","OTXB","RXB","IDL","COMB"};
static ViString PWRMeasConditonArr[] = {"NORM","EXTR"};
static ViString modRangeArr[] = {"ARFC","TXB","RXB","COMB","DCSR","G8RX","PCSR"};
static ViString syncToMidambleArr[] = {"FRAM","TSC"};
static ViString channelPowArr[] = {"ACP","CPOW","OBAN","CN","CN0","ADJ"};
static ViString spectrumMeasModeArr[] = {"MOD","MOD:FAIL","MOD:EXC","SWIT","SWIT:FAIL"};
static ViString limitSpurParamArr[] = {"TXB","OTXB","RXB","IDL"};
static ViString triggerArr[] = {"IMM","LINE","VID","","EXT","","RFP","AF", ""};
static ViString calTypeArr[] = {"ALL","BAND","LDET","SHOR","IQ","LOS","PPE","PRES"};
static ViString inputSrcArr[] = {"RF","CAL"};
static ViString operationMemArr[] = {"CDIR ","COPY ","DEL ","INIT ","LOAD:STAT 1,",
                                     "MDIR ","MOVE ","MSIS ","NAME ","RDIR ",
                                     "STOR:STAT 1,","STOR:TRAC 1,","STOR:TRAC 2,",
                                     "STOR:TRAC 3,","STOR:TRAC 4,"};
static ViString digiModMeasArr[] = {"MERM","MEPK","MEPS","PERM","PEPK","PEPS","EVRM",
                                    "EVPK","EVPS","IQOF","IQIM","FERR","FEPK","ADR",
                                    "RHO","DEV","FSPK","FSRM","FSPS","DTTS"};
static ViString summaryMarkerArr[] = {"MAX","PPE","MPE","MIDD","RMS","MEAN"};
static ViString sourceCalArr[] = {"TRAN","REFL","REFL"};
static ViString sourceCalCollArr[] = {"THR","OPEN","THR"};
static ViString triggerAdjustArr[] = {"FRAM:AUTO ONCE","FRAM","SLOT:AUTO ONCE","SLOT"};
static ViString networkTypeBTSArr[] = {"PRES","NETW PGSM;:CONF:BTS:NETW:PHASE 1",
                                       "NETW PGSM;:CONF:BTS:NETW:PHASE 2","NETW EGSM",
                                       "NETW DCS;:CONF:BTS:NETW:PHASE 1",
                                       "NETW DCS;:CONF:BTS:NETW:PHASE 2",
                                       "NETW DCS;:CONF:BTS:NETW:PHASE 2,PLUS",
                                       "NETW PCS","NETW RGSM","NETW GSM850"};
static ViString networkTypeMSArr[] = {"PRES","NETW PGSM;:CONF:MS:NETW:PHASE 1",
                                       "NETW PGSM;:CONF:MS:NETW:PHASE 2","NETW EGSM",
                                       "NETW DCS;:CONF:MS:NETW:PHASE 1",
                                       "NETW DCS;:CONF:MS:NETW:PHASE 2",
                                       "NETW DCS;:CONF:MS:NETW:PHASE 2,PLUS",
                                       "NETW PCS",
                                       "NETW RGSM",
                                       "NETW GSM850" };
static ViString burstSectionArr[] = {"FULL","TOP","RIS","FALL"};
static ViString phaseFreqErrorArr[] = {"PERR","FERR"};
static ViString burstResultTypeArr[] = {"RMS","PEAK"};
static ViString burstMeasResultArr[] = {"AVER","MAX"};
static ViString powerMeasModeArr[] = {"",":STAT",":DYN",":LEV"};
static ViString selStatusRegArr[] = {"",":POW",":LIM",":LMAR",":SYNC",":ACPL",
                                     ":FREQ",":TRAN"};
static ViString statusRegArr[] = {"OPER:EVEN","OPER:COND","QUES:EVEN","QUES:COND",
                                  "QUES:POW:EVEN","QUES:POW:COND","QUES:LIM:EVEN",
                                  "QUES:LIM:COND","QUES:LMAR:EVEN","QUES:LMAR:COND",
                                  "QUES:SYNC:EVEN","QUES:SYNC:COND","QUES:ACPL:EVEN",
                                  "QUES:ACPL:COND","QUES:FREQ:EVEN","QUES:FREQ:COND",
                                  "QUES:TRAN:EVEN","QUES:TRAN:COND","QUE"};
static ViString HCQuadrantArr[] = {"FULL","QUAD1","QUAD2","QUAD3","QUAD4"};
static ViString modulationArr[] = {"AM:STAT","FM:STAT","DM:STAT","POW:ALC:SOUR"};
static ViString GSMBurstModeArr[] = {"PFER","POW","PTEM"};
static ViString modulTypeArr[] = {"AM","FM","PM"};
static ViString spacingArr[] = {"LOG","LIN"};
static ViString countParameterArr[] = {":CONF:BURS:PFER:COUN",":CONF:BURS:POW:COUN",
                                       ":CONF:BURS:PTEM:COUN",":CONF:SPEC:MOD:COUN",
                                       ":CONF:SPEC:SWIT:COUN",":CONF:SPUR:COUN",
                                       ":CONF:SPUR:COUN:RXB",":CONF:BURS:MACC:COUN"};
static ViString absRelArr[] = {"ABS","REL",VI_NULL};
static ViString statusArr[] = {"PASSED","FAILED","MARGIN","EXC","ABORT",
                               "RUNNING","FINISHED",VI_NULL};
static ViString itemSelectrArr[] = {"NONE","DEF","ALL","GSET","HWS","TRACE1",
                                    "TRACE2","TRACE3","TRACE4","LIN","LIN:ALL",
                                    "TRAN","TRAN:ALL","CVL","CVL:ALL","SCD",
                                    "CSET","HCOP","MACR","WTAB"};
static ViString freqModeArr[] = {"CW","FIX","SWE"};
static ViString afDemodModeArr[] = {"OFF","AM","FM","PM","AMV"};
static ViString sweepSpacingModeArr[] = {"LIN","LOG","AUTO"};
static ViString resBWTypeArr[] = {"3","6"};
static ViString attenuatorStepsizeArr[] = {"1dB","10dB"};
static ViString separatorArr[] = {"POIN","COMMA"};
static ViString triggerSlopeArr[] = {"NEG","POS"};
static ViString triggerModeArr[] = {"IMM","EXT","VID"};
static ViString WCDPMeasurementArr[] = {"POW","ACLR","OBW","WCDP","FDOM","TDOM","ESP","CCDF"};
static ViString CDPMeasurementArr[] = {"POW","ACPR","MOD","CDP","FDOM","TDOM"};
static ViString mkrCPDFunctionArr[] = {"PIL","PAG","SYNC","TERR","PERR","CPIC","PCCP","DPCC"};
static ViString measurementCDPArr[] = {"PTOT","FERR","ACH","PTAL","ACO","TERR",
                                       "PERR","CPOW"};
static ViString fastModeArr[] = {"NORM","FAST"};
static ViString CDMAStandardArr[] = {"FWCDMA8","FWCDMA19"};
static ViString lowerUpperLimitsArr[] = {"LOW","UPP"};
static ViString CDPMeasModeArr[] = {"XPOW:CDP","XPOW:CDP:RAT","XTIM:CDP:ERR:SUMM",
                                    "XTIM:CDP:ERR", "XTIM:CDP:ERR:PHAS"};
static ViString WCDPMeasModeArr[]= {":CALC1:FEED 'XPOW:CDP'",
                                    ":CALC1:FEED 'XPOW:CDP:RAT'",
                                    ":CALC2:FEED 'XTIM:CDP:ERR:SUMM'",
                                    ":CALC2:FEED 'XTIM:CDP:MACC'",
                                    ":CALC2:FEED 'XTIM:CDP:PVSL'",
                                    ":CALC2:FEED 'XTIM:CDP:BSTR'",
                                    ":CALC1:FEED 'XTIM:CDP:ERR:CTAB'",
                                    ":CALC2:FEED 'XTIM:CDP:ERR:PCD'",
                                    ":CALC2:FEED 'XTIM:CDP:SYMB:CONS'",
                                    ":CALC2:FEED 'XTIM:CDP:SYMB:EVM'",
                                    ":CALC1:FEED 'XPOW:CDP:OVER'" };
static ViString sweepTimeArr[] = {"STAN","AUTO"};
static ViString antennaArr[] = {"COND","RAD"};
static ViString BTSTypeArr[] = {"NORM","MICR","PIC"};
static ViString mTypeArr[] = {"GMSK","EDGE"};
static ViString conditionsArr[] = {"NORM","EXTR"};
static ViString gsmMeasBWArr[] = {"DEF","300kHz","1MHz"};
static ViString errorLimitArr[] = {"PPE","PRMS","FREQ","EVMR","EVMP","OSUP",
                                   "PERC"};
static ViString MACCMeasurementArr[] = {"RMS","PEAK","OSUP","PERC","FREQ"};
static ViString measurementWCDPArr[] = {"PTOT","FERR","TFR","TOFF","MACC",
                                        "PCD","EVMR","EVMP","CERR","CSL",
                                        "SRAT","CHAN","CDP","CDPR","IQOF",
                                        "IQIM"};
static ViString measModeSEMArr[] = {"AUTO","MAN","USER"};
static ViString preferenceArr[] = {"TOT","CPIC"};
static ViString measurementWCDPMSArr[] = {"PTOT","FERR","TFR","MACC",
                                          "PCD","EVMR","EVMP","CERR","SRAT",
                                          "CHAN","CDP","CDPR","IQOF","IQIM",
                                          "CMAP","PSYM"};
static ViString antennaModeArr[] = {"OFF","1","2"};
static ViString syncTypeArr[] = {"SCH","CPIC"};
static ViString signalMappingArr[] = {"I","Q"};
static ViString averMethodArr[] = {"VID","LIN","MIN","MAX","SCAL"};

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/*===========================================================================*/
/* rsfsex_stringValPair is used in the rsfsex_error_message function         */
/* rsfsex_statusDataRanges is used to track session dependent status & ranges*/
/*===========================================================================*/
typedef struct  rsfsex_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rsfsex_tStringValPair;

struct rsfsex_statusDataRanges
{
    ViInt32 option;
    ViInt32 instrVer;
    ViInt32 preselector;
    ViBoolean errorChecking;
    ViChar  instrDriverRevision[256];
};

typedef struct rsfsex_statusDataRanges *rsfsex_instrRange;

/*****************************************************************************/
/*= UTILITY ROUTINE DECLARATIONS (Non-Exportable Functions) =================*/
/*****************************************************************************/
void rsfsex_delay (ViReal64 numberOfSeconds);
ViBoolean rsfsex_invalidViBooleanRange (ViBoolean val);
ViBoolean rsfsex_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rsfsex_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max);
ViBoolean rsfsex_invalidViString (ViString val, ViUInt32 maxLength);
ViStatus rsfsex_initCleanUp (ViSession openRMSession, ViPSession openInstrSession,
                ViStatus currentStatus);
ViStatus rsfsex_defaultInstrSetup (ViSession openInstrSession);
ViInt32 rsfsex_absRelToInt(ViChar buff[]);
ViInt32 rsfsex_statusToInt(ViChar buff[]);
void rsfsex_SWAP_32(unsigned char *data, long points);
static ViStatus rsfsex_ReadDataUnknownLength(ViSession instrSession,
                ViChar **outBuffer, ViUInt32 *count);
static ViStatus rsfsex_ParseCatalog(ViChar *catalogList, ViInt32 *nbFiles);
static ViStatus rsfsex_CopyStringBuffer(ViChar *output, const ViChar *input,
                ViInt32 bufferSize);

/*****************************************************************************/
/*------------- INSTRUMENT-DEPENDENT UTILITY ROUTINE DECLARATIONS -----------*/
/*****************************************************************************/
ViStatus rsfsex_checkBeforeRead (ViSession instrSession);
ViStatus rsfsex_sysStatus (ViSession instrSession);
ViStatus rsfsex_confOPT (ViSession instrSession, _VI_FAR ViChar optsList[],
                _VI_FAR ViChar instrVer[]);
ViStatus rsfsex_waitOPC (ViSession instrSession, ViPString command,
                ViPString instrResp, ViInt32 timeout);

/*****************************************************************************/
/*====== USER-CALLABLE FUNCTIONS (Exportable Functions) =====================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViUInt16 iman;
    ViStatus rsfsex_status = VI_SUCCESS;
    ViSession rmSession = 0;
    ViUInt16 interface = VI_INTF_GPIB;
    ViUInt32 retCnt = 0;
    ViByte rdBuffer[BUFFER_SIZE];

    /*- Set standard "C" locale --------------------------------------------*/
    {
        char *locale;

        locale = setlocale(LC_ALL, "C");
    }

    /*- Check input parameter ranges ----------------------------------------*/
    if (rsfsex_invalidViBooleanRange (IDQuery))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (resetDevice))
        return VI_ERROR_PARAMETER3;

    /*- Open instrument session ---------------------------------------------*/
    if ((rsfsex_status = viOpenDefaultRM (&rmSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viOpen (rmSession, resourceName, VI_LOAD_CONFIG, VI_NULL,
        instrSession)) < 0) {
        viClose (rmSession);
        return rsfsex_status;
    }

    if ((rsfsex_status = viGetAttribute (*instrSession, VI_ATTR_INTF_TYPE, &interface)) < 0)
        return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);

    /* Interface specific support */
    if (interface == VI_INTF_ASRL) /* Serial Port */
        {
        if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_TERMCHAR, '\n')) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        /* VI_ATTR_ASRL_END_OUT changed to VI_ASRL_END_NONE due to Agilent VISA */
        if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_ASRL_END_OUT, VI_ASRL_END_NONE)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        if ((rsfsex_status = viFlush (*instrSession, VI_ASRL_IN_BUF)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        }
    else /* GPIB, RSIB */
        {
            if (interface == VI_INTF_GPIB)
            {
                // only old NT instruments 
                if ((rsfsex_status = viGetAttribute (*instrSession, VI_ATTR_RSRC_MANF_ID,
                                                     &iman)) < 0)
                    return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status); 
                if(iman!=0xfff) // not possible for Agilent VISA
                {
                    if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_GPIB_READDR_EN,
                                                     0)) < 0)
                    return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
                }
            }
        
        /* VI_ATTR_SEND_END_EN will stay with this attribute set to VI_TRUE */
        if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_SEND_END_EN,
            VI_TRUE)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        }

    /*- Configure VISA Formatted I/O ----------------------------------------*/
    if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_TMO_VALUE, 15000)) < 0)
        return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
    if ((rsfsex_status = viSetBuf (*instrSession, VI_READ_BUF|VI_WRITE_BUF, 4000)) < 0)
        return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
    if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_WR_BUF_OPER_MODE,
                            VI_FLUSH_ON_ACCESS)) < 0)
        return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
    if ((rsfsex_status = viSetAttribute (*instrSession, VI_ATTR_RD_BUF_OPER_MODE,
                            VI_FLUSH_ON_ACCESS)) < 0)
        return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. Go to remote mode. */
            if ((rsfsex_status = viWrite (*instrSession, "@REM\n", 5, &retCnt)) < 0)
                return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        break;
#ifdef VI_INTF_TCPIP
        case VI_INTF_TCPIP: /* RSIB Interface. Go to remote mode. */
            if ((rsfsex_status = viSetAttribute (*instrSession, RS_ATTR_RSIB_SRE, 1)) < 0)
                return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        break;
#endif
        }

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery) {
        if ((rsfsex_status = viWrite (*instrSession, "*IDN?\n", 6, &retCnt)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
        if ((rsfsex_status = viRead (*instrSession, rdBuffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;

        /* Test FSEx and FSE? models */
        if (strncmp (rdBuffer, "Rohde&Schwarz,FSE", 17) != 0)
            /* Test FSIQ and FSIG models */
            if (strncmp (rdBuffer, "Rohde&Schwarz,FSI", 17) != 0)
                /* Test ESIB models */
                if (strncmp (rdBuffer, "Rohde&Schwarz,ESI", 17) != 0)
                    return rsfsex_initCleanUp (rmSession, instrSession,
                        VI_ERROR_FAIL_ID_QUERY);
     }

    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice) {
        if ((rsfsex_status = rsfsex_reset (*instrSession)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);
    }
    else  /*- Send Default Instrument Setup ---------------------------------*/
        if ((rsfsex_status = rsfsex_defaultInstrSetup (*instrSession)) < 0)
            return rsfsex_initCleanUp (rmSession, instrSession, rsfsex_status);

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Spectrum                                                   */
/* Purpose:  This function shows how to use instrument driver functions. For */
/*           reasonable measurement is necessary set up instrument to the    */
/*           required state.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_appReadSpectrum (ViSession instrSession, ViInt32 measMode,
                                     ViInt32 freqParam, ViReal64 startFreq,
                                     ViReal64 stopFreq, ViInt32 sourceTrace,
                                     ViPInt32 noofPoints, ViReal64 _VI_FAR traceData[])
{
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (measMode, 0, 3))
        return VI_ERROR_PARAMETER2;

    /*
        This function switches ON/OFF state checking of the instrument
        (reading of the Standard Event Register and checking it for
        error). All driver functions are using state checking.
        Switch this function to ON when debug your application. For
        better bus throughput and instrument performance switch it OFF.
        As default is state checking switched to ON!
    */
    if ((rsfsex_status = rsfsex_errorCheckState (instrSession, VI_FALSE)) < VI_SUCCESS)
        return rsfsex_status;
    
    switch (measMode) {
        case 0: /* Set Up Frequencies */
            if (rsfsex_invalidViInt32Range (freqParam, 0, 2))
                return VI_ERROR_PARAMETER3;
            if (rsfsex_invalidViReal64Range (startFreq, 0.0, stopFreq))
                return VI_ERROR_PARAMETER4;
            if (rsfsex_invalidViReal64Range (stopFreq, startFreq, 40.0e9))
                return VI_ERROR_PARAMETER5;
            if ((rsfsex_status = rsfsex_confStartStopFrq (instrSession, 1,
                freqParam, startFreq, stopFreq)) < 0)
                return rsfsex_status;
        break;
        case 1: /* Single Measurement */ case 2: /* Continual Measurement */
            if ((rsfsex_status = rsfsex_confSweep (instrSession, 1, (ViInt32)(measMode-1), 0)) < 0)
                return rsfsex_status;
            /* Send trigger */
            if ((rsfsex_status = rsfsex_writeInstrData (instrSession, "*TRG")) < 0)
                return rsfsex_status;
        break;
        case 3: /* Takes the measurement result */
            if (rsfsex_invalidViInt32Range (sourceTrace, 0, 3))
                return VI_ERROR_PARAMETER6;
            if ((rsfsex_status = rsfsex_dataReadTrace (instrSession, sourceTrace,
                noofPoints, traceData)) < 0)
                return rsfsex_status;
    }

    /*
        This function switches ON/OFF state checking of the instrument
        (reading of the Standard Event Register and checking it for
        error). All driver functions are using state checking.
        Switch this function to ON when debug your application. For
        better bus throughput and instrument performance switch it OFF.
        As default is state checking switched to ON!
    */
    if ((rsfsex_status = rsfsex_errorCheckState (instrSession, VI_TRUE)) < VI_SUCCESS)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Scan Results                                               */
/* Purpose:  This application function returns the trace points data. This   */
/*           function is only possible to use in form of a query during scan */
/*           measurements. The number of transmitted measurement results     */
/*           depends on the scan settings. Instrument is using default or    */
/*           user predefined settings for all other parameters related to    */
/*           this function.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_appReadScan (ViSession instrSession,
                ViBoolean measMode, ViReal64 recFreq, ViReal64 stepWidth,
                ViInt32 *noofPoints, ViChar _VI_FAR statusData[], ViInt32 *traceStatus,
                ViReal64 T1[], ViReal64 T2[], ViReal64 T3[], ViReal64 T4[])
{
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (measMode))
        return VI_ERROR_PARAMETER2;

    if (measMode == VI_FALSE) { /* Configure and run measurement. */
        /* Aborts all measurements. */
        if ((rsfsex_status = rsfsex_actAbort (instrSession)) < 0)
            return rsfsex_status;
        /* Sets Receiver mode. */
        if ((rsfsex_status = rsfsex_actRECMode (instrSession)) < 0)
            return rsfsex_status;
        /* Sets Receiver frequency. */
        if ((rsfsex_status = rsfsex_confRECFreq (instrSession, recFreq, stepWidth)) < 0)
            return rsfsex_status;
        /* Switch block data transmission during a scan to on (Feed Control). */
        if ((rsfsex_status = rsfsex_confFeedControl (instrSession, VI_TRUE)) < 0)
            return rsfsex_status;
        /* Sets Continuous measurement. */
        if ((rsfsex_status = rsfsex_confRECSweep (instrSession, 2, VI_TRUE)) < 0)
            return rsfsex_status;
        /* Run Scan. */
        if ((rsfsex_status = rsfsex_actRECRunScan (instrSession)) < 0)
            return rsfsex_status;
    }
    else { /* Takes the measurement results. */
        if ((rsfsex_status = rsfsex_dataReadScan (instrSession, noofPoints,
            statusData, traceStatus, T1, T2, T3, T4)) < 0)
            return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Receiver Results                                           */
/* Purpose:  This application function setups the Receiver mode first, then  */
/*           defines and activates four detectors and then gets the          */
/*           measurement results. The values of all activated detectors are  */
/*           transferred as outputs. Instrument is using default or user     */
/*           predefined settings for all other parameters related to this    */
/*           function.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_appReadReceiver (ViSession instrSession,
                ViBoolean measMode, ViReal64 *firstDetector,
                ViReal64 *secondDetector, ViReal64 *thirdDetector,
                ViReal64 *fourthDetector)
{
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (measMode))
        return VI_ERROR_PARAMETER2;

    /*
        This function switches ON/OFF state checking of the instrument
        (reading of the Standard Event Register and checking it for
        error). All driver functions are using state checking.
        Switch this function to ON when debug your application. For
        better bus throughput and instrument performance switch it OFF.
        As default is state checking switched to ON!
    */
    if ((rsfsex_status = rsfsex_errorCheckState (instrSession, VI_FALSE)) < VI_SUCCESS)
        return rsfsex_status;
    
    if (measMode == VI_FALSE) { /* Configure measurement. */
        /* Sets Receiver mode. */
        if ((rsfsex_status = rsfsex_actRECMode (instrSession)) < 0)
            return rsfsex_status;
        /* Activates detectors. If detector is not available, error is ommited. */
        if ((rsfsex_status = rsfsex_confRECDetector (instrSession, VI_TRUE,
            VI_FALSE, VI_TRUE, VI_TRUE, VI_FALSE, VI_TRUE, VI_FALSE)) < 0)
            return rsfsex_status;
        /* Sets Continuous measurement. */
        if ((rsfsex_status = rsfsex_confRECSweep (instrSession, 1, VI_TRUE)) < 0)
            return rsfsex_status;
    }
    else { /* Takes the measurement results. */
        if ((rsfsex_status = rsfsex_dataReadReceiver (instrSession,
            firstDetector, secondDetector, thirdDetector, fourthDetector)) < 0)
            return rsfsex_status;
    }

    /*
        This function switches ON/OFF state checking of the instrument
        (reading of the Standard Event Register and checking it for
        error). All driver functions are using state checking.
        Switch this function to ON when debug your application. For
        better bus throughput and instrument performance switch it OFF.
        As default is state checking switched to ON!
    */
    if ((rsfsex_status = rsfsex_errorCheckState (instrSession, VI_TRUE)) < VI_SUCCESS)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Start and Stop Frequency                                        */
/* Purpose:  This function configures start and stop frequencies for the     */
/*           spectrum analyzer.                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confStartStopFrq (ViSession instrSession,
                ViInt32 window, ViInt32 parameter, ViReal64 startFreq,
                ViReal64 stopFreq)
{
    ViUInt32 retCnt = 0;
    ViStatus rsfsex_status = VI_SUCCESS;
    ViByte buffer[BUFFER_SIZE];

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (parameter, 0, 2))
        return VI_ERROR_PARAMETER3;

    switch (parameter) {
        case 0:
            sprintf (buffer, ":SENS%ld:FREQ:STOP %.12f;STAR %.12f\n", window, stopFreq,
                     startFreq);
        break;
        case 1:
            sprintf (buffer, ":SENS%ld:FREQ:STAR %.12f\n", window, startFreq);
        break;
        case 2:
            sprintf (buffer, ":SENS%ld:FREQ:STOP %.12f\n", window, stopFreq);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Config Span And Center Frequency                                */
/* Purpose:  This function configures frequency span and center frequency    */
/*           for the spectrum analyzer.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSpanCenterFrq (ViSession instrSession,
                ViInt32 window, ViInt32 parameter, ViReal64 spanFreq,
                ViReal64 centerFreq)
{
    ViUInt32 retCnt = 0;
    ViStatus rsfsex_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];

    ViReal64 lowerLimit = 0.0;
    ViReal64 upperLimit = 40.0E9;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (parameter, 0, 2))
        return VI_ERROR_PARAMETER3;

    switch (parameter) {
        case 0:
            if (rsfsex_invalidViReal64Range (spanFreq, lowerLimit, upperLimit))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:FREQ:CENT %.12f;SPAN %.12f\n", window, centerFreq,
                     spanFreq);
        break;
        case 1:
            if (rsfsex_invalidViReal64Range (spanFreq, lowerLimit, upperLimit))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:FREQ:SPAN %.12f\n", window, spanFreq);
        break;
        case 2:
            sprintf (buffer, ":SENS%ld:FREQ:CENT %.12f\n", window, centerFreq);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Config Frequency Offset                                         */
/* Purpose:  This function configures frequency offset of the spectrum       */
/*           analyzer.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confFreqOffset (ViSession instrSession,
                ViInt32 window, ViReal64 offsFreq)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (offsFreq, -100.0E9, 100.0E9))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:FREQ:OFFS %.12f\n", window, offsFreq);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Frequency Link                                                  */
/* Purpose:  This function selects the frequency coupling. The frequency     */
/*           coupling defines which of the dependent parameters is to remain */
/*           constant when choosen (start, stop, center or span) frequency   */
/*           is changed.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confFreqLink (ViSession instrSession,
                ViInt32 window, ViInt32 freqParameter, ViInt32 linkParameter)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (freqParameter, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (linkParameter, 0, 3))
        return VI_ERROR_PARAMETER4;
    if (freqParameter == linkParameter)
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    sprintf (buffer, ":SENS%ld:FREQ:%s:LINK %s\n", window, freqParameterArr[freqParameter],
                freqParameterArr[linkParameter]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Frequency Mode                                                  */
/* Purpose:  This function switches between frequency (SWEep) and time (CW | */
/*           FIXed) domain in the analyzer mode                              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confFreqMode (ViSession instrSession, ViInt32 window,
                ViInt32 frequencyMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (frequencyMode, 0, 2))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:FREQ:MODE %s\n", window, freqModeArr[frequencyMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Reference Level                                                 */
/* Purpose:  This function configures the reference level for the instrument */
/*           when it is in spectrum analyzer or vecotor analyzer mode.       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRefLevel (ViSession instrSession, ViInt32 window,
    ViReal64 refLev)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (refLev, -1.0E12, 1.0E12))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:RLEV %.12f\n", window, refLev);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Reference Level Opt                                             */
/* Purpose:  This function configures the reference offset,                  */
/*           probe, and input units for the instrument when it is in spectrum*/
/*           analyzer mode.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRefLevelOpt (ViSession instrSession, ViInt32 window,
                ViInt32 funcMode, ViReal64 maxLev, ViReal64 refLevOffs,
                ViInt32 unit)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (funcMode, 0, 5))
        return VI_ERROR_PARAMETER3;

    switch (funcMode) {
        case 0: /* Reference Level Offset */
            if (rsfsex_invalidViReal64Range (refLevOffs, -200.0, 200.0))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:RLEV:OFFS %.12fDB\n",
                window, refLevOffs);
        break;
        case 1: /* Ref Val Auto Off */
            if (rsfsex_invalidViInt32Range (unit, 0, 16))
                return VI_ERROR_PARAMETER6;
            if (unit == 0) {
                if (rsfsex_invalidViReal64Range (maxLev, -200.0, 200.0))
                    return VI_ERROR_PARAMETER4;
            }
            sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:SCALE:RVAL:AUTO OFF;"
                ":DISP:WIND%ld:TRAC:Y:SCALE:RVAL %.12f%s\n", window, window,
                maxLev, unitRefLevelArr[unit]);
        break;
        case 2: /* Ref Val Auto On */
            sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:SCALE:RVAL:AUTO ON\n", window);
        break;
        case 3: /* Probe Off */
            sprintf (buffer, ":UNIT:PROB OFF\n");
        break;
        case 4: /* Probe Off */
            sprintf (buffer, ":UNIT:PROB ON\n");
        break;
        case 5: /* Specify Ref Level Unit, if Vector Analyzer mode, units are not allowed */
            if (rsfsex_invalidViInt32Range (unit, 0, 16))
                return VI_ERROR_PARAMETER6;
            if (unit != 8)
                sprintf (buffer, ":CALC%ld:UNIT:POWER %s\n", window, unitRefLevelArr[unit]);
            else
                *buffer = VI_NULL;
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure Range Level                                           */
/* Purpose:  This function configures the Y axis range of the spectrum       */
/*           analyzer.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confLevelRange (ViSession instrSession,
                ViInt32 window, ViInt32 levRange, ViReal64 logManValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (levRange, 0, 2))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":DISP:WIND%ld:TRACE:Y:SPAC %s", window, ySpaceArr[levRange]);

    if (levRange == 0) {
        if (rsfsex_invalidViReal64Range (logManValue, 10.0, 200.0))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, "%s;SCAL %.12f", buffer, logManValue);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker State                                                    */
/* Purpose:  This function enables or disables a marker. When the marker is  */
/*           switched on, a peak search is done automatically.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMarkState (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean markState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (markState))
        return VI_ERROR_PARAMETER4;

    if (markState == VI_TRUE)
        sprintf (buffer, ":CALC%ld:MARK%ld:STAT ON\n", window, markNumber);
    else
        sprintf (buffer, ":CALC%ld:MARK%ld:STAT OFF\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker Position                                                 */
/* Purpose:  This function sets the marker to the specified frequency.       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMarkPosition (ViSession instrSession, ViInt32 window,
    ViInt32 markNumber, ViReal64 pos)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CALC%ld:MARK%ld:X %.12f\n", window, markNumber, pos);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker Opt                                                      */
/* Purpose:  This function selects the trace for a marker or deletes all     */
/*           markers.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMarkOpt (ViSession instrSession, ViInt32 window,
    ViInt32 markNumber, ViInt32 trace, ViBoolean deleteAllMkrs)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (deleteAllMkrs))
        return VI_ERROR_PARAMETER5;

    if (deleteAllMkrs == VI_TRUE)
        sprintf (buffer, ":CALC%ld:MARK:AOFF\n", window);
    else {
        if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
            return VI_ERROR_PARAMETER3;
        if (rsfsex_invalidViInt32Range (trace, 1, 4))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, ":CALC%ld:MARK%ld:TRAC %ld\n", window, markNumber, trace);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker Demodulation                                             */
/* Purpose:  This function configures the demodulation markers.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkDemod (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViReal64 stopTime,
                ViBoolean demodState, ViBoolean modType, ViReal64 volume)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (demodState))
        return VI_ERROR_PARAMETER5;

    if (demodState == VI_TRUE) {

        if (rsfsex_invalidViReal64Range (stopTime, 1.0E-2, 1.0E3))
            return VI_ERROR_PARAMETER4;
        if (rsfsex_invalidViBooleanRange (modType))
            return VI_ERROR_PARAMETER6;
        if (rsfsex_invalidViReal64Range (volume, 0.0, 100.0))
            return VI_ERROR_PARAMETER7;

        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:DEM:STAT ON;HOLD %.12f;:SYST:SPE:VOL %.12f",
                 window, markNumber, stopTime, volume/100.0);

        if (modType == VI_TRUE)
            sprintf (buffer, "%s;:CALC%ld:MARK%ld:FUNC:DEM:SEL AM", buffer,
            window, markNumber);
        else
            sprintf (buffer, "%s;:CALC%ld:MARK%ld:FUNC:DEM:SEL FM", buffer,
            window, markNumber);
    }
    else
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:DEM:STAT OFF", window, markNumber);

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Frequency Counter                                               */
/* Purpose:  This function configures the frequency counter.                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkFreqCnt (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViInt32 countResolution,
                ViBoolean countState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (countState))
        return VI_ERROR_PARAMETER5;

    if (countState == VI_TRUE) {
        if (rsfsex_invalidViInt32Range (countResolution, 0, 5))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, ":CALC%ld:MARK%ld:COUN ON;COUN:RES %s\n",
            window, markNumber, counterResArr[countResolution]);
    }
    else
        sprintf (buffer, ":CALC%ld:MARK%ld:COUN OFF\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Noise Measurement                                               */
/* Purpose:  This function configures the noise power density measurement.   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkNoise (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean noiseState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (noiseState))
        return VI_ERROR_PARAMETER4;

    if (noiseState == VI_TRUE)
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:NOIS ON\n", window, markNumber);
    else
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:NOIS OFF\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Channels                                          */
/* Purpose:  This function configures the number of adjacent channels for    */
/*           channel power measurement.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanChannels (ViSession instrSession,
                ViInt32 window, ViInt32 numbOfAdjChans)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (numbOfAdjChans, 1, 3))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:POW:ACH:ACP %ld\n", window, numbOfAdjChans);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Standard                                          */
/* Purpose:  This function configures the standard for channel power         */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanStandard (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViInt32 ACPS)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (ACPS, 0, 20))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:POW:PRES %s\n", window,
        markNumber, ACPStandardArr[ACPS]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Channel Opt                                       */
/* Purpose:  This function configures the channel bandwidth and channel      */
/*           spacing for channel power measurement.                          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanOpt (ViSession instrSession,
                ViInt32 window, ViInt32 numAdjCh, ViReal64 CHBw,
                ViReal64 ADJBw, ViReal64 ADJChSpac, ViReal64 ALT1Bw,
                ViReal64 ALT1ChSpac, ViReal64 ALT2Bw, ViReal64 ALT2ChSpac)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (numAdjCh, 1, 3))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (CHBw, 0.0, 10.0E9))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (ADJBw, 0.0, 10.0E9))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViReal64Range (ADJChSpac, 0.0, 2.0E9))
        return VI_ERROR_PARAMETER6;

    sprintf (buffer, ":SENS%ld:POW:ACH:BWID %.12f;SPAC:ACH %.12f;:SENS%ld:POW:ACH:BWID:ACH %.12f;",
             window, CHBw, ADJChSpac, window, ADJBw);

    if (numAdjCh > 1) {
        if (rsfsex_invalidViReal64Range (ALT1Bw, 0.0, 10.0E9))
            return VI_ERROR_PARAMETER7;
        if (rsfsex_invalidViReal64Range (ALT1ChSpac, 0.0, 2.0E9))
            return VI_ERROR_PARAMETER8;
        sprintf (buffer, "%s;:SENS%ld:POW:ACH:SPAC:ALT1 %.12f;:SENS%ld:POW:ACH:BWID:ALT1 %.12f",
                 buffer, window, ALT1ChSpac, window, ALT1Bw);
    }
    if (numAdjCh > 2) {
        if (rsfsex_invalidViReal64Range (ALT2Bw, 0.0, 10.0E9))
            return VI_ERROR_INSTR_PARAMETER9;
        if (rsfsex_invalidViReal64Range (ALT2ChSpac, 0.0, 2.0E9))
            return VI_ERROR_INSTR_PARAMETER10;
        sprintf (buffer, "%s;:SENS%ld:POW:ACH:SPAC:ALT2 %.12f;:SENS%ld:POW:ACH:BWID:ALT2 %.12f",
                 buffer, window, ALT2ChSpac, window, ALT2Bw);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Channel Set                                       */
/* Purpose:  This function controls relative/absolute mode of channel power  */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowChanSet (ViSession instrSession,
                ViInt32 window, ViBoolean CPACPMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (CPACPMode))
        return VI_ERROR_PARAMETER3;

    if (CPACPMode == VI_TRUE)
        sprintf (buffer, ":SENS%ld:POW:ACH:MODE REL\n", window);
    else
        sprintf (buffer, ":SENS%ld:POW:ACH:MODE ABS\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Occupied BW Meas                                  */
/* Purpose:  This function configures the bandwidth for occupied bandwidth   */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowOccPowBW (ViSession instrSession,
                ViInt32 window, ViReal64 power)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (power, 10.0, 99.9))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:POW:BAND %.12fPCT\n", window, power);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Meas Mode                                         */
/* Purpose:  This function sets the channel power measurement modes.         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowMeas (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViInt32 chanPowType,
                ViBoolean chanPowMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (chanPowMode))
        return VI_ERROR_PARAMETER5;

    if (chanPowMode == VI_FALSE)
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:POW OFF\n", window, markNumber);
    else {
        if (rsfsex_invalidViInt32Range (chanPowType, 0, 4))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:POW:SEL %s;\n", window,
            markNumber, chanPowTypeArr[chanPowType]);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power Measurement Limit                                 */
/* Purpose:  This function configures the limit check for channel power      */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkChPowLim (ViSession instrSession,
                ViInt32 window, ViInt32 numbOfAdjChans, ViReal64 ADJLow,
                ViReal64 ALT1Low, ViReal64 ALT2Low, ViReal64 ADJHigh,
                ViReal64 ALT1High, ViReal64 ALT2High, ViBoolean ADJState,
                ViBoolean ALT1State, ViBoolean ALT2State)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (numbOfAdjChans, 1, 3))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (ADJLow, -500.0, 500.0))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (ALT1Low, -500.0, 500.0))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViReal64Range (ALT2Low, -500.0, 500.0))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViReal64Range (ADJHigh, -500.0, 500.0))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViReal64Range (ALT1High, -500.0, 500.0))
        return VI_ERROR_PARAMETER8;
    if (rsfsex_invalidViReal64Range (ALT2High, -500.0, 500.0))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rsfsex_invalidViBooleanRange (ADJState))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rsfsex_invalidViBooleanRange (ALT1State))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rsfsex_invalidViBooleanRange (ALT2State))
        return VI_ERROR_INSTR_PARAMETER12;

    sprintf (buffer, ":SENS%ld:POW:ACH:ACP %ld;", window, numbOfAdjChans);

    sprintf (buffer, "%s:CALC%ld:LIM:ACP:ACH %.12fDB,%.12fDB;ALT1 %.12fDB,%.12fDB;ALT2 %.12fDB,%.12fDB",
             buffer, window, ADJLow, ADJHigh, ALT1Low, ALT1High, ALT2Low, ALT2High);

    if ((ADJState == VI_TRUE) || (ALT1State == VI_TRUE) || (ALT2State == VI_TRUE))
        sprintf (buffer, "%s;STAT ON", buffer);
    else
        sprintf (buffer, "%s;STAT OFF", buffer);

    if (ADJState == VI_TRUE)
        sprintf (buffer, "%s;ACH:STAT ON", buffer);
    else
        sprintf (buffer, "%s;ACH:STAT OFF", buffer);

    if (numbOfAdjChans > 1) {
        if (ALT1State == VI_TRUE)
            sprintf (buffer, "%s;:CALC%ld:LIM:ACP:ALT1:STAT ON", buffer, window);
        else
            sprintf (buffer, "%s;:CALC%ld:LIM:ACP:ALT1:STAT OFF", buffer, window);

        if (numbOfAdjChans == 3) {
            if (ALT2State == VI_TRUE)
                sprintf (buffer, "%s;:CALC%ld:LIM:ACP:ALT2:STAT ON", buffer, window);
            else
                sprintf (buffer, "%s;:CALC%ld:LIM:ACP:ALT2:STAT OFF", buffer, window);
        }
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker State                                              */
/* Purpose:  This function enables or disables a delta marker.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDeltaMarkState (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean markState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (markState))
        return VI_ERROR_PARAMETER4;

    if (markState == VI_FALSE) {
        sprintf (buffer, ":CALC%ld:DELT%ld:STAT OFF\n", window, markNumber);
    }
    else {
        sprintf (buffer, ":CALC%ld:DELT%ld:STAT ON\n", window, markNumber);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker Position                                           */
/* Purpose:  This function sets the delta marker to the specified frequency. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDeltaMarkPosition (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViReal64 markPos)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CALC%ld:DELT%ld:X %.12f\n", window, markNumber, markPos);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker Opt                                                */
/* Purpose:  This function deletes all delta markers, if set and toggles     */
/*           between absolute and relative measurement.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDeltaMarkOpt (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViInt32 trace,
                ViBoolean deleteAllMkrs, ViBoolean deltaMarker)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    if (deleteAllMkrs == VI_TRUE)
        sprintf (buffer, ":CALC%ld:DELT:AOFF\n", window);
    else {
        if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
            return VI_ERROR_PARAMETER3;
        if (rsfsex_invalidViInt32Range (trace, 1, 4))
            return VI_ERROR_PARAMETER4;
        if (rsfsex_invalidViBooleanRange (deleteAllMkrs))
            return VI_ERROR_PARAMETER5;
        if (rsfsex_invalidViBooleanRange (deltaMarker))
            return VI_ERROR_PARAMETER6;
        sprintf (buffer, ":CALC%ld:DELT%ld:TRAC %ld;MODE %s\n",
            window, markNumber, trace, absRelArr[deltaMarker]);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker Fixed Ref                                          */
/* Purpose:  This function activates/deactivates reference fixed marker.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMDeltaMarkFixRef (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean refFixed)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (refFixed))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:DELT%ld:FUNC:FIX:STAT %s\n", window, markNumber,
        switchArr[refFixed]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker Fixed Ref Point                                    */
/* Purpose:  This function configures reference point for delta marker       */
/*           measurement reference fixed.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMDeltaMarkFixRefPoint (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViInt32 refPointSel,
                ViReal64 refPointValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (refPointSel, 0, 2))
        return VI_ERROR_PARAMETER4;

    switch (refPointSel) {
        case 0:
            if (rsfsex_invalidViReal64Range (refPointValue, -200.0, 200.0))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:DELT%ld:FUNC:FIX:RPO:Y %.12fDBM\n", window,
            markNumber, refPointValue);
        break;
        case 1:
            if (rsfsex_invalidViReal64Range (refPointValue, -100.0, 100.0))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:DELT%ld:FUNC:FIX:RPO:Y:OFFS %.12fDB\n",
            window, markNumber, refPointValue);
        break;
        case 2:
            if (rsfsex_invalidViReal64Range (refPointValue, -100.0, 40.0E9))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:DELT%ld:FUNC:FIX:RPO:X %.12f\n", window,
            markNumber, refPointValue);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure Phase Noise Measurement                               */
/* Purpose:  This function configures the phase noise measurement.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkPhaseNoise (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean noiseState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (noiseState))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:DELT%ld:FUNC:PNO %s\n", window, markNumber,
        switchArr[noiseState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure Marker Search Parameter                               */
/* Purpose:  This function configures the search function.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkSearchParam (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViReal64 peakExc,
                ViBoolean exclLow, ViBoolean searchLim)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (peakExc, 0.0, 80.0))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViBooleanRange (exclLow))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViBooleanRange (searchLim))
        return VI_ERROR_PARAMETER6;

    sprintf (buffer, ":CALC%ld:MARK%ld:LOEX ", window, markNumber);

    if (exclLow == VI_TRUE)
        sprintf (buffer, "%sON;", buffer);
    else
        sprintf (buffer, "%sOFF;", buffer);

    sprintf (buffer, "%sPEXC %.12fDB;", buffer, peakExc);

    sprintf (buffer, "%sX:SLIM ", buffer);

    if (searchLim == VI_TRUE)
        sprintf (buffer, "%sON;", buffer);
    else
        sprintf (buffer, "%sOFF;", buffer);

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure Marker Search Parameter                               */
/* Purpose:  This function configures the measurement functions ndB down and */
/*           shape factor.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMMarkSearchNdB (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViInt32 levelFunc, ViReal64 ndBDownValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (levelFunc, 0, 3))
        return VI_ERROR_PARAMETER4;

    switch (levelFunc) {
        case 0:
            sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:NDBD:STAT OFF;"
                ":CALC%ld:MARK%ld:FUNC:SFAC:STAT OFF\n",
                window, markNumber, window, markNumber);
            break;
        case 1:
            if (rsfsex_invalidViReal64Range (ndBDownValue, 0.0, 100.0))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:NDBD %.12fDB;NDBD:STAT ON\n",
                window, markNumber, ndBDownValue);
            break;
        case 2:
            sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:SFAC:STAT ON;"
                ":CALC%ld:MARK%ld:FUNC:SFAC (60dB/3dB)\n",
                window, markNumber, window, markNumber);
            break;
        case 3:
            sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:SFAC:STAT ON;"
                ":CALC%ld:MARK%ld:FUNC:SFAC (60dB/6dB)\n",
                window, markNumber, window, markNumber);
            break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Summary Marker                                                  */
/* Purpose:  This function configures the summary markers. Summary marker are*/
/*           available for measurements in the time domain (SPAN = 0).       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSumMark (ViSession instrSession, ViInt32 window,
                ViInt32 markNumber, ViInt32 summMkr, ViBoolean stateSwitch)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    if (summMkr == 9) { /* All Off */
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:SUMM:AOFF", window, markNumber);
    }
    else {

        if (rsfsex_invalidViInt32Range (summMkr, 0, 9))
            return VI_ERROR_PARAMETER4;
        if (rsfsex_invalidViBooleanRange (stateSwitch))
            return VI_ERROR_PARAMETER5;

        if (summMkr == 0) {  /* Summary Marker ON/OFF*/
            sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:SUMM ", window, markNumber);
        }
        else {
            sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:SUMM:%s ", window, markNumber,
                 summMkrArr[summMkr - 1]);
        }

        if (stateSwitch == VI_TRUE)
            sprintf (buffer, "%sON", buffer);
        else
            sprintf (buffer, "%sOFF", buffer);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Lines                                                   */
/* Purpose:  This function sets the display lines in the instrument, i.e.,   */
/*           the level, frequency and time lines (depending on the X-axis) as*/
/*           well as threshold and reference lines.                          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDLines (ViSession instrSession, ViInt32 window,
                ViInt32 lineType, ViBoolean lineNo, ViInt32 lineOperationSwitch,
                ViReal64 linePositionValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (lineType, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (lineOperationSwitch, 0, 2))
        return VI_ERROR_PARAMETER5;

    switch (lineType) {
        case 0: case 1: case 4:
            if (rsfsex_invalidViBooleanRange (lineNo))
                return VI_ERROR_PARAMETER4;
            if (lineOperationSwitch == 2) {
                if (rsfsex_invalidViReal64Range (linePositionValue, -330.0, 1.0e30))
                    return VI_ERROR_PARAMETER6;
                sprintf (buffer, ":CALC%ld:%s%ld %.12f\n", window, lineTypeArr[lineType], lineNo+1,
                    linePositionValue);
            }
            else
                if (lineOperationSwitch == 1)
                    sprintf (buffer, ":CALC%ld:%s%ld:STAT ON\n", window, lineTypeArr[lineType],
                        lineNo+1);
                else
                    sprintf (buffer, ":CALC%ld:%s%ld:STAT OFF\n", window, lineTypeArr[lineType],
                        lineNo+1);
        break;
        default:
            if (lineOperationSwitch == 2) {
                if (rsfsex_invalidViReal64Range (linePositionValue, -330.0, 1.0e30))
                    return VI_ERROR_PARAMETER6;
                sprintf (buffer, ":CALC%ld:%s %.12f\n", window, lineTypeArr[lineType], linePositionValue);
            }
            else
                if (lineOperationSwitch == 0)
                    sprintf (buffer, ":CALC%ld:%s:STAT OFF\n", window, lineTypeArr[lineType]);
                else
                    sprintf (buffer, ":CALC%ld:%s:STAT ON\n", window, lineTypeArr[lineType]);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Limit Lines State                                               */
/* Purpose:  This function operates with limit lines. The limit line         */
/*           subsystem comprises the limit lines and the corresponding limit */
/*           checks. This function allows to switch limit line operations.   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confLimitLineState (ViSession instrSession,
                ViInt32 window, ViInt32 limitLineNo, ViInt32 limitLineOp,
                ViString limitLineName)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (limitLineNo, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (limitLineOp, 0, 3))
        return VI_ERROR_PARAMETER4;

    switch (limitLineOp) {
        case 0: case 1:
            if (rsfsex_invalidViString (limitLineName, 8))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:LIM%ld:NAME '%s';STATE %s\n", window,
                limitLineNo, limitLineName, switchArr[limitLineOp]);
        break;
        case 2:
            if (rsfsex_invalidViString (limitLineName, 8))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:LIM%ld:COPY \'%s\'\n", window, limitLineNo,
                limitLineName);
        break;
        case 3:
            sprintf (buffer, ":CALC%ld:LIM%ld:NAME \'%s\';DEL\n", window,
                limitLineNo, limitLineName);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Limit Lines Parameters                                          */
/* Purpose:  This function sets the X-axis (CONTrol) and Y-axis (upper and/or*/
/*           lower) limit line parameters.                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confLimitLineParam (ViSession instrSession,
                ViInt32 window, ViInt32 traceNumber, ViInt32 limitLineNo,
                ViString limitLineName, ViString comment,
                ViBoolean spacing, ViBoolean modeX, ViBoolean modeY,
                ViBoolean ctrlUnit, ViBoolean domain, ViBoolean lineParameter,
                ViInt32 units, ViInt32 noofValues,
                ViReal64 _VI_FAR xaxisValues[], ViReal64 _VI_FAR yaxisValues[],
                ViReal64 margin)
{
    ViUInt32 retCnt = 0;
    ViInt32 i;
    static ViChar buffer[2*BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    char    *p2buffer;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (traceNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (limitLineNo, 1, 8))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViString (limitLineName, 8))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViString (comment, 50))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViBooleanRange (modeX))
        return VI_ERROR_PARAMETER8;
    if (rsfsex_invalidViBooleanRange (modeY))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rsfsex_invalidViBooleanRange (ctrlUnit))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rsfsex_invalidViBooleanRange (domain))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rsfsex_invalidViBooleanRange (lineParameter))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rsfsex_invalidViInt32Range (noofValues, 0, 50))
        return VI_ERROR_INSTR_PARAMETER14;
    /* Parametr 14 is not range checked */
    /* Parametr 15 is not range checked */
    if (rsfsex_invalidViReal64Range (margin, -1.0e99, 1.0e99))
        return VI_ERROR_INSTR_PARAMETER17;

    /*
        Delete old limit line. Execution error has
        to be ignored when the limit line doesn't exist.
    */

    sprintf (buffer, ":CALC%ld:LIM%ld:NAME \'%s\';DEL\n", window,
             limitLineNo, limitLineName);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    /* Status checking. */
    if (rsfsex_sysStatus (instrSession) != VI_SUCCESS)
        /* Clear STB to ignore execution error */
        if ((rsfsex_status = viWrite (instrSession, "*CLS\n", 5, &retCnt)) < 0)
            return rsfsex_status;

/* X Axis values */
    memset(buffer, 0, sizeof(buffer));
    p2buffer = buffer;

    if (domain == VI_TRUE) /* Sent Units */
        p2buffer += sprintf (p2buffer, ":CALC%ld:LIM%ld:CONT:DOM %s;MODE %s;UNIT %s;DATA ",
            window, limitLineNo, domainArr[domain], modeArr[modeX], ctrlUnitArr[ctrlUnit]);
    else
        p2buffer += sprintf (p2buffer, ":CALC%ld:LIM%ld:CONT:DOM %s;MODE %s;DATA ",
            window, limitLineNo, domainArr[domain], modeArr[modeX]);
            
    for (i = 0; i<noofValues; i++)
        p2buffer += sprintf (p2buffer, "%.12f,", xaxisValues[i]);
    /* Remove , from the end */
    p2buffer--;
    *p2buffer = '\0';

/* Y Axis values */

    if (rsfsex_invalidViInt32Range (units, 0, 15))
        return VI_ERROR_INSTR_PARAMETER13;

    p2buffer += sprintf (p2buffer, ";:CALC%ld:LIM%ld:UNIT %s;COMM \'%s\'", window,
             limitLineNo, unitArr[units], comment);

    if (lineParameter == VI_TRUE) {
        if (rsfsex_invalidViBooleanRange (spacing))
            return VI_ERROR_PARAMETER7;
        p2buffer += sprintf (p2buffer, ";:CALC%ld:LIM%ld:UPP:MODE %s;SPAC %s;MARG %.12f;DATA ",
                 window, limitLineNo, modeArr[modeY], spacingArr[spacing],
                 margin);
    }
    else
        p2buffer += sprintf (p2buffer, ";:CALC%ld:LIM%ld:LOW:MODE %s;MARG %.12f;DATA ",
                 window, limitLineNo, modeArr[modeY], margin);
    
    for (i = 0; i<noofValues; i++)
        p2buffer += sprintf (p2buffer, "%.12f,", yaxisValues[i]);
    p2buffer--;
    *p2buffer = '\0';

    p2buffer += sprintf (p2buffer, ";:CALC%ld:LIM%ld:TRAC %ld", window, limitLineNo, traceNumber);
    p2buffer += sprintf (p2buffer, ";:CALC%ld:LIM%ld:%s:STATE ON", window,
        limitLineNo, (lineParameter == VI_TRUE) ? "UPP" : "LOW");

    p2buffer += sprintf (p2buffer, "\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Limit Lines Catalog                                             */
/* Purpose:  This function reads out the names of all limit lines stored on  */
/*           the harddisk.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confLimitLineCat (ViSession instrSession, 
                ViPInt32 nbOfLimis, ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 retCnt;
    ViChar   *buffer = VI_NULL,
             *p2buffer;

    if (bufferSize < 0)
        return VI_ERROR_PARAMETER3;
    if ((bufferSize > 0) && (catalogList == VI_NULL))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viWrite (instrSession, "*CLS;:CALC:LIM:CAT?;*OPC?\n", 26, &retCnt)) < 0)
        return rsfsex_status;
        
    if ((rsfsex_status = rsfsex_ReadDataUnknownLength(instrSession, &buffer, &retCnt)) < 0)
        return rsfsex_status;

    if ((p2buffer = strchr(buffer, ';')) == VI_NULL)
        p2buffer = buffer;
    
    *p2buffer = '\0';

        /* skip to end of first filename */
    if ((rsfsex_status = rsfsex_ParseCatalog(buffer, nbOfLimis)) < VI_SUCCESS)
    {
        free(buffer);
        if (nbOfLimis) *nbOfLimis = 0;
        return rsfsex_status;
    }

    rsfsex_status = rsfsex_CopyStringBuffer(catalogList, buffer, bufferSize);

    free(buffer);
    
    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;
        
        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Base Line Clipping                                              */
/* Purpose:  This function is for switching on or off the threshold line     */
/*           (base line), below which all measured values are cleared. If on */
/*           selected then defines the position of a threshold line (base    */
/*           line).                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBaseLine (ViSession instrSession, ViInt32 window,
                ViBoolean thresholdState, ViReal64 linePositionValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (thresholdState))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (linePositionValue, -330.0, 1.0e30))
        return VI_ERROR_PARAMETER4;

    if (thresholdState == VI_TRUE)
        sprintf (buffer, ":CALC%ld:CTHR:STAT ON;:CALC%ld:CTHR %.12f\n",
                 window, window, linePositionValue);
    else
        sprintf (buffer, ":CALC%ld:CTHR:STAT OFF\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace Setup                                                     */
/* Purpose:  This function defines the type of display and the evaluation of */
/*           the traces.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTrace (ViSession instrSession, ViInt32 window,
                ViInt32 traceNumber, ViInt32 traceMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (traceNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (traceMode, 0, 11))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":DISP:WIND%ld:TRAC%ld:%s\n", window, traceNumber,
        traceModeArr[traceMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Detector                                                        */
/* Purpose:  This function controls the recording of measurement values via  */
/*           the type of detector selected for each trace.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMDetector (ViSession instrSession,
                ViInt32 traceNumber, ViInt32 traceDetector)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (traceNumber, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (traceDetector, 0, 9))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "SENS:DET%ld:FUNC%s\n", traceNumber, traceDetectorArr[traceDetector]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace Math                                                      */
/* Purpose:  This function allows to process data from the SENSe-subsystem in*/
/*           numeric expressions.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMTraceMath (ViSession instrSession,
                ViInt32 window, ViInt32 traceNumber, ViBoolean mathState,
                ViString mathExpression)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    *buffer = VI_NULL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (traceNumber, 0, 7))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (mathState))
        return VI_ERROR_PARAMETER4;

    if (mathState == VI_FALSE)
        sprintf (buffer, ":CALC%ld:MATH%ld:STAT %s\n", window, traceNumber,
            switchArr[mathState]);
    else {
        if (mathExpression) {
            if (strlen (mathExpression) > 256)
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":CALC%ld:MATH%ld (%s);:CALC%ld:MATH%ld:STAT %s\n",
                window, traceNumber, mathExpression, window, traceNumber,
                switchArr[mathState]);
        } else
            return VI_ERROR_PARAMETER5;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace Averaging Method                                          */
/* Purpose:  This function selects the trace averaging method (Video and     */
/*           Linear averaging).                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceAveMethod (ViSession instrSession,
                ViInt32 window, ViInt32 averMethod)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (averMethod, 0, 1))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:AVER:TYPE %s\n", window, averMethodArr[averMethod]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Feed Control                                                    */
/* Purpose:  This function switches block data transmission during a scan on */
/*           and off. The block size dependens on the scan time.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confFeedControl (ViSession instrSession,
                ViBoolean feedControl)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViBooleanRange (feedControl))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":TRAC:FEED:CONT %s\n", (feedControl == VI_FALSE) ? "NEV" : "ALW");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace ASCII Append                                              */
/* Purpose:  This function defines whether data are to be added to the output*/
/*           file or whether the output file is to be overwritten.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceExp (ViSession instrSession, ViBoolean append)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (append))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM:DEXP:APP %s\n", switchArr[append]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace ASCII Decimal Separator                                   */
/* Purpose:  This function defines which decimal separator (decimal point or */
/*           comma) is to be used for outputting measurement data to the file*/
/*           in ASCII format. Different languages of evaluation programs (eg */
/*           MS-Excel) can thus be supported.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceDSep (ViSession instrSession,
                ViBoolean separator)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (separator))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM:DEXP:DSEP %s\n", separatorArr[separator]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace ASCII Header                                              */
/* Purpose:  This function defines whether a header (start frequency, sweep  */
/*           time, detector, etc) is to be stored at the beginning of the    */
/*           output file or if only the measured values are to be stored.    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceHeader (ViSession instrSession,
                ViBoolean header)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (header))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM:DEXP:HEAD %s\n", switchArr[header]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace ASCII Comment                                             */
/* Purpose:  This function defines a comment for the output file.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceComment (ViSession instrSession,
                ViString commentString)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (!commentString)
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM:DEXP:COMM '%s'\n", commentString);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace I/Q State                                                 */
/* Purpose:  This function witches IQ data recording on or off. Since IQ data*/
/*           recording is not compatible with other measurement functions,   */
/*           the latter are switched off as long as the IQ data recording    */
/*           function is active. As long as the function is active, no       */
/*           results will be output on the screen.                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceIQState (ViSession instrSession, 
                ViBoolean traceState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViBooleanRange (traceState))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2000000)) { /* available only with option FSIQB70. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":TRAC:IQ %s\n", switchArr[traceState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trace I/Q Set                                                   */
/* Purpose:  This function configures the most important parameters (such as */
/*           sample rate, trigger mode, trigger slope, trigger offset and    */
/*           record length) for recording the IQ data are determined by means*/
/*           of this function.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTraceIQ (ViSession instrSession,
                ViReal64 sampleRate, ViInt32 triggerMode, ViBoolean triggerSlope,
                ViReal64 triggerOffset, ViReal64 recordLength)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViReal64Range (sampleRate, 40.0e3, 32.0e6))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (triggerMode, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (triggerSlope))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (triggerOffset, -590.0e-6, 2.5e-3))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViReal64Range (recordLength, 1.0e-6, 20.4e-3))
        return VI_ERROR_PARAMETER6;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2000000)) { /* available only with option FSIQB70. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":TRACe:IQ:SET RAW,8MHz,%.12f,%s,%s,%.12f,%.12f\n", sampleRate,
             triggerModeArr[triggerMode], triggerSlopeArr[triggerSlope],
             triggerOffset, recordLength);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Resolution BW                                                   */
/* Purpose:  This function controls the setting of the analyzer's resolution */
/*           filter bandwidths. Automatically sets the coupling to manual.   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confResbw (ViSession instrSession, ViInt32 window,
                ViReal64 bwValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (bwValue, 1.0, 10.0e6))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:BAND:RES %.12f\n", window, bwValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Video BW                                                        */
/* Purpose:  This function controls the setting of the analyzer's video      */
/*           filter bandwidths. Automatically sets the coupling to manual.   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMVibw (ViSession instrSession, ViInt32 window,
                ViReal64 bwValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (bwValue, 1.0, 10.0e6))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:BAND:VID %.12f\n", window, bwValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Resolution BW Type                                              */
/* Purpose:  This function sets the resolution bandwidth type.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confResbwType (ViSession instrSession, ViInt32 window,
                ViInt32 resBWType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 17))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (resBWType, 0, 1))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:BWIDTH:RES:FILT %s\n", window,
        resBWTypeArr[resBWType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Coupling Settings                                               */
/* Purpose:  This function controls the setting of the analyzer coupled      */
/*           functions for resolution and video filter.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCoup (ViSession instrSession, ViInt32 window,
                ViInt32 bandwidthOperation, ViInt32 bandwidth,
                ViInt32 resolutionMode, ViInt32 bandwidthPLL, ViReal64 ratio)
{
    ViUInt32 retCnt = 0;
    ViInt32 stat = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    ViReal64 tmp = 0;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (bandwidthOperation, 0, 4))
        return VI_ERROR_PARAMETER3;

    switch (bandwidthOperation) {
        case 0: /* Resolution */
            if (rsfsex_invalidViInt32Range (bandwidth, 0, 3))
                return VI_ERROR_PARAMETER4;
            switch (bandwidth) {
               case 0: case 1:
                    sprintf (buffer, ":SENS%ld:BAND:RES:AUTO %s\n", window,
                        switchArr[bandwidth]);
               break;
               case 2:
                    if (rsfsex_invalidViReal64Range (ratio, 0.0001, 1.0))
                        return VI_ERROR_PARAMETER7;
                    sprintf (buffer, ":SENS%ld:BAND:RES:RAT %.12f\n", window, ratio);
               break;
               case 3:
                    if (rsfsex_invalidViInt32Range (resolutionMode, 0, 3))
                        return VI_ERROR_PARAMETER5;
                     sprintf (buffer, ":SENS%ld:BAND:RES:MODE%s\n",
                        window, resModeArr[resolutionMode]);
               break;
            }
        break;
        case 1: /* Video */
            /* Bandwidth parameter 3 is not allowed */
            if (rsfsex_invalidViInt32Range (bandwidth, 0, 2))
                return VI_ERROR_PARAMETER4;
            switch (bandwidth) {
               case 0: case 1:
                   sprintf (buffer, ":SENS%ld:BAND:VID:AUTO %s\n", window,
                        switchArr[bandwidth]);
               break;
               case 2:
                    if (rsfsex_invalidViReal64Range (ratio, 0.001, 1000.0))
                        return VI_ERROR_PARAMETER7;
                    sprintf (buffer, ":SENS%ld:BAND:VID:RAT %.12f\n", window, ratio);
               break;
            }
        break;
        case 2: /* Sweeptime */
            if (rsfsex_invalidViInt32Range (bandwidth, 0, 1))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:SWE:TIME:AUTO %s\n", window, switchArr[bandwidth]);
        break;
        case 3: /* PLL */
            if (rsfsex_invalidViInt32Range (bandwidthPLL, 0, 3))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":SENS%ld:BAND:PLL %s\n", window,
                bandwidthPLLArr[bandwidthPLL]);
        break;
        case 4: /* Default */
            sprintf (buffer, ":INST%ld:NSEL?\n", window);  /* query mode */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
                return rsfsex_status;

            if (sscanf (buffer, "%ld", &stat) != 1) {
                rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
            else
                if (stat != 1) /* check analyzer mode */ {
                    rsfsex_status = RSFSEX_ERROR_INSTRUMENT_CONFLICT;
                        return rsfsex_status;
                }

            sprintf (buffer, ":SENS%ld:FREQ:SPAN?\n", window); /* query span */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
                return rsfsex_status;

            if (sscanf (buffer, "%le", &tmp) != 1) /* check Zerospan */ {
                rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
            else
                if (tmp == 0.0)  { /* Zerospan */
                    sprintf (buffer, ":SENS%ld:BAND:VID:AUTO ON;"
                    ":SENS%ld:BAND:RES:RAT 0.02;:SENS%ld:BAND:VID:RAT SIN;\n",
                    window, window, window );
                }
                else  { /* Span > 0 */
                    sprintf (buffer, ":SENS%ld:BAND:RES:AUTO ON;:SENS%ld:BAND:VID:AUTO ON;"
                    ":SENS%ld:BAND:RES:RAT 0.02;:SENS%ld:BAND:VID:RAT SIN;"
                    ":SENS%ld:SWE:TIME:AUTO ON\n", window, window, window, window, window );
                }

        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trigger Delay                                                   */
/* Purpose:  This function defines the length of the trigger delay.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTrgDelay (ViSession instrSession, ViInt32 window,
                ViReal64 triggerValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (triggerValue, -100.0, 100.0))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":TRIG%ld:SEQ:HOLD %.12f\n", window, triggerValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Sweep                                                           */
/* Purpose:  This function configures the sweep subsystem.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSweep (ViSession instrSession, ViInt32 window,
                                    ViInt32 sweep, ViInt32 sweepCountValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (sweep, 0, 4))
        return VI_ERROR_PARAMETER3;

    switch (sweep) {
        case 0:
            sprintf (buffer, ":INIT%ld:CONT ON\n", window);
        break;
        case 1:
            sprintf (buffer, ":INIT%ld:CONT OFF\n", window);
        break;
        case 2:
            if (rsfsex_invalidViInt32Range (sweepCountValue, 0, 32767))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:SWE:COUN %ld\n", window, sweepCountValue);
        break;
        case 3:
            sprintf (buffer, ":INIT%ld:DISP ON\n", window);
        break;
        case 4:
            sprintf (buffer, ":INIT%ld:DISP OFF\n", window);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Sweep  Time                                                     */
/* Purpose:  This function controls the setting of the analyzer's sweeptime. */
/*           Automatically sets the coupling to manual.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSweepTime (ViSession instrSession, ViInt32 window,
                                        ViReal64 sweepTime)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (sweepTime, 1.0e-6, 16000.0))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:SWE:TIME %.12f\n", window, sweepTime);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Trigger                                                         */
/* Purpose:  This function configures trigger source and trigger slope.      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTrg (ViSession instrSession, ViInt32 window,
                ViInt32 trigger, ViReal64 triggerValue, ViBoolean triggerSlope)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (trigger, 0, 8))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (triggerSlope))
        return VI_ERROR_PARAMETER5;

    switch (trigger) {
        case 3:
            if (rsfsex_invalidViReal64Range (triggerValue, 0.0, 100.0))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":TRIG%ld:SEQ:LEV:VID %.12f\n", window, triggerValue);
        break;
        case 5:
            if (rsfsex_invalidViReal64Range (triggerValue, -5.0, 5.0))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":TRIG%ld:SEQ:LEV:EXT %.12f\n", window, triggerValue);
        break;
        case 8:
            sprintf (buffer, ":TRIG%ld:SEQ:LEV:AF %.12f\n", window, triggerValue);
        break;
        default:
            sprintf (buffer, ":TRIG%ld:SEQ:SOUR %s;:TRIG%ld:SEQ:SLOP %s\n",
            window, triggerArr[trigger], window, gatePolarityArr[triggerSlope]);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Gate Settings                                                   */
/* Purpose:  This function configures the gate parameters.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMGateSet (ViSession instrSession, ViInt32 window,
                ViBoolean gateSweep, ViReal64 gateLevel, ViBoolean gateMode,
                ViBoolean gatePolarity, ViReal64 gateDelay, ViReal64 gateLength,
                ViBoolean gateSource)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (gateSweep))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (gateLevel, -5.0, 5.0))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViBooleanRange (gateMode))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViBooleanRange (gatePolarity))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViReal64Range (gateDelay, 0.0, 100.0))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViBooleanRange (gateSource))
        return VI_ERROR_INSTR_PARAMETER9;

    sprintf (buffer, ":SENSE%ld:SWE:EGAT:LEV %.12f;TYPE %s;POL %s;HOLD %.12f;SOUR %s;"
        ":SENSE%ld:SWE:EGAT %s", window, gateLevel, gateModeArr[gateMode],
        gatePolarityArr[gatePolarity], gateDelay, gateSourceArr[gateSource],
        window, switchArr[gateSweep]);

    if (gateMode == VI_FALSE) {
        if (rsfsex_invalidViReal64Range (gateLength, 0.0, 100.0))
            return VI_ERROR_PARAMETER8;
        sprintf (buffer, "%s;:SENSE%ld:SWE:EGAT:LENG %.12f", buffer, window,
                 gateLength);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Gap Sweep Settings                                              */
/* Purpose:  This function configures the gap sweep parameters.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSAMGapSweep (ViSession instrSession,
                ViInt32 window, ViBoolean gapSweep, ViReal64 preTriggers,
                ViReal64 gapLengths, ViReal64 trgToGapTimes)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (gapSweep))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (preTriggers, -100.0, 100.0))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (gapLengths, 0.0, 100.0))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViReal64Range (trgToGapTimes, -100.0, 100.0))
        return VI_ERROR_PARAMETER6;

    sprintf (buffer, ":SENS%ld:SWE:GAP:PRET %.12f;LENG %.12f;TRGT %.12f;:SENS%ld:SWE:GAP %s\n",
        window, preTriggers, gapLengths, trgToGapTimes, window, switchArr[gapSweep]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Sweep Spacing                                                   */
/* Purpose:  This function toggles between linear and logarithmic step modes */
/*           of the receiver. In analyzer mode, it toggles between linear and*/
/*           logarithmic sweep. The frequency axis is set to linear or       */
/*           logarithmic scaling accordingly.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSweepSpac (ViSession instrSession, ViInt32 window,
                ViInt32 sweepSpacingMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (sweepSpacingMode, 0, 2))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:SWE:SPAC %s\n", window,
        sweepSpacingModeArr[sweepSpacingMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: RF Input Attenuator                                             */
/* Purpose:  This function configures the attenuator at the instrument's RF  */
/*           input. It switches automatically to manual mode.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInAtt (ViSession instrSession, ViInt32 window,
                ViReal64 attValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (attValue, 0.0, 70.0))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:ATT %.12f;ATT:AUTO OFF\n", window, attValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: RF Input Attenuator Auto                                        */
/* Purpose:  This function configures the attenuator at the instrument's RF  */
/*           input to desired Auto mode.                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInAttAuto (ViSession instrSession,
                ViInt32 window, ViInt32 RFAttenuation)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (RFAttenuation, 0, 3))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:ATT:AUTO ON;AUTO:MODE %s\n", window,
        inpAttAutoModeArr[RFAttenuation]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: RF Input Attenuator Stepsize                                    */
/* Purpose:  This function defines the attenuator stepsize.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInAttStep (ViSession instrSession, ViInt32 window,
                ViInt32 attenuatorStepsize)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (attenuatorStepsize, 0, 1))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x80000)) { /* available only with option FSE-B13 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":INP%ld:ATT:STEP %s\n", window,
             attenuatorStepsizeArr[attenuatorStepsize]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure RF Input Impedance                                    */
/* Purpose:  This function configures the input impedance of the             */
/*           instrument's RF input.                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInImp (ViSession instrSession, ViInt32 window,
                ViInt32 imp)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (imp, 0, 2))
        return VI_ERROR_PARAMETER3;

    switch (imp) {
        case 0:
            sprintf (buffer, ":INP%ld:IMP 50\n", window);
        break;
        case 1:
            sprintf (buffer, ":INP%ld:IMP 75;IMP:CORR RAM\n", window);
        break;
        case 2:
            sprintf (buffer, ":INP%ld:IMP 75;IMP:CORR RAZ\n", window);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: RF Input Coupling                                               */
/* Purpose:  This function switches the input coupling of the RF input       */
/*           between AC and DC.                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInputCoupling (ViSession instrSession,
                ViInt32 window, ViBoolean coupling)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (coupling))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:COUP %s\n", window, (coupling == VI_TRUE) ? "AC" : "DC");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: RF Input                                                        */
/* Purpose:  This function selects the instrument's RF input.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInput (ViSession instrSession, ViInt32 window,
                ViBoolean selectInput)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (selectInput))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:TYPE %s\n", window,
        (selectInput == VI_TRUE) ? "INPUT2" : "INPUT1");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: RF Input Gain                                                   */
/* Purpose:  This function defines the input gain. This function also        */
/*           includes the preamplifier into the autoranging function.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRFInputGain (ViSession instrSession, ViInt32 window,
                ViBoolean autoPreamp, ViReal64 inputGain)
{
    ViUInt32 retCnt = 0;
    ViInt32 state = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    /* Check Analyzer mode. */
    if ((rsfsex_status = rsfsex_waitOPC (instrSession, ":INST:NSEL?\n", buffer, 5000)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%ld", &state) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    
    if (state != 1) {
        /* Check Auto Ranging mode. */
        if ((rsfsex_status = rsfsex_waitOPC (instrSession, ":INP:ATT:AUTO?\n", buffer, 5000)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%ld", &state) != 1)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

        if (state) {
            if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
                return rsfsex_status;
            /* available only with FSE? or ESIB */
            if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
                return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

            if (rsfsex_invalidViInt32Range (window, 1, 2))
                return VI_ERROR_PARAMETER2;
            if (rsfsex_invalidViBooleanRange (autoPreamp))
                return VI_ERROR_PARAMETER3;

            if (inputGain > 0.0)
                sprintf (buffer, ":INP%ld:GAIN:STATE ON;:INP%ld:GAIN:AUTO %s\n",
                    window, window, switchArr[autoPreamp]);
            else
                sprintf (buffer, ":INP%ld:GAIN:STATE OFF\n", window);

            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
        }
    }
    else {
        sprintf (buffer, ":INP%ld:GAIN:STATE %s\n", window,
            (inputGain > 0.0) ? "ON" : "OFF");

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
    }

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Mixer Level                                                     */
/* Purpose:  This function sets the nominal mixer level of the analyzer.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMixerLev (ViSession instrSession, ViInt32 window,
                ViReal64 mixLevel)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (mixLevel, -100.0, -10.0))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:MIX %.12f\n", window, mixLevel);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Mixer Band Lock On                                              */
/* Purpose:  This function switches the external mixer to the "band lock on" */
/*           mode and configures its parameters.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMixBLOn (ViSession instrSession, ViInt32  window,
                ViInt32 band, ViInt32 harmType, ViBoolean ports, ViBoolean convTabUsed,
                ViString convTabName, ViReal64 lossLow, ViReal64 lossHigh,
                ViBoolean biasState, ViReal64 bias)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *p2buffer = buffer;
    ViUInt32    retCnt = 0;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (convTabUsed))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViInt32Range (harmType, 0, 2))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (convTabUsed == VI_FALSE) { /* OFF */
        if (rsfsex_invalidViInt32Range (band, 0, 10))
            return VI_ERROR_PARAMETER3;
        if (rsfsex_invalidViReal64Range (lossLow, 0.0, 100.0))
            return VI_ERROR_PARAMETER8;
        if (rsfsex_invalidViBooleanRange (biasState))
            return VI_ERROR_INSTR_PARAMETER10;
        if (rsfsex_invalidViReal64Range (bias, -10.0, 10.0))
            return VI_ERROR_INSTR_PARAMETER11;
        switch (band)
        {
            case 0: /* A */
                if (rsfsex_invalidViBooleanRange (ports))
                    return VI_ERROR_PARAMETER5;
                if (rsfsex_invalidViReal64Range (lossHigh, 0.0, 100.0))
                    return VI_ERROR_INSTR_PARAMETER9;
                
                p2buffer += sprintf (p2buffer, ":SENS%ld:MIX:BLOC ON;HARM:BAND %s;TYPE %s"
                                               ";:SENS%ld:MIX:PORT %ld;:SENS%ld:MIX:LOSS %.12fDB;:SENS%ld:MIX:BIAS %.12fMA",
                                                window, mixBandArr[band], mixParityArr[harmType], window, ports+2,
                                                window, lossLow, window, biasState*bias);
               /*
                * For Even harmonic type, HIGH Loss can be set.
                */
                if (harmType == 0)
                {
                    p2buffer += sprintf (p2buffer, ";:SENS%ld:MIX:LOSS:HIGH %.12fDB", window, lossHigh);
                }
            break;
            case 1: /* Q */
                if (rsfsex_invalidViBooleanRange (ports))
                    return VI_ERROR_PARAMETER5;
                if (rsfsex_invalidViReal64Range (lossHigh, 0.0, 100.0))
                    return VI_ERROR_INSTR_PARAMETER9;
                p2buffer += sprintf (p2buffer, ":SENS%ld:MIX:BLOC ON;HARM:BAND %s;TYPE %s;"
                                               ":SENS%ld:MIX:PORT %ld;:SENS%ld:MIX:LOSS %.12fDB;:SENS%ld:MIX:BIAS %.12fMA",
                                     window, mixBandArr[band], mixParityArr[harmType], window, ports+2,
                                     window, lossLow, window, biasState*bias);
               /*
                * For Odd harmonic type, HIGH Loss can be set.
                */
                if (harmType == 1)
                {
                    p2buffer += sprintf (p2buffer, ";:SENS%ld:MIX:LOSS:HIGH %.12fDB", window, lossHigh);
                }
            break;
            default:
                sprintf (buffer, ":SENS%ld:MIX:BLOC ON;HARM:BAND %s;TYPE %s"
                    ";:SENS%ld:MIX:PORT %ld;:SENS%ld:MIX:LOSS %.12fDB"
                    ";:SENS%ld:MIX:BIAS %.12fMA", window, mixBandArr[band],
                    mixParityArr[harmType], window, ports+2, window, lossLow,
                    window, biasState*bias);
        }
    }
    else { /* ON */
        if (rsfsex_invalidViInt32Range (band, 0, 10))
            return VI_ERROR_PARAMETER3;
        if (rsfsex_invalidViBooleanRange (biasState))
            return VI_ERROR_INSTR_PARAMETER10;
        if (rsfsex_invalidViReal64Range (bias, -10.0, 10.0))
            return VI_ERROR_INSTR_PARAMETER11;
        switch (band) {
            case 0: /* A */
                if (rsfsex_invalidViBooleanRange (ports))
                    return VI_ERROR_PARAMETER5;
                sprintf (buffer, ":SENS%ld:MIX:BLOC ON;HARM:BAND %s;TYPE %s"
                    ";:SENS%ld:MIX:PORT %ld;:SENS%ld:MIX:BIAS %.12fMA",
                    window, mixBandArr[band], mixParityArr[harmType], window, ports+2,
                    window, biasState*bias);
            break;
            case 1: /* Q */
                if (rsfsex_invalidViBooleanRange (ports))
                    return VI_ERROR_PARAMETER5;
                sprintf (buffer, ":SENS%ld:MIX:BLOC ON;HARM:BAND %s;TYPE %s;"
                ":SENS%ld:MIX:PORT %ld;:SENS%ld:MIX:BIAS %.12fMA",
                window, mixBandArr[band], mixParityArr[harmType], window, ports+2,
                window, biasState*bias);
            break;
            default:
                if (rsfsex_invalidViInt32Range (harmType, 0, 2))
                    return VI_ERROR_PARAMETER4;
                sprintf (buffer, ":SENS%ld:MIX:BLOC ON;HARM:BAND %s;TYPE %s"
                    ";:SENS%ld:MIX:PORT %ld;:SENS%ld:MIX:BIAS %.12fMA",
                    window, mixBandArr[band], mixParityArr[harmType], window, ports+2,
                    window, biasState*bias);
        }

        if (rsfsex_invalidViString (convTabName, 8))
            return VI_ERROR_PARAMETER7;
        sprintf (buffer, "%s;:SENS%ld:MIX:LOSS:TABL '%s'", buffer, window,
                 convTabName);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Mixer Band Lock Off                                             */
/* Purpose:  This function switches the external mixer to the "band lock off"*/
/*           mode and configures its parameters.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMixBLOff (ViSession instrSession, ViInt32 window,
                ViBoolean ports, ViInt32 harmonic, ViReal64 loss,
                ViBoolean biasState, ViReal64 bias)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (ports))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (harmonic, 2, 62))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (loss, 0.0, 100.0))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViBooleanRange (biasState))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViReal64Range (bias, -10.0, 10.0))
        return VI_ERROR_PARAMETER7;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:MIX:BLOC OFF;HARM %ld;LOSS %.12fDB"
        ";:SENS%ld:MIX:PORT %ld;BIAS %.12fMA\n", window, harmonic, loss,
        window, ports+2, biasState*bias);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: External Mixer                                                  */
/* Purpose:  This function enables and configures the external mixer.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMix (ViSession instrSession, ViInt32 window,
                ViBoolean extMixState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (extMixState))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    sprintf (buffer, ":SENS%ld:MIX:STAT %s\n", window, switchArr[extMixState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: External Mixer Signal                                           */
/* Purpose:  This function controls signal ID method.                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMixSignal (ViSession instrSession, ViInt32 window,
                ViInt32 signalID, ViReal64 autoIDThreshold)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (signalID, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (autoIDThreshold, 0.1, 100.0))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    sprintf (buffer, ":SENS%ld:MIX:SIGN %s;:SENS%ld:MIX:THR %.12f\n", window,
        mixSigIDArr[signalID], window, autoIDThreshold);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Default Conversion Loss                                         */
/* Purpose:  This function set default conversion loss value.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDefConvLoss (ViSession instrSession, ViInt32 window)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];
    ViUInt32    retCnt = 0;
    rsfsex_instrRange instrPtr;
    
    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }
    
    sprintf(buffer, ":SENS%ld:MIX:LOSS DEFAULT\n", window);
    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer) , &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;
    
    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Conversion Loss Table                                           */
/* Purpose:  This function creates and/or edits conversion loss table.       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMixLossTab (ViSession instrSession, ViInt32 window,
                ViString name, ViString mixer, ViString SN, ViInt32 band,
                ViInt32 harmType, ViReal64 bias, ViString comment,
                ViBoolean ports, ViInt32 numbOfVals, ViReal64 _VI_FAR freq[],
                ViReal64 _VI_FAR level[])
{
    ViInt32 i = 0;
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViString (name, 8))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViString (mixer, 16))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViString (SN, 16))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViInt32Range (band, 0, 10))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViInt32Range (harmType, 0, 2))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViReal64Range (bias, -10.0, 10.0))
        return VI_ERROR_PARAMETER8;
    if (rsfsex_invalidViString (comment, 60))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rsfsex_invalidViBooleanRange (ports))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rsfsex_invalidViInt32Range (numbOfVals, 1, 50))
        return VI_ERROR_INSTR_PARAMETER11;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    sprintf (buffer, ":SENS%ld:CORR:CVL:SEL '%s';MIX '%s';SNUM '%s'"
        ";BAND %s;TYPE %s;BIAS %.12fMA;COMM '%s'", window, name, mixer, SN,
        mixBandArr[band], mixParityArr[harmType], bias, comment);

    if (ports == VI_TRUE)
        sprintf (buffer, "%s;PORT 3", buffer);
    else
        sprintf (buffer, "%s;PORT 2", buffer);

    sprintf (buffer, "%s;:SENS%ld:CORR:CVL:SEL '%s';DATA ", buffer,  window, name);

    for (i=0; i<numbOfVals; i++)
        sprintf (buffer, "%s%.4Le,%.2Le,", buffer, freq[i], level[i]);

    buffer[strlen (buffer) - 1] = '\n';

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Conversion Loss Table Delete                                    */
/* Purpose:  This function deletes a conversion loss table.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMixLossTabDelete (ViSession instrSession,
                ViInt32 window, ViString name)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViString (name, 8))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:CORR:CVL:SEL \'%s\';CLE\n", window, name);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Conversion Loss Table Catalog                                   */
/* Purpose:  This function reads out the names of all conversion loss tables */
/*           stored on the harddisk.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confExtMixLossTabCat (ViSession instrSession, 
                ViInt32 window, ViPInt32 count, ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViChar   wrtBuffer[BUFFER_SIZE];
    ViUInt32 retCnt;
    ViChar   *buffer = VI_NULL, *p2buffer;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000)) { /* available only with option FSE-B21 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }
    if (bufferSize < 0)
        return VI_ERROR_PARAMETER4;
    if ((bufferSize > 0) && (catalogList == VI_NULL))
        return VI_ERROR_PARAMETER5;

    sprintf (wrtBuffer, "*CLS;:SENS%ld:CORR:CVL:CAT?;*OPC?\n", window);
    
    if ((rsfsex_status = viWrite (instrSession, wrtBuffer, strlen(wrtBuffer), &retCnt)) < 0)
        return rsfsex_status;
        
    if ((rsfsex_status = rsfsex_ReadDataUnknownLength(instrSession, &buffer, &retCnt)) < 0)
        return rsfsex_status;
        
    if ((p2buffer = strchr(buffer, ';')) == VI_NULL)
        p2buffer = buffer;
    
    *p2buffer = '\0';

    /* skip to end of first filename */
    if ((rsfsex_status = rsfsex_ParseCatalog(buffer, count)) < VI_SUCCESS)
    {
        free(buffer);
        if (count) *count = 0;
        return rsfsex_status;
    }

    rsfsex_status = rsfsex_CopyStringBuffer(catalogList, buffer, bufferSize);

    free(buffer);
    
    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;
        
        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Preselector State                                               */
/* Purpose:  This function switches the instruments preselector on or off.   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confPreselState (ViSession instrSession,
                ViInt32 window, ViBoolean preselState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (preselState))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:PRES %s\n", window, switchArr[preselState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Mode                                                    */
/* Purpose:  This function switches the test result display between FULL     */
/*           SCREEN and SPLIT SCREEN.                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDisplayMode (ViSession instrSession,
                ViBoolean displayFormat)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (displayFormat))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, "%s\n", displayFormatArr[displayFormat]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Screen Coupling                                                 */
/* Purpose:  This command defines the coupling between the two measurement   */
/*           windows screen A and B.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confScreenCpl (ViSession instrSession, ViBoolean coupling)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (coupling))
        return VI_ERROR_PARAMETER2;

    if (coupling == VI_TRUE)
        sprintf (buffer, ":INST:COUP ALL\n");
    else
        sprintf (buffer, ":INST:COUP NONE\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Control                                                 */
/* Purpose:  This function controls the apperance of display elements.       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDisplayControl (ViSession instrSession,
                ViBoolean frequency, ViBoolean logo, ViBoolean time,
                ViBoolean displayComment)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (frequency))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (logo))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (time))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViBooleanRange (displayComment))
        return VI_ERROR_PARAMETER5;

    sprintf (buffer, ":DISP:LOGO %s;TIME %s;ANN:FREQ %s;:DISP:TEXT:STAT %s\n",
        switchArr[logo], switchArr[time], switchArr[frequency],
        switchArr[displayComment]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Comment                                                 */
/* Purpose:  This function displays the comment string on the instruments    */
/*           screen.                                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDisplayComment (ViSession instrSession,
                ViString commentString)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViString (commentString, 256))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":DISPLAY:TEXT:DATA '%s'\n", commentString);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Config Display                                                  */
/* Purpose:  This function configures the apperance of display.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDisplayParams (ViSession instrSession,
                ViInt32 displayParameter, ViInt32 colorMap,
                ViInt32 predefinedColors, ViReal64 TINT, ViReal64 SATURATION,
                ViReal64 BRIGHTNESS)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (displayParameter, 0, 2))
        return VI_ERROR_PARAMETER2;

    switch (displayParameter) {
        case 0:
            if (rsfsex_invalidViInt32Range (colorMap, 1, 13))
                return VI_ERROR_PARAMETER3;
            if (rsfsex_invalidViReal64Range (TINT, 0.0, 100.0))
                return VI_ERROR_PARAMETER5;
            if (rsfsex_invalidViReal64Range (SATURATION, 0.0, 100.0))
                return VI_ERROR_PARAMETER6;
            if (rsfsex_invalidViReal64Range (BRIGHTNESS, 0.0, 100.0))
                return VI_ERROR_PARAMETER7;
            sprintf (buffer, ":DISP:CMAP%ld:HSL %.12f,%.12f,%.12f\n",
                colorMap, TINT, SATURATION, BRIGHTNESS);
        break;
        case 1:
            if (rsfsex_invalidViInt32Range (colorMap, 1, 13))
                return VI_ERROR_PARAMETER3;
            if (rsfsex_invalidViInt32Range (predefinedColors, 0, 15))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":DISP:CMAP%ld:PDEF %s\n", colorMap,
                predefinedColorsArr[predefinedColors]);
        break;
        case 2:
            sprintf (buffer, ":DISP:CMAP:DEF\n");
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Update                                                  */
/* Purpose:  This function switches on or off the update of all display      */
/*           elements.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDisplayUpdate (ViSession instrSession,
                ViBoolean displayUpdate)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (displayUpdate))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SYST:DISP:UPD %s\n", switchArr[displayUpdate]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Screen Saver                                            */
/* Purpose:  This function switches the screen saver mode on or off. If mode */
/*           is set to on, then is allowed to determine the time after which */
/*           the screen saver is switched on.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confDisplaySave (ViSession instrSession,
                ViBoolean screenSaver, ViInt32 holdoffTime)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (screenSaver))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (holdoffTime, 1, 100))
        return VI_ERROR_PARAMETER3;

    if (screenSaver == VI_TRUE)
        sprintf (buffer, ":DISP:PSAV:STAT ON;HOLD %ld\n", holdoffTime);
    else
        sprintf (buffer, ":DISP:PSAV OFF\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Setup Transducer                                                */
/* Purpose:  This function configures the transducer parameters.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTransducer (ViSession instrSession,
                ViInt32 trdOperation, ViString trdName, ViBoolean trdFactor)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (trdOperation, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViString (trdName, 8))
        return VI_ERROR_PARAMETER3;

    switch (trdOperation) {
        case 0:
            if (rsfsex_invalidViBooleanRange (trdFactor))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":CORR:TRAN:SEL \'%s\';STAT %s\n", trdName, switchArr[trdFactor]);
        break;
        case 1:
            if (rsfsex_invalidViBooleanRange (trdFactor))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":CORR:TSET:SEL \'%s\';STAT %s\n", trdName, switchArr[trdFactor]);
        break;
        case 2:
            sprintf (buffer, ":CORR:TRAN:SEL \'%s\';DEL\n", trdName);
        break;
        case 3:
            sprintf (buffer, ":CORR:TSET:SEL \'%s\';DEL\n", trdName);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Active Transducer                                           */
/* Purpose:  This function reveals the active transducer factor (set). If no */
/*           transducer factor (set) is switched on, a void string will be   */
/*           output.                                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTransducerGet (ViSession instrSession,
                ViInt32 transducerOperation, ViChar _VI_FAR activeTransducer[])
{
    ViUInt32 retCnt = 0;
    ViChar   buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (transducerOperation, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (activeTransducer == NULL)
        return VI_ERROR_PARAMETER3;

    if (transducerOperation == 0)
        sprintf (buffer, "*CLS;:CORR:TRAN:ACT?\n");
    else
        sprintf (buffer, "*CLS;:CORR:TSET:ACT?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if ((buffer[0] == '\'') && (buffer[1] == '\''))
        *activeTransducer = '\0';
    else if (sscanf (buffer, "'%[^']", activeTransducer) != 1) {
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Setup Transducer Def                                            */
/* Purpose:  This function creates a new transducer factor. The transducer   */
/*           is stored on harddisk any may be activated by function          */
/*           rsfsex_confTransducer                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTransducerDef (ViSession instrSession,
    ViString trdName, ViBoolean trdScaling, ViInt32 trdFactorUnit,
    ViString comment, ViInt32 points, ViReal64 _VI_FAR freqData[],
    ViReal64 _VI_FAR levelData[])
{
    ViUInt32 retCnt = 0;
    ViInt32 i = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViString (trdName, 8))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (trdScaling))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (trdFactorUnit, 0, 8))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViInt32Range (points, 1, 50))
        return VI_ERROR_PARAMETER6;

    if (comment) {
        if (rsfsex_invalidViString (comment, 50))
            return VI_ERROR_PARAMETER5;
        sprintf (buffer, ":CORR:TRAN:SEL \'%s\';COMM \'%s\';SCAL %s;UNIT \'%s\';DATA ",
            trdName, comment, trdScalingArr[trdScaling], trdUnitArr[trdFactorUnit]);
    }
    else {
        sprintf (buffer, ":CORR:TRAN:SEL \'%s\';SCAL %s;UNIT \'%s\';DATA ",
            trdName, trdScalingArr[trdScaling], trdUnitArr[trdFactorUnit]);
    }

    for (i=0; i<points; i++) {
        sprintf (buffer, "%s%.2f,%.12f,", buffer, freqData[i], levelData[i]);
    }

    buffer[strlen (buffer) - 1] = '\n';

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Setup Transducer Set Def                                        */
/* Purpose:  This function creates a new transducer set.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTransducerSetDef (ViSession instrSession,
    ViString transducerSetName, ViInt32 transducerSetUnit,
    ViString transducerSetComment, ViBoolean sweepBreak, ViInt32 noofRanges,
    ViString transducerNames, ViReal64 _VI_FAR rangeStart[],
    ViReal64 _VI_FAR rangeStop[])
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt32    retCnt = 0;
    ViInt32     i = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      tmpBuffer[1024];
    ViChar      *p2buffer, *p2data, *p2end;
    
    if (rsfsex_invalidViString (transducerSetName, 8))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (transducerSetUnit, 0, 8))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (sweepBreak))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViInt32Range (noofRanges, 1, 10))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViString (transducerNames, 1024))
        return VI_ERROR_PARAMETER7;
    
    p2buffer = buffer; 

    if (transducerSetComment)
        {
        if (rsfsex_invalidViString (transducerSetComment, 50))
            return VI_ERROR_PARAMETER4;
            
        p2buffer += sprintf (p2buffer, ":CORR:TSET:SEL \'%s\';COMM \'%s\';UNIT \'%s\';BREAK ",
                 transducerSetName, transducerSetComment,
                 trdUnitArr[transducerSetUnit]);
        }
    else
        {
        p2buffer += sprintf (p2buffer, ":CORR:TSET:SEL \'%s\';UNIT \'%s\';BREAK ",
                 transducerSetName, trdUnitArr[transducerSetUnit]);
        }

    p2buffer += sprintf (p2buffer, "%s;", (sweepBreak == VI_TRUE) ? "ON" : "OFF");

    strcpy(tmpBuffer, transducerNames);
    p2data = tmpBuffer;
    for (i = 0; i < noofRanges && p2data; i++)
    {
        p2end = strchr(p2data, ';');
        if (!p2end && (i+1) < noofRanges)
            return VI_ERROR_PARAMETER7;
        if (p2end) *p2end = '\0';
        p2buffer += sprintf(p2buffer, "RANG%ld %.12fHZ,%.12fHZ,%s;", i+1, rangeStart[i], rangeStop[i], p2data);

        p2data = (p2end) ? p2end + 1 : p2end;
    }

    buffer[strlen (buffer) - 1] = '\n';

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/****************************************************************************
 * Function: Get Transducer Catalog
 * Purpose:  This function reads out the names of all transducer factors
 *           (sets) stored on the harddisk. 
 ****************************************************************************/
ViStatus _VI_FUNC rsfsex_confTransducerCat (ViSession instrSession,
                ViInt32 transducerOperation, ViInt32 *count,
                ViInt32 bufferSize, ViChar _VI_FAR catalogList[])
{
    ViUInt32 retCnt = 0;
    ViChar   *buffer = VI_NULL,
             *p2buffer,
             buffer2[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    
    if (rsfsex_invalidViInt32Range (transducerOperation, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (bufferSize < 0)
        return VI_ERROR_PARAMETER4;
    if ((bufferSize > 0) && (catalogList == VI_NULL))
        return VI_ERROR_PARAMETER5;
    
    sprintf (buffer2, "*CLS;:CORR:T%s:CAT?;*OPC?\n", (transducerOperation == 0) ? "RAN" : "SET");
    
    if ((rsfsex_status = viWrite (instrSession, buffer2, strlen(buffer2), &retCnt)) < 0)
        {
        free(buffer);
        return rsfsex_status;
        }
    if ((rsfsex_status = rsfsex_ReadDataUnknownLength (instrSession, &buffer, VI_NULL)) < 0)
        return  rsfsex_status;

    if ((p2buffer = strchr(buffer, ';')) == VI_NULL)
        p2buffer = buffer;
    
    *p2buffer = '\0';
    
    /* skip to end of first filename */
    if ((rsfsex_status = rsfsex_ParseCatalog(buffer, count)) < VI_SUCCESS)
    {
        free(buffer);
        if (count) *count = 0;
        return rsfsex_status;
    }
    
    rsfsex_status = rsfsex_CopyStringBuffer(catalogList, buffer, bufferSize);

    free(buffer);
    
    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;
        
        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Reference Oscillator                                            */
/* Purpose:  This function selects the reference oscillator, and configures  */
/*           the external frequency if necssary.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confReferenceOsc (ViSession instrSession, ViBoolean source,
                ViInt32 extFreq)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER2;

    if (source == VI_FALSE)
        sprintf (buffer, ":ROSC:SOUR %s\n", refSourceArr[source]);
    else {
        if (rsfsex_invalidViInt32Range (extFreq, 1000000, 16000000))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, ":ROSC:SOUR %s;:ROSC:EXT:FREQ %ld\n",
            refSourceArr[source], extFreq);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Time and Date                                                   */
/* Purpose:  This function configures the instrument's internal clock and    */
/*           calendar.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSystemTime (ViSession instrSession, ViBoolean timeDate,
                ViInt32 hour, ViInt32 minute, ViInt32 second, ViInt32 day,
                ViInt32 month, ViInt32 year)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (timeDate))
        return VI_ERROR_PARAMETER2;

    if (timeDate) { /* time == VI_TRUE */
        if (rsfsex_invalidViInt32Range (hour, 0, 23))
            return VI_ERROR_PARAMETER3;
        if (rsfsex_invalidViInt32Range (minute, 0, 59))
            return VI_ERROR_PARAMETER4;
        if (rsfsex_invalidViInt32Range (second, 0, 59))
            return VI_ERROR_PARAMETER5;
        sprintf (buffer, ":SYST:TIME %ld,%ld,%ld\n", hour, minute, second);
    }
    else {
        if (rsfsex_invalidViInt32Range (day, 1, 31))
            return VI_ERROR_PARAMETER6;
        if (rsfsex_invalidViInt32Range (month, 1, 12))
            return VI_ERROR_PARAMETER7;
        if (rsfsex_invalidViInt32Range (year, 1980, 2099))
            return VI_ERROR_PARAMETER8;
        sprintf (buffer, ":SYST:DATE %ld,%ld,%ld\n", year, month, day);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Hardcopy Options                                                */
/* Purpose:  This function configures the object to print, how to print and  */
/*           the device used to print.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confHCOpt (ViSession instrSession, ViInt32 window,
                ViInt32 output, ViInt32 quadrant, ViBoolean color,
                ViBoolean changeTraceColor)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (output, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (quadrant, 0, 4))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViBooleanRange (color))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViBooleanRange (changeTraceColor))
        return VI_ERROR_PARAMETER6;

    sprintf (buffer, "HCOPY:DEV:COL %s;:HCOPY:PAGE:DIM:%s"
        ";:HCOP:ITEM:WIND%ld:TRAC:CAIN %s", switchArr[color],
        HCQuadrantArr[quadrant], window, switchArr[changeTraceColor]);

    switch (output) {
        case 0:
             sprintf (buffer, "%s;:HCOP:ITEM:ALL", buffer);
        break;
        case 1:
             sprintf (buffer, "%s;:HCOP:ITEM:WIND%ld:TRAC:STAT ON", buffer, window);
        break;
        case 2:
             sprintf (buffer, "%s;:HCOP:ITEM:WIND:TABL:STAT ON", buffer);
        break;
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Hardcopy Comment                                                */
/* Purpose:  Sets the comment lines for screen and comment text for printout */
/*           to trace 1 or 2.                                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confHCComment (ViSession instrSession,
                ViString screenTitle, ViString _1stScreenComment,
                ViString _2ndScreenComment)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    buffer[0] = '\0';

    if (screenTitle) {
        if (rsfsex_invalidViString (screenTitle, 60))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, ":HCOPY:ITEM:LABEL:TEXT '%s'", screenTitle);
    }

    if (_1stScreenComment) {
        if (rsfsex_invalidViString (_1stScreenComment, 100))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, "%s;:HCOPY:ITEM:WIND1:TEXT '%s'", buffer,
                 _1stScreenComment);
    }

    if (_2ndScreenComment) {
        if (rsfsex_invalidViString (_2ndScreenComment, 100))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, "%s;:HCOPY:ITEM:WIND2:TEXT '%s'", buffer,
                 _2ndScreenComment);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Hardcopy Device                                                 */
/* Purpose:  This function selects the interface and configuration for the   */
/*           hardcopy. The destination, data format, paper feed, form feed,  */
/*           and preset are also configured.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confHCDevice (ViSession instrSession,
                ViInt32 deviceNumber, ViInt32 dataFormat, ViInt32 destination,
                ViInt32 GPIBAddress, ViBoolean preset, ViBoolean formFeed,
                ViBoolean paperFeed, ViBoolean resolution, ViBoolean pageOrientation)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (deviceNumber, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (dataFormat, 0, 17))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (destination, 0, 4))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViBooleanRange (preset))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViBooleanRange (formFeed))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViBooleanRange (paperFeed))
        return VI_ERROR_PARAMETER8;
    if (rsfsex_invalidViBooleanRange (resolution))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rsfsex_invalidViBooleanRange (pageOrientation))
        return VI_ERROR_INSTR_PARAMETER10;

    sprintf (buffer,"HCOPY:DEV:LANG%ld %s;:HCOPY:DEST%ld '%s'"
        ";:HCOPY:DEV:PRES%ld %s;:HCOP:ITEM:FFE%ld:STAT %s"
        ";:HCOP:ITEM:PFE%ld:STAT %s;:HCOP:DEV:RES%ld %s;:HCOP:PAGE:ORI%ld %s",
        deviceNumber, dataFormatArr[dataFormat], deviceNumber,
        destinationArr[destination], deviceNumber, switchArr[preset],
        deviceNumber, switchArr[formFeed], deviceNumber, switchArr[paperFeed],
        deviceNumber, (resolution) ? "300" : "150", deviceNumber,
        (pageOrientation) ? "PORT" : "LAND");

    if (destination == 0) /* GPIB */ {
        if (rsfsex_invalidViInt32Range (GPIBAddress, 1, 30))
            return VI_ERROR_PARAMETER5;
        sprintf (buffer,"%s;:SYST:COMM:GPIB:RDEV%ld:ADDR %ld", buffer,
                 deviceNumber, GPIBAddress);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: NT Hardcopy Device                                              */
/* Purpose:  This function selects the interface and configuration for the   */
/*           hardcopy. The destination and data format are also configured.  */
/*           This function is available only for NT based instruments (e.g.  */
/*           FSIQ or FSIG).                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confNTHCDevice (ViSession instrSession,
                ViInt32 deviceNumber, ViInt32 dataFormat,
                ViInt32 destination)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (deviceNumber, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (dataFormat, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (destination, 0, 2))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer,":HCOPY:DEV:LANG%ld %s;:HCOPY:DEST%ld '%s'\n",
        deviceNumber, dataFormatNTArr[dataFormat], deviceNumber,
        destinationNTArr[destination]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Printer List                                                */
/* Purpose:  This function queries the list of printers under Windows NT     */
/*           (e.g. FSIQ or FSIG).                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGetPrinterList (ViSession instrSession,
                ViChar _VI_FAR printerList[])
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if ((rsfsex_status = viWrite (instrSession, "*CLS;:SYST:COMM:PRIN:ENUM:FIRS?\n",
        32, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "'%[^']'", buffer) == 1) {
        /* Get list of printers. */
        do {
            sprintf (printerList, "%s,", buffer);
            if ((rsfsex_status = viWrite (instrSession, "*CLS;:SYST:COMM:PRIN:ENUM:NEXT?\n",
                32, &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
                return rsfsex_status;
        } while (sscanf (buffer, "'%[^']'", buffer) == 1);
        /* Remove remaining coma character */
        printerList[strlen(printerList)-1] = '\0';
    }
    else
        printerList[0] = '\0';

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Set Printer                                                     */
/* Purpose:  This function selects one of the printers installed under       */
/*           Windows NT. Prior to use this function get list of available    */
/*           printers using function Get Printer List (e.g. FSIQ or FSIG).   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSetPrinter (ViSession instrSession,
                ViInt32 deviceNumber, ViString printerName)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (deviceNumber, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViString (printerName, 128))
        return VI_ERROR_PARAMETER3;

    if (deviceNumber == 1)
        sprintf (buffer, "SYST:COMM:PRIN:SEL '%s'\n", printerName);
    else 
        sprintf (buffer, "SYST:COMM:PRIN%ld:SEL '%s'\n", deviceNumber, printerName);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: AF Demod Mode                                                   */
/* Purpose:  This function selects the type of analog demodulation.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confAFDemodMode (ViSession instrSession,
                ViInt32 window, ViInt32 demodMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (demodMode, 0, 2))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:DEM %s\n", window, afDemodModeArr[demodMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Standard                                                */
/* Purpose:  This function configures digital demodulation standards, and is */
/*           only operational when option FSE-B7 is installed.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiSTD (ViSession instrSession, ViInt32 window,
                ViInt32 digitalStandards)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (digitalStandards, 0, 29))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:DDEM:PRES %s\n", window, digiSTDArr[digitalStandards]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Demodulation                                            */
/* Purpose:  This function configures digital demodulation formats, and is   */
/*           only operational when option FSE-B7 is installed.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiDemod (ViSession instrSession,
                ViInt32 window, ViInt32 demodFormat)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (demodFormat, 0, 12))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld%s\n", window, digitModArr[demodFormat]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Demod Parameters                                        */
/* Purpose:  This function configures the digital demodulation measurement   */
/*           filter, reference filter, alpha/BT and symbol rate.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiDemodParam (ViSession instrSession, ViInt32 window,
                ViInt32 measFilter, ViInt32 refFilter, ViReal64 symbolRate,
                ViReal64 alphaBt)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (measFilter, 0, 17))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (refFilter, 0, 16))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (symbolRate, 160.0, 7.0e6))
        return VI_ERROR_PARAMETER5;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:DDEM:FILT:MEAS %s;REF %s;:SENS%ld:DDEM:SRATE %.12f",
        window, measFilterArr[measFilter], refFilterArr[refFilter], window,
        symbolRate);

    if ((measFilter < 4) && (refFilter < 3)) {
        if (rsfsex_invalidViReal64Range (alphaBt, 0.14, 1.0))
            return VI_ERROR_PARAMETER6;
        sprintf (buffer, "%s;:SENS%ld:DDEM:FILT:ALPHA %.12f", buffer, window, alphaBt);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Demod Parameters Def                                    */
/* Purpose:  This function configures additional parameters of the digital   */
/*           demodulation.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiDemodParamDef (ViSession instrSession, ViInt32 window,
    ViBoolean normalize, ViBoolean sideBand, ViReal64 FSKRefDev)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (normalize))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (sideBand))
        return VI_ERROR_PARAMETER4;
    if (FSKRefDev >= 0.0)
        if (rsfsex_invalidViReal64Range (FSKRefDev, 0.0, 4.0e6))
            return VI_ERROR_PARAMETER5;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (FSKRefDev >= 0.0)
        sprintf (buffer, ":SENS%ld:DDEM:NORM %s;SBAN %s;:CALC%ld:FSK:DEV:REF %.12f\n",
            window, switchArr[normalize], sideBandArr[sideBand], window, FSKRefDev);
    else
        sprintf (buffer, ":SENS%ld:DDEM:NORM %s;SBAN %s\n", window, switchArr[normalize],
            sideBandArr[sideBand]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Meas Result Param                                       */
/* Purpose:  This function configures the digital demodulation measurement   */
/*           result parameters. This funciton is only active when option     */
/*           FSE-B7 is installed.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiResultParam (ViSession instrSession,
                ViInt32 window, ViInt32 operation, ViInt32 operationValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (operation, 0, 3))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) /* available only with option FSE-B7 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;

    switch (operation) {
        case 0: /* Result Length */
            if (rsfsex_invalidViInt32Range (operationValue, 10, 1600))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:DDEM:TIME %ld\n", window, operationValue);
        break;
        case 1: /* Frame Length */
            if (rsfsex_invalidViInt32Range (operationValue, 100, 1600))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:DDEM:SEAR:TIME %ld\n", window, operationValue);
        break;
        case 2: /* Memory Size */
            if (rsfsex_invalidViInt32Range (operationValue, 1024, 16384))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:TCAP:LENG %ld\n", window, operationValue);
        break;
        case 3: /* Points per Symbol */
            if (rsfsex_invalidViInt32Range (operationValue, 1, 16))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:DDEM:PRATE %ld\n", window, operationValue);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Meas Result                                             */
/* Purpose:  This function selects the measured data for the vector analyzer */
/*           mode.                                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiResult (ViSession instrSession, ViInt32 window,
    ViInt32 format)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (format, 0, 10))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CALC%ld:FORM %s\n", window, formArr[format]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Sync Sequence Catalog                                   */
/* Purpose:  This function reads out the names of all sync patterns stored on*/
/*           the harddisk.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqCat (ViSession instrSession,
                ViInt32 window, ViPInt32 count, ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViChar   wrtBuffer[BUFFER_SIZE];
    ViUInt32 retCnt;
    ViChar   *buffer = VI_NULL, *p2buffer;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }
    if (bufferSize < 0)
        return VI_ERROR_PARAMETER4;
    if ((bufferSize > 0) && (catalogList == VI_NULL))
        return VI_ERROR_PARAMETER5;

    sprintf (wrtBuffer, "*CLS;:SENS%ld:DDEM:SEAR:SYNC:CAT?;*OPC?\n", window);

    if ((rsfsex_status = viWrite (instrSession, wrtBuffer, strlen (wrtBuffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_ReadDataUnknownLength(instrSession, &buffer, &retCnt)) < 0)
        return rsfsex_status;

    if ((p2buffer = strchr(buffer, ';')) == VI_NULL)
        p2buffer = buffer;
    
    *p2buffer = '\0';
    
    /* skip to end of first filename */
    if ((rsfsex_status = rsfsex_ParseCatalog(buffer, count)) < VI_SUCCESS)
    {
        free(buffer);
        if (count) *count = 0;
        return rsfsex_status;
    }

    rsfsex_status = rsfsex_CopyStringBuffer(catalogList, buffer, bufferSize);

    free(buffer);
    
    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;
        
        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Sync Sequence Meas Only                                 */
/* Purpose:  This function is used to sets (On) that the analyzer measured   */
/*           values are displayed and taken into account in the error        */
/*           analysis only if the set sync pattern is found. Bursts with a   */
/*           wrong sync pattern (sync not found) are ignored.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqMOnly (ViSession instrSession, 
                ViInt32 window, ViBoolean measOnly)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (measOnly))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:DDEM:SEAR:SYNC:MONL %s\n", window, switchArr[measOnly]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Vector Signal Analysis Mode                                     */
/* Purpose:  This function selects the operating mode in vector signal       */
/*           analysis.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDemodMode (ViSession instrSession, ViInt32 window,
    ViInt32 opMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (opMode, 0, 11))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CALC%ld:FEED '%s'\n", window, analogMeasResArr[opMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analog Summary Settings                                         */
/* Purpose:  This function controls the modulation summary setting for analog*/
/*           demodulation.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMSumSet (ViSession instrSession, ViInt32 window,
    ViInt32 parameter, ViBoolean state, ViBoolean indMode, ViReal64 refValue,
    ViBoolean measTime)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (parameter, 0, 4))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (parameter)
        {
        case 0: /* Average Hold */
            if (rsfsex_invalidViBooleanRange (state))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:MSUM:AHOL %s\n", window, switchArr[state]);
            break;
        case 1: /* Measurement Indication */
            if (rsfsex_invalidViBooleanRange (indMode))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":SENS%ld:MSUM:MODE %s\n", window, modeArr[indMode]);
            break;
        case 2: /* Summary Time */
            if (rsfsex_invalidViBooleanRange (measTime))
                return VI_ERROR_PARAMETER7;
            sprintf (buffer, ":SENS%ld:MSUM:MTIM %s\n", window, measTimeArr[measTime]);
            break;
        case 3: /* Reference Modulation */
            if (rsfsex_invalidViReal64Range (refValue, 0.0001, 1000.0))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":SENS%ld:MSUM:REF %.12f\n", window, refValue);
            break;
        case 4: /* SINAD Measurement */
            if (rsfsex_invalidViBooleanRange (state))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":CALC%ld:MARK:FUNC:ADEM:SIN %s\n", window, switchArr[state]);
            break;
        }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Modulation Summary Units                                        */
/* Purpose:  This function selects the relative unit of the summary marker in*/
/*           the relative result display.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMSumSetUnits (ViSession instrSession,
                ViInt32 window, ViBoolean markerUnits)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (markerUnits))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:MSUM:RUN %s\n", window,
        (markerUnits == VI_FALSE) ? "DB" : "PCT");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Trigger                                                 */
/* Purpose:  This function configures the digital demodulation trigger       */
/*           parameters.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiTrg (ViSession instrSession, ViInt32 window,
                ViBoolean findBurst, ViBoolean findSync)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (findBurst))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (findSync))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:DDEM:SEAR:PULS:STAT %s;:SENS%ld:DDEM:SEAR:SYNC:STAT %s\n",
        window, switchArr[findBurst], window, switchArr[findSync]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Sequence  Offset                                        */
/* Purpose:  This function defines the offset of the display with reference  */
/*           to the synchronization sequence.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqOffset (ViSession instrSession,
                ViInt32 window, ViInt32 syncOffset)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (syncOffset, -1600, 1600))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:DDEM:SEAR:SYNC:OFFSET %ld\n", window, syncOffset);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Sync Sequence                                           */
/* Purpose:  This function defines the synchronization sequence. A file that */
/*           has been set previously by the function Digital Sync Sequence   */
/*           Sel (confVSAMDigiSeqSel) becomes invalid.                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeq (ViSession instrSession, ViInt32 window,
                ViString syncPattern)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViString (syncPattern, 256))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:DDEM:SEAR:SYNC:PATT \"%s\"\n", window, syncPattern);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Digital Sync Sequence Sel                                       */
/* Purpose:  This function handles synchronization sequence operations       */
/*           (selects, creates or deletes synchronization sequence by name). */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDigiSeqSel (ViSession instrSession,
                ViInt32 window, ViInt32 operation, ViString patternName,
                ViString comment, ViString syncPattern)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (operation, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViString (patternName, 8))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (operation) {
        case 0: /* Select Pattern */
            sprintf (buffer, ":SENS%ld:DDEM:SEAR:SYNC:SEL '%s'\n", window, patternName);
        break;
        case 1: /* Create Pattern */
            if (rsfsex_invalidViString (comment, 60))
                return VI_ERROR_PARAMETER5;
            if (rsfsex_invalidViString (syncPattern, 328))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":SENS%ld:DDEM:SEAR:SYNC:NAME '%s';COMM '%s';DATA '%s'\n",
                window, patternName, comment, syncPattern);
        break;
        case 2: /* Delete Pattern */
            sprintf (buffer, ":SENS%ld:DDEM:SEAR:SYNC:DEL '%s'\n", window, patternName);
        break;
    }
    
    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analog Demodulation Parameters                                  */
/* Purpose:  This function controls realtime/offline operation, AF coupling  */
/*           and sideband of analog demodulation function.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMADemodParam (ViSession instrSession, ViInt32 window,
                ViInt32 parameter, ViBoolean AFCoupling, ViBoolean sideBand,
                ViBoolean realTime)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (parameter, 0, 2))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (parameter)
        {
        case 0: /* Realtime */
            if (rsfsex_invalidViBooleanRange (realTime))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":SENS%ld:ADEM:RTIM %s\n", window, switchArr[realTime]);
            break;
        case 1: /* Side Band */
            if (rsfsex_invalidViBooleanRange (sideBand))
                return VI_ERROR_PARAMETER5;
            sprintf (buffer, ":SENS%ld:ADEM:SBAN %s\n", window, sideBandArr[sideBand]);
            break;
        case 2: /* AF Coupling */
            if (rsfsex_invalidViBooleanRange (AFCoupling))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:ADEM:AF:COUP %s\n", window, AFCouplingArr[AFCoupling]);
            break;
        }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analog Demodulation Filter                                      */
/* Purpose:  This function selects the filters for AF signal path for        */
/*           analog demodulation.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDemodFilt (ViSession instrSession, ViInt32 window,
                ViInt32 filterType, ViBoolean filterState, ViInt32 filterFreq,
                ViInt32 AMFMDeemphVal, ViBoolean deemphasisLink)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (filterType, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (filterState))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (filterType) {
        case 0: /* High Pass AF Filter */
            if (filterState == VI_TRUE) {
                if (rsfsex_invalidViInt32Range (filterFreq, 5, 15000))
                    return VI_ERROR_PARAMETER5;
                sprintf (buffer, ":SENS%ld:FILT:HPAS:STAT ON;FREQ %ld\n",
                    window, filterFreq);
            }
            else
                sprintf (buffer, ":SENS%ld:FILT:HPAS:STAT OFF\n", window);
        break;
        case 1: /* Low Pass AF Filter */
            if (filterState == VI_TRUE) {
                if (rsfsex_invalidViInt32Range (filterFreq, 5, 15000))
                    return VI_ERROR_PARAMETER5;
                sprintf (buffer, ":SENS%ld:FILT:LPAS:STAT ON;FREQ %ld\n",
                    window, filterFreq);
            }
            else
                sprintf (buffer, ":SENS%ld:FILT:LPAS:STAT OFF\n", window);
        break;
        case 2: /* AM/FM Deemphasis */
            if (rsfsex_invalidViInt32Range (AMFMDeemphVal, 0, 2))
                return VI_ERROR_PARAMETER6;
            if (rsfsex_invalidViBooleanRange (deemphasisLink))
                return VI_ERROR_PARAMETER7;
            sprintf (buffer, ":SENS%ld:FILT:DEMP:STAT %s;TCON %s;LINK %s\n",
                window, switchArr[filterState], AMFMDeemphValArr[AMFMDeemphVal],
                deemphasisLinkArr[deemphasisLink]);
        break;
        case 3: /* Weighting AF Filter - CCITT */
            sprintf (buffer, ":SENS%ld:FILT:CCIT %s\n",
                window, switchArr[filterState]);
        break;
        case 4: /* Weighting AF Filter - C-Message */
            sprintf (buffer, ":SENS%ld:FILT:CMES %s\n",
                window, switchArr[filterState]);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analog Demodulation Bandwidth                                   */
/* Purpose:  This function controls the demodulation bandwidth.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDemodBW (ViSession instrSession, ViInt32 window,
                ViReal64 demodBW)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (demodBW, 5.0E3, 3.0E6))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:BWID:DEM %.12fHZ\n", window, demodBW);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analog Demodulation Squelch                                     */
/* Purpose:  This function controls the additional demodulation parameters.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDemodSq (ViSession instrSession, ViInt32 window,
    ViInt32 demodParam, ViBoolean squelchState, ViReal64 parValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (demodParam, 0, 3))
        return VI_ERROR_PARAMETER3;

    switch (demodParam)
        {
        case 0: /* Squelch State */
            if (rsfsex_invalidViReal64Range (parValue, -5.0E9, +5.0E9))
                return VI_ERROR_PARAMETER5;
            break;
        case 1: /* Squelch Value */
            if (rsfsex_invalidViReal64Range (parValue, -5.0E9, +5.0E9))
                return VI_ERROR_PARAMETER5;
            break;
        case 2: /* Volume */
            if (rsfsex_invalidViReal64Range (parValue, 0.0, 1.0))
                return VI_ERROR_PARAMETER5;
            break;
        case 3: /* AF Output Sens */
            if (rsfsex_invalidViReal64Range (parValue, 0.0, 100.0))
                return VI_ERROR_PARAMETER5;
            break;
        default:
            return VI_ERROR_PARAMETER3;
        }

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (demodParam) {
        case 0: /* Squelch State */
            if (rsfsex_invalidViInt32Range (window, 1, 2))
                return VI_ERROR_PARAMETER2;
            if (rsfsex_invalidViBooleanRange (squelchState))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":SENS%ld:ADEM:SQU %s\n", window, switchArr[squelchState]);
        break;
        case 1: /* Squelch Value */
            if (rsfsex_invalidViInt32Range (window, 1, 2))
                return VI_ERROR_PARAMETER2;
            sprintf (buffer, ":SENS%ld:ADEM:SQU:LEV %.12fDBM\n", window, parValue);
        break;
        case 2: /* Volume */
            sprintf (buffer, ":SYST:SPE:VOL %.12f\n", parValue);
            break;
        case 3: /* AF Output Sens */
            if (rsfsex_invalidViInt32Range (window, 1, 2))
                return VI_ERROR_PARAMETER2;
            sprintf (buffer, ":OUTP%ld:AF:SENS %.12f\n", window, parValue);
        break;
        default:
            return VI_ERROR_PARAMETER3;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Vector Signal Analysis Display                                  */
/* Purpose:  This function configures the reference value position.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDisp (ViSession instrSession, ViInt32 window,
                ViInt32 refValOper, ViReal64 refValueX, ViReal64 refValueY,
                ViReal64 refValuePos, ViReal64 YperDivision)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (refValOper, 0, 3))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1F0)) { /* available only with option FSE-B7, FSE-B8..B11 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (refValOper) {
        case 0: /* X */
            if (rsfsex_invalidViReal64Range (refValueX, -1.0E12, 1.0E12))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":DISP:WIND%ld:TRAC:X:RVAL %.12f\n", window, refValueX);
        break;
        case 1: /* Y */
            if (rsfsex_invalidViReal64Range (refValueY, -1.0E12, 1.0E12))
                return VI_ERROR_PARAMETER5;
            if (rsfsex_invalidViReal64Range (refValuePos, 0.0, 100.0))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:RVAL %.12f;RPOS %.12f\n",
                window, refValueY, refValuePos);
        break;
        case 2: /* X and Y */
            if (rsfsex_invalidViReal64Range (refValueX, -1.0E12, 1.0E12))
                return VI_ERROR_PARAMETER4;
            if (rsfsex_invalidViReal64Range (refValueY, -1.0E12, 1.0E12))
                return VI_ERROR_PARAMETER5;
            if (rsfsex_invalidViReal64Range (refValuePos, 0.0, 100.0))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:RVAL %.12f;RPOS %.12f"
                ";:DISP:WIND%ld:TRAC:X:RVAL %.12f\n", window, refValueY,
                refValuePos, window, refValueX);
        break;
        case 3:
            if (rsfsex_invalidViReal64Range (YperDivision, -1.0E12, 1.0E12))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:PDIV %.12f\n", window, YperDivision);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Display Scaling Mode                                            */
/* Purpose:  This function selects seconds or symbols as an x-axis unit.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMDispScalingMode (ViSession instrSession,
                ViInt32 window, ViBoolean scalingMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (scalingMode))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CALC%ld:X:UNIT:TIME %s\n", window, (scalingMode) ? "SYM" : "S");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker Coupled                                                  */
/* Purpose:  This function couples markers (and delta markers) of different  */
/*           traces in the combined display mode REAL/IMAG PAR. In this case */
/*           the X position of corresponding markers is identical.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confVSAMarkCoupled (ViSession instrSession,
                ViInt32 window, ViBoolean couplingMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (couplingMode))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CALC%ld:MARK:COUP %s\n", window, switchArr[couplingMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Tracking Generator Src Values                                   */
/* Purpose:  This function configures tracking generator source values.      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTrackSrc (ViSession instrSession, ViInt32 window,
                ViInt32 setSrcValue, ViReal64 srcValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (setSrcValue, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (srcValue, -200.0e6, 200.0e6))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1E0)) { /* available only with option FSE-B8..B11 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SOUR%ld:%s %.12f\n", window, setSrcValueArr[setSrcValue], srcValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Tracking Generator Display                                      */
/* Purpose:  This function configures the reference value position.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTrackDisp (ViSession instrSession,
                ViInt32 window, ViReal64 refValuePos, ViReal64 refValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (refValuePos, 0.0, 100.0))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (refValue, -200.0, 200.0))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1F0)) { /* available only with option FSE-B7, FSE-B8..B11 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:RVAL %.12f;RPOS %.12f\n", window, refValue, refValuePos);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Tracking Generator Modulation                                   */
/* Purpose:  This function switches on or off the external modulations of the*/
/*           tracking generator.                                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTrackModulation (ViSession instrSession, ViInt32 window,
                ViInt32 modulation, ViBoolean modState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (modulation, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (modState))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1E0)) { /* available only with option FSE-B8..B11 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (modulation != 3)
        sprintf (buffer, ":SOUR%ld:%s %s\n", window, modulationArr[modulation],
             switchArr[modState]);
    else
        sprintf (buffer, ":SOUR%ld:%s %s\n", window, modulationArr[modulation],
            refSourceArr[modState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: TV Mode Trigger Config                                          */
/* Purpose:  This function is used to synchronize instrument actions with    */
/*           events in TV - demodulation mode.                               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTVTrgSeq (ViSession instrSession, ViInt32 window,
                ViBoolean syncType, ViInt32 verticalSync, ViInt32 horizSyncVal,
                ViBoolean videoPolarity, ViBoolean lineSystem)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (syncType))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (videoPolarity))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViBooleanRange (lineSystem))
        return VI_ERROR_PARAMETER7;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2)) { /* available only with option FSE-B3 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (syncType == VI_TRUE) { /* horizontal */
        if (rsfsex_invalidViInt32Range (horizSyncVal, 0, 1024))
           return VI_ERROR_PARAMETER5;
        sprintf (buffer, ":TRIG%ld:SEQ:VID:LINE:NUMB %ld", window, horizSyncVal);
    }
    else { /* vertical */
        if (rsfsex_invalidViInt32Range (verticalSync, 0, 2))
            return VI_ERROR_PARAMETER4;
        sprintf (buffer, ":TRIG%ld:SEQ:VID:FIEL:SEL %s", window,
            verticalSyncArr[verticalSync]);
    }

    sprintf (buffer, "%s;:TRIG%ld:SEQ:VID:FORM:LPFR %s;:TRIG%ld:SEQ:VID:SSIG:POL %s",
             buffer, window, lineSystemArr[lineSystem], window,
             gatePolarityArr[videoPolarity]);

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: TV Mode Pict Sound Offset                                       */
/* Purpose:  This function defines the frequency offset between video and    */
/*           audio carrier of the measured signal.                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confTVPSOffset (ViSession instrSession, ViInt32 window,
                ViReal64 offset)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (offset, 0.0, 6.5e6))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2)) { /* available only with option FSE-B3 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:TV:PSOF %.12f\n", window, offset);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Modulation Type                                              */
/* Purpose:  This function selects the modulation type (GMSK or EDGE (8PSK)).*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSModType (ViSession instrSession,
                ViBoolean modulationType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (modulationType))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:MTYP %s\n", mTypeArr[modulationType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Modulation Type                                             */
/* Purpose:  This function selects the modulation type (GMSK or EDGE (8PSK)).*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSModType (ViSession instrSession,
                ViBoolean modulationType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (modulationType))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:MTYP %s\n", mTypeArr[modulationType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Set Ext Attenuator                                          */
/* Purpose:  This function announces to the instrument a possibly needed     */
/*           external attenuation of the input signal, so that it is taken   */
/*           into account later when the level is set.                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMExtAttn (ViSession instrSession, ViReal64 extAttn)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViReal64Range (extAttn, -100.0, 100.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:CORR:LOSS:INP:MAGN %.12f\n", extAttn);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Power Settings                                              */
/* Purpose:  This function selects BTS power values to be changed.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSPower (ViSession instrSession, ViInt32 BTSPower,
                ViReal64 powerValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (BTSPower, 0, 7))
        return VI_ERROR_PARAMETER2;

    switch (BTSPower) {
        case 1: case 2: case 3:
            sprintf (buffer, ":CONF:BTS:POW:CLAS M%ld\n", BTSPower);
        break;
        case 7:
            sprintf (buffer, ":CONF:BTS:POW:CLAS P1\n");
        break;
        default:
            if (rsfsex_invalidViReal64Range (powerValue, 0.0, 47.0))
                return VI_ERROR_PARAMETER3;
            sprintf (buffer, ":CONF:BTS:POW:%s %.12f\n", BTSPowerArr[BTSPower], powerValue);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Power Settings                                               */
/* Purpose:  This function selects MS power values to be changed.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSPower (ViSession instrSession, ViInt32 MSPower,
                ViReal64 powerValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (MSPower, 0, 5))
        return VI_ERROR_PARAMETER2;
/*
    if (rsfsex_invalidViReal64Range (powerValue, 0.0, 49.0))
        return VI_ERROR_PARAMETER3;
*/
    switch (MSPower) {
        case 0:
            sprintf (buffer, ":CONF:MS:POW:CLAS %.0f\n", powerValue);
        break;
        case 1:
            sprintf (buffer, ":CONF:MS:POW:LEV %.12f\n", powerValue);
        break;
        case 2:
            sprintf (buffer, ":CONF:MS:POW:EXP %.12f\n", powerValue);
        break;
        case 3:
            sprintf (buffer, ":CONF:MS:POW:CLAS EG1\n");
        break;
        case 4:
            sprintf (buffer, ":CONF:MS:POW:CLAS EG2\n");
        break;
        case 5:
            sprintf (buffer, ":CONF:MS:POW:CLAS EG3\n");
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Small                                                        */
/* Purpose:  This command switches the limits for spurious measurement in the*/
/*           RGSM range. The command is available only for Phase II+.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSSmall (ViSession instrSession, ViBoolean limits)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (limits))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:POW:SMAL %s\n", switchArr[limits]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Limit Line Ref Power                                         */
/* Purpose:  This function defines the level for the selection of            */
/*           level-dependent limit lines.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSPowerLline (ViSession instrSession,
                ViReal64 refPowerValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViReal64Range (refPowerValue, 0.0, 60.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:POW:LIM %.12f\n", refPowerValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Limit Line Ref Power                                        */
/* Purpose:  This function defines the level for the selection of            */
/*           level-dependent limit lines.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSPowerLline (ViSession instrSession,
                ViReal64 refPowerValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViReal64Range (refPowerValue, 0.0, 60.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:POW:LIM %.12f\n", refPowerValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Error Limits                                                 */
/* Purpose:  For the modulation accuracy measurement, only the values for    */
/*           RMS EVM, PEAK EVM, ORIG OFFSET SUPPRESSION, 95:th PERCENTILE and*/
/*           FREQUENCY are entered instead of limit lines (available for     */
/*           option FSE-K20). For the phase/frequency measurement PPE (phase */
/*           peak value), PRMS (phase mean value) and FREQUENCY (frequency   */
/*           error limits) are only available values (available for option   */
/*           FSE-K10).                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSErrLim (ViSession instrSession,
                ViInt32 errorLimit, ViReal64 errorLimitValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (errorLimit, 0, 6))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (errorLimitValue, 0.0, 1000.0))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CONF:MS:LIM:%s %.12f\n", errorLimitArr[errorLimit],
        errorLimitValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Error Limits                                                */
/* Purpose:  For the modulation accuracy measurement, only the values for    */
/*           RMS EVM, PEAK EVM, ORIG OFFSET SUPPRESSION, 95:th PERCENTILE and*/
/*           FREQUENCY are entered instead of limit lines (available for     */
/*           option FSE-K21). For the phase/frequency measurement PPE (phase */
/*           peak value), PRMS (phase mean value) and FREQUENCY (frequency   */
/*           error limits) are only available values (available for option   */
/*           FSE-K11).                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSErrLim (ViSession instrSession,
                ViInt32 errorLimit, ViReal64 errorLimitValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (errorLimit, 0, 6))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (errorLimitValue, 0.0, 1000.0))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CONF:BTS:LIM:%s %.12f\n", errorLimitArr[errorLimit],
        errorLimitValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS User Limits                                                  */
/* Purpose:  This function switches between user-defined (OFF) and           */
/*           standard-defined (ON) limit values.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSErrLimUser (ViSession instrSession,
                ViBoolean limits)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (limits))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:LIM:STAN %s\n", switchArr[(limits) ? 0 : 1]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS User Limits                                                 */
/* Purpose:  This function switches between user-defined (OFF) and           */
/*           standard-defined (ON) limit values.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSErrLimUser (ViSession instrSession,
                ViBoolean limits)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (limits))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:LIM:STAN %s\n", switchArr[(limits) ? 0 : 1]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Spurious Range                                              */
/* Purpose:  This function provides commands for configuring the measurements*/
/*           in the GSM BTS (FSE-K11) or GSM MS (FSE-K10) Analyzer mode used */
/*           for measuring the power of spurious emissions.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMSpurRange (ViSession instrSession,
                ViInt32 spurParam)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (spurParam, 0, 4))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:SPUR:RANG %s\n", spurParamArr[spurParam]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Spurious Emissions                                          */
/* Purpose:  This function selects the features of the measurement of        */
/*           spurious emissions.                                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMSpurEmi (ViSession instrSession,
                ViBoolean antenna)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (antenna))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:SPUR:ANT %s\n", antennaArr[antenna]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Set Spurious Step                                           */
/* Purpose:  This function selects a subband of the selected band for a      */
/*           spurious measurement. Each band is divided up into 1 to max. 26 */
/*           subbands. A subband is selected for measurement by setting ON.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMSpurStep (ViSession instrSession,
                ViInt32 subbandNumber, ViBoolean measurementState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (subbandNumber, 1, 26))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (measurementState))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CONF:SPUR:STEP%ld %s\n", subbandNumber,
        switchArr[measurementState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS SHF                                                          */
/* Purpose:  This function defines whether the base station uses slow        */
/*           frequency hopping or not.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSSFH (ViSession instrSession, ViBoolean mode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (mode))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:CHAN:SFH %s\n", switchArr[mode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS SHF                                                         */
/* Purpose:  This function defines whether the base station uses slow        */
/*           frequency hopping or not.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSSFH (ViSession instrSession, ViBoolean mode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (mode))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:CHAN:SFH %s\n", switchArr[mode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Cositing                                                    */
/* Purpose:  This function selects whether the base station has the          */
/*           "cositing" feature.                                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSCositing (ViSession instrSession, ViBoolean cositing)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (cositing))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:COS %s\n", switchArr[cositing]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Number of Bursts                                            */
/* Purpose:  This function defines the number of bursts used for determining */
/*           the average and maximum values.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMNoCnt (ViSession instrSession,
                ViInt32 countParameter, ViInt32 numbCnt)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (countParameter, 0, 7))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (numbCnt, 1, 1000))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "%s %ld\n", countParameterArr[countParameter], numbCnt);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Burst PWR Condition                                         */
/* Purpose:  This function defines the conditions for power measurement.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMPowCond (ViSession instrSession,
                ViBoolean PWRMeasConditon)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (PWRMeasConditon))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BURS:POW:COND %s\n", PWRMeasConditonArr[PWRMeasConditon]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Burst Phase Freq Condition                                  */
/* Purpose:  This function defines the conditions for phase-frequency        */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMPFerCond (ViSession instrSession,
                ViBoolean conditions)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (conditions))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BURS:PFER:COND %s\n", conditionsArr[conditions]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Burst Reference                                             */
/* Purpose:  This function switches between automatic and user-activated     */
/*           preview of power versus time. When switched to On, the preview  */
/*           is always performed, when switched to Off it is omitted.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMBurstRef (ViSession instrSession, 
                ViBoolean burstReferenceAuto)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (burstReferenceAuto))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BURS:REF:AUTO %s\n", switchArr[burstReferenceAuto]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Spectrum Mod Range                                          */
/* Purpose:  This function selects the frequency range for the measurement.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMModRange (ViSession instrSession,
                ViInt32 modRange)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (modRange, 0, 6))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:SPEC:MOD:RANG %s\n", modRangeArr[modRange]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM RX Band Gain                                                */
/* Purpose:  This function announces to the instrument a possibly needed     */
/*           preamplification in the RX-band (RX BAND GAIN), so that it is   */
/*           taken into account later when the measured values are read out. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMRXBandGain (ViSession instrSession,
                ViReal64 RXBandGain)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViReal64Range (RXBandGain, -200.0, 200.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:CORR:RXG:INP:MAGN %.12f\n", RXBandGain);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM TX Gate                                                     */
/* Purpose:  This function switches gating in the TX band on or off. If      */
/*           gating is switched off, all 8 slots should be active.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMTXGate (ViSession instrSession,
                ViBoolean gatingState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (gatingState))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:SPEC:MOD:TGAT %s\n", switchArr[gatingState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Trigger Sync Source                                         */
/* Purpose:  This function defines the trigger reference point for           */
/*           measurements in the time domain (carrier power, power vs. time).*/
/*           The frame trigger of the base station or mobile may be selected */
/*           as well as the relation to the midamble (TSC) of the slot to be */
/*           measured.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMSyncSrc (ViSession instrSession,
                ViBoolean syncToMidamble)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (syncToMidamble))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":TRIG:SEQ:SYNC:SOUR %s\n", syncToMidambleArr[syncToMidamble]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analyzer Mode                                                   */
/* Purpose:  This function sets the instrument to the spectrum analyzer mode.*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMode (ViSession instrSession, ViInt32 window)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":INST%ld:SEL SAN\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Sweeptime                                                    */
/* Purpose:  This function selects the sweep-time computing mode for the     */
/*           spurious measurement.                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confMSSweeptime (ViSession instrSession,
                ViBoolean sweepTime)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (sweepTime))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:SWE %s\n", sweepTimeArr[sweepTime]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Sweeptime                                                   */
/* Purpose:  This function selects the sweep-time computing mode for the     */
/*           spurious measurement.                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSSweeptime (ViSession instrSession,
                ViBoolean sweepTime)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (sweepTime))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:SWE %s\n", sweepTimeArr[sweepTime]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Station Type                                                */
/* Purpose:  This function selects base station type (normal, micro or pico).*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confBTSStationType (ViSession instrSession,
                ViInt32 BTSType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (BTSType, 0, 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:STYP %s\n", BTSTypeArr[BTSType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Conditions                                                  */
/* Purpose:  This function defines the conditions for modulation accuracy    */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMCondition (ViSession instrSession,
                ViBoolean conditions)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (conditions))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BURS:MACC:COND %s\n", conditionsArr[conditions]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Measurement Bandwidth                                       */
/* Purpose:  This function defines the measurement bandwidth.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confGSMMeasBW (ViSession instrSession,
                ViInt32 measBW)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];
    
    if (rsfsex_invalidViInt32Range (measBW,0 , 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:BAND:RES %s\n", gsmMeasBWArr[measBW]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), VI_NULL)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Receiver Input Attenuator Auto                                  */
/* Purpose:  This function automatically couples the input attenuation to the*/
/*           reference level (analyzer) or activates the auto range function */
/*           (receiver).                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECInAttAuto (ViSession instrSession, ViInt32 window,
                ViBoolean attMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (attMode))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INP%ld:ATT:AUTO %s\n", window, switchArr[attMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Receiver Frequency                                              */
/* Purpose:  This control defines the receiver frequency and step width of   */
/*           the receiver frequency.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECFreq (ViSession instrSession, ViReal64 recFreq,
                ViReal64 stepWidth)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":SENS:FREQ:CW %.12f;CW:STEP %.12f\n", recFreq, stepWidth);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Receiver Coupling                                               */
/* Purpose:  This function sets the coupling of the receiver settings        */
/*           from the concerning subscans to the marker frequency to on or   */
/*           off.                                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECCoupling (ViSession instrSession,
                ViBoolean markerTrack, ViBoolean settingsCoupled)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViBooleanRange (markerTrack))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (settingsCoupled))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CALC:MARK:COUP %s;:CALC:MARK:SCO %s\n", switchArr[markerTrack],
        switchArr[settingsCoupled]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Advanced Detector                                               */
/* Purpose:  This function controls the recording of measurement values via  */
/*           the type of detector selected for each trace in receiver mode.  */
/*           All four detectors may be switched on simultaneously.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECDetector (ViSession instrSession,
                ViBoolean maxPeak, ViBoolean minPeak, ViBoolean average,
                ViBoolean RMS, ViBoolean ACV, ViBoolean QPE, ViBoolean QPECoupling)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViBooleanRange (maxPeak))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (minPeak))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (average))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViBooleanRange (RMS))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViBooleanRange (ACV))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViBooleanRange (QPE))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViBooleanRange (QPECoupling))
        return VI_ERROR_PARAMETER8;

    /* Max four detector can be switched simultaneosly. */
    if (((maxPeak+minPeak+average+RMS+ACV+QPE) > 4) ||
        ((maxPeak+minPeak+average+RMS+ACV+QPE) == 0))
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;
    
    sprintf (buffer, ":SENS:BAND:RES:AUTO %s;:SENS:DET:REC %s%s%s%s%s%s",
        switchArr[QPECoupling],
        (maxPeak) ? "POS," : "", (minPeak) ? "NEG," : "",
        (average) ? "AVER," : "", (RMS) ? "RMS," : "",
        (ACV) ? "ACV," : "", (QPE) ? "QPE," : "");

    buffer[strlen (buffer) - 1] = '\n';

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Receiver Y-Axes Range                                           */
/* Purpose:  This function defines the minimum (maximum) grid level for the  */
/*           display in the receiver mode.                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECYAxesRange (ViSession instrSession, ViInt32 window,
                ViBoolean yaxesMode, ViReal64 yaxesValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (yaxesMode))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":DISP:WIND%ld:TRAC:Y:%s %.12f\n", window,
        (yaxesMode) ? "TOP" : "BOTT", yaxesValue);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Number of Ranges                                                */
/* Purpose:  This function determines the number of scan ranges.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECScanNoRanges (ViSession instrSession,
                ViInt32 noofRanges)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (noofRanges, 1, 10))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:SCAN:RANG %ld\n", noofRanges);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Scan Range Definition                                           */
/* Purpose:  This function defines scan range parameters. A scan is defined  */
/*           in the form of tables. Each scan range is determined by the     */
/*           start frequency, stop frequency, step width and by the          */
/*           measurement parameters valid for the range.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECScanRange (ViSession instrSession,
                ViInt32 rangeNo, ViReal64 startFreq, ViReal64 stopFreq, 
                ViReal64 stepWidth, ViReal64 IFBandwidth, ViReal64 measTime,
                ViBoolean preampMode, ViReal64 inputGain, ViBoolean RFAttenuation,
                ViReal64 manualAttenuation, ViBoolean selectInput,
                ViInt32 inputImpedance)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (rsfsex_invalidViInt32Range (rangeNo, 1, 10))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (startFreq, 0.0, 40.0e9))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (stopFreq, 0.0, 40.0e9))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (stepWidth, 0.0, 40.0e9))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViReal64Range (IFBandwidth, 0.0, 40.0e9))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViReal64Range (measTime, 100.0e-9, 100.0))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViBooleanRange (preampMode))
        return VI_ERROR_PARAMETER8;
    if (rsfsex_invalidViReal64Range (inputGain, 0.0, 30.0))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rsfsex_invalidViBooleanRange (RFAttenuation))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rsfsex_invalidViReal64Range (manualAttenuation, 0.0, 70.0))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rsfsex_invalidViBooleanRange (selectInput))
        return VI_ERROR_INSTR_PARAMETER12;

    /* Check Sweep Spacing mode. */
    if ((rsfsex_status = rsfsex_waitOPC (instrSession, ":SENS:SWE:SPAC?", buffer, 5000)) < 0)
        return rsfsex_status;
    if (strncmp (buffer, "AUTO", 4) == 0) /* If Auto, do not send Step Size. */
        sprintf (buffer, ":SENS:SCAN%ld:STAR %.12f;STOP %.12f;TIME %.12f"
            ";:SENS:SCAN%ld:BAND:RES %.12f", rangeNo, startFreq, stopFreq,
            measTime, rangeNo, IFBandwidth);
    else
        sprintf (buffer, ":SENS:SCAN%ld:STAR %.12f;STOP %.12f;STEP %.12f;TIME %.12f"
            ";:SENS:SCAN%ld:BAND:RES %.12f", rangeNo, startFreq, stopFreq,
            stepWidth, measTime, rangeNo, IFBandwidth);

    sprintf (buffer, "%s;:SENS:SCAN%ld:INP:TYPE %s", buffer, rangeNo,
        (selectInput == VI_TRUE) ? "INPUT2" : "INPUT1");

    sprintf (buffer, "%s;:SENS:SCAN%ld:INP:ATT:AUTO %s;:SENS:SCAN%ld:INP:ATT %.12f",
        buffer, rangeNo, switchArr[RFAttenuation],rangeNo, manualAttenuation);

     sprintf (buffer, "%s;:SENS:SCAN%ld:INP:GAIN:STATE %s", buffer, rangeNo,
        (inputGain > 0.0) ? "ON" : "OFF");

    if (RFAttenuation == VI_TRUE) {
        sprintf (buffer, "%s;:SENS:SCAN%ld:INP:GAIN:AUTO %s", buffer, rangeNo,
            switchArr[preampMode]);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Receiver Sweep                                                  */
/* Purpose:  This function determines if the trigger system is continuously  */
/*           initiated ("Free Run") or not.                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confRECSweep (ViSession instrSession, ViInt32 window,
                ViBoolean sweepMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (sweepMode))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":INIT%ld:CONT %s\n", window, switchArr[sweepMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure CDPower Measurement                                   */
/* Purpose:  This function selects the cdmaOne measurement.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPMeas (ViSession instrSession,
                ViInt32 CDPMeasurement)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (CDPMeasurement, 0, 5))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:IS95:MEAS %s\n", CDPMeasurementArr[CDPMeasurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure WCDPower MS Meas                                      */
/* Purpose:  This function selects the WCDMA mobile station tests.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSMeas (ViSession instrSession,
                ViInt32 WCDPMeasurement)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (WCDPMeasurement, 0, 7))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MS:MEAS %s\n", WCDPMeasurementArr[WCDPMeasurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Measurement Mode                                            */
/* Purpose:  This function selects the CDP meausrement mode.                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPMeasMode (ViSession instrSession,
                ViInt32 measurementMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;
    
    if (rsfsex_invalidViInt32Range (measurementMode, 0, 4))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CALC:FEED '%s'\n", CDPMeasModeArr[measurementMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Measurement Mode                                           */
/* Purpose:  This function selects the WCDP meausrement mode.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMeasMode (ViSession instrSession,
                ViInt32 measurementMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;
    
    if (rsfsex_invalidViInt32Range (measurementMode, 0, 10))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73 */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    sprintf (buffer, "%s\n", WCDPMeasModeArr[measurementMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Set to Standard                                             */
/* Purpose:  This function is for CDP presetting.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPSetStd (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71 or FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS:CDP:PRES\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP PN-Offset (Chips)                                           */
/* Purpose:  This function sets the nominal offset value of the base station */
/*           (in chips).                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPPNOffset (ViSession instrSession,
                ViInt32 offset)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (offset, -32768, 32768))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:CDP:PNOF %ld\n", offset);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Inactive Channel Treshold                                   */
/* Purpose:  This function sets the threshold value in the CDPR diagram from */
/*           which a channel is treated as active. The level entered refers  */
/*           to the total signal power.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPICT (ViSession instrSession,
                ViReal64 tresholdValuedB)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71 or FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViReal64Range (tresholdValuedB, -200.0, 200.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:CDP:ICTR %.12f\n", tresholdValuedB);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Side Band                                                   */
/* Purpose:  This function is for interchanging the left and the right       */
/*           sideband.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPSBand (ViSession instrSession,
                ViBoolean sideBand)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71 or FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (sideBand))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:CDP:SBAN %s\n", sideBandArr[sideBand]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Meas Period                                                 */
/* Purpose:  This function activates or deactivates the automatic            */
/*           determination of the optimum demodulation period. The           */
/*           demodulator calculates the signal/noise ratio of the cdmaOne    */
/*           signal and automatically selects a suitable setting.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPMeasPeriod (ViSession instrSession,
                ViBoolean autoMode, ViInt32 manualSettings)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (autoMode))
        return VI_ERROR_PARAMETER2;

    if (autoMode == VI_TRUE)
        sprintf (buffer, ":SENS:CDP:MPER:AUTO ON\n");
    else {
        if (rsfsex_invalidViInt32Range (manualSettings, 1, 24))
            return VI_ERROR_PARAMETER3;

        sprintf (buffer, ":SENS:CDP:MPER:AUTO OFF;:SENS:CDP:MPER %ld\n",
            manualSettings);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Fast Mode                                                   */
/* Purpose:  This function enables faster calculation. The timing error and  */
/*           phase error are not calculated in the fast mode.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPFastMode (ViSession instrSession,
                ViBoolean fastMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0xC000000)) { /* available only with option FSIQK71 or FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (fastMode))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS:DET:CDP:FUNC:MODE %s\n", fastModeArr[fastMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Input Channel                                               */
/* Purpose:  This function selects the CDMA standard and channel frequency.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPInpChan (ViSession instrSession,
                ViInt32 CDMAStandard, ViInt32 channelFrequency)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;
    ViInt32  max = (CDMAStandard == 0) ? 1023 : 1199;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (CDMAStandard, 0, 1))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (channelFrequency, 1, max))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CONF:CDP:PRES %s;CHAN %ld\n",
        CDMAStandardArr[CDMAStandard], channelFrequency);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Spreading Factor                                            */
/* Purpose:  This function defines the spreading factor. The spreading factor*/
/*           is only significant for display mode PEAK CODE DOMAIN ERROR.    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPSFactor (ViSession instrSession,
                ViInt32 spreadingFactor)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (spreadingFactor, 4, 512))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS2:CDP:SFAC %ld\n", spreadingFactor);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Code Number                                                 */
/* Purpose:  This function sets the code number. The code number refers to   */
/*           code class 9 (spreading factor 512).                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPCodeNum (ViSession instrSession,
                ViInt32 codeNumber)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (codeNumber, 0, 511))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:CODE %ld\n", codeNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP CPICH Slot                                                  */
/* Purpose:  This function sets the slot number of the common pilot channels */
/*           (CPICH).                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPSlot (ViSession instrSession,
                ViInt32 CPICHSlot)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (CPICHSlot, 0, 14))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:SLOT %ld\n", CPICHSlot);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Scrambling Code                                             */
/* Purpose:  This function defines the scrambling code in hexadecimal format.*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPLCode (ViSession instrSession,
                ViInt32 scramblingCode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CDP:LCOD #H%X\n", scramblingCode);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Normalize                                                   */
/* Purpose:  This function switches normalization of the unit circle with the*/
/*           IQ offset on or off.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPNormalize (ViSession instrSession,
                ViBoolean IQOffset)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71 or FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (IQOffset))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:NORM %s\n", switchArr[IQOffset]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Q Invert                                                    */
/* Purpose:  This function inverts the Q component of the signal.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPQInvert (ViSession instrSession,
                ViBoolean QInvert)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0xC000000)) { /* available only with option FSIQK71 or FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (QInvert))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:QINV %s\n", switchArr[QInvert]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Preference                                                  */
/* Purpose:  This function switches between the use of total power or CPICH  */
/*           power as reference for the relative CDP measurement values.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPPref (ViSession instrSession,
                ViBoolean preference)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (preference))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:PREF %s\n", preferenceArr[preference]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Sync Type                                                   */
/* Purpose:  This function selects the type of synchronization.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPSyncType (ViSession instrSession,
                ViBoolean syncType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (syncType))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:STYP %s\n", syncTypeArr[syncType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Signal Mapping                                              */
/* Purpose:  This function defines the mapping of the CDP signal.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPSigMap (ViSession instrSession,
                ViBoolean signalMapping)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (signalMapping))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:MAPP %s\n", signalMappingArr[signalMapping]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Antenna Type                                                */
/* Purpose:  This function switches on or off the antenna diversity mode and */
/*           selects the antenna of the diversity path.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPAntennaType (ViSession instrSession,
                ViInt32 antennaMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (antennaMode, 0, 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CDP:ANT %s\n", antennaModeArr[antennaMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table                                              */
/* Purpose:  This function switches the channel table on or off. On switching*/
/*           on, the measured channel table is requested by the DSPs, stored */
/*           under the name RECENT and switched on. After the RECENT channel */
/*           table is switched on, another channel table can be selected with*/
/*           the function WCDP Channel Table File (confWCDPChTableFile). The */
/*           RECENT channel table must always be switched on first with this */
/*           function and then the required channel table can be selected    */
/*           with the function WCDP Channel Table File (confWCDPChTableFile).*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTable (ViSession instrSession,
                ViBoolean channelTable)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (channelTable))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:STAT %s\n", switchArr[channelTable]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table File                                         */
/* Purpose:  This function selects a predefined channel table file. Before   */
/*           using this command, the RECENT channel table must be switched on*/
/*           first with the function WCDP Channel Table (confWCDPChTable).   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableFile (ViSession instrSession,
                ViString channelTableFile)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableFile, 8))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:SEL '%s'\n", channelTableFile);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Name                                         */
/* Purpose:  This function selects an existing channel table or creates the  */
/*           name of a new channel table.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableName (ViSession instrSession,
                ViString channelTableName)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableName, 8))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:NAME '%s'\n", channelTableName);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Copy                                         */
/* Purpose:  This function copies one channel table onto another one. The    */
/*           channel table to be copied is selected with function WCDP       */
/*           Channel Table Name (confWCDPChTableName).                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableCopy (ViSession instrSession,
                ViString channelTableName)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableName, 8))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:COPY '%s'\n", channelTableName);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Delete                                       */
/* Purpose:  This function deletes the selected channel table.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableDelete (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:DEL\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Restore                                      */
/* Purpose:  This function restores the original predefined channel tables.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableRestore (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:REST\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Comment                                      */
/* Purpose:  This function defines a comment for the selected channel table. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableComment (ViSession instrSession,
                ViString channelTableComment)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableComment, 128))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:COMM '%s'\n", channelTableComment);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Data                                         */
/* Purpose:  This function defines the values of the selected channel table. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableData (ViSession instrSession,
                ViInt32 _VI_FAR codeClass[], ViInt32 _VI_FAR codeNumber[],
                ViInt32 _VI_FAR useTFCI[], ViInt32 _VI_FAR timingOffset[],
                ViInt32 _VI_FAR pilotLength[], ViInt32 _VI_FAR pitch[],
                ViInt32 _VI_FAR status[], ViReal64 _VI_FAR CDPRelative[],
                ViInt32 numElements)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViChar buffer1[BUFFER_SIZE];
    ViChar offset[10];
    ViInt32 i = 0;
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (!codeClass)
        return VI_ERROR_PARAMETER2;
    if (!codeNumber)
        return VI_ERROR_PARAMETER3;
    if (!useTFCI)
        return VI_ERROR_PARAMETER4;
    if (!timingOffset)
        return VI_ERROR_PARAMETER5;
    if (!pilotLength)
        return VI_ERROR_PARAMETER6;
    if (!pitch)
        return VI_ERROR_PARAMETER7;
    if (!status)
        return VI_ERROR_PARAMETER8;
    if (!CDPRelative)
        return VI_ERROR_INSTR_PARAMETER9;
    if (rsfsex_invalidViInt32Range (numElements, 1, 3))
        return VI_ERROR_INSTR_PARAMETER10;

    buffer1[0] = '\0';

    for (i=0; i<numElements; i++) {
        sprintf (offset, "%ld", timingOffset[i]);

        sprintf (buffer1, "%s%ld,%ld,%ld,%s,%ld,%ld,%ld,%.12f,",
            buffer1, codeClass[i], codeNumber[i], useTFCI[i],
            (timingOffset[i] == -1) ? "AUTO" : offset,
            pilotLength[i], pitch[i], status[i], CDPRelative[i]);
    }

    /* Remove last remaining ',' comma. */
    buffer1[strlen(buffer1) - 1] = '\0';
    
    sprintf (buffer, ":CONF:WCDP:BTS:CTAB:DATA %s", buffer1);

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP Channel Table Catalog                                      */
/* Purpose:  This function reads out the names of all channel tables stored  */
/*           on the harddisk.                                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPChTableCatalog (ViSession instrSession,
                ViPInt32 nbOfTables, ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 retCnt;
    ViChar   *buffer = VI_NULL,
             *p2buffer;

    if (bufferSize < 0)
        return VI_ERROR_PARAMETER3;
    if ((bufferSize > 0) && (catalogList == VI_NULL))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viWrite (instrSession, "*CLS;:CONF:WCDP:BTS:CTAB:CAT?;*OPC?\n",
        36, &retCnt)) < 0)
        return rsfsex_status;

    if ((rsfsex_status = rsfsex_ReadDataUnknownLength(instrSession, &buffer, &retCnt)) < 0)
        return rsfsex_status;

    if ((p2buffer = strchr(buffer, ';')) == VI_NULL)
        p2buffer = buffer;

    *p2buffer = '\0';

        /* skip to end of first filename */
    if ((rsfsex_status = rsfsex_ParseCatalog(buffer, nbOfTables)) < VI_SUCCESS)
    {
        free(buffer);
        if (nbOfTables) *nbOfTables = 0;
        return rsfsex_status;
    }

    rsfsex_status = rsfsex_CopyStringBuffer(catalogList, buffer, bufferSize);

    free(buffer);

    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;

        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table                                           */
/* Purpose:  This function switches the channel table on or off. On switching*/
/*           on, the measured channel table is requested by the DSPs, stored */
/*           under the name RECENT and switched on. After the RECENT channel */
/*           table is switched on, another channel table can be selected with*/
/*           the function WCDP MS Channel Table File (confWCDPMSChTableFile).*/
/*           The RECENT channel table must always be switched on first with  */
/*           this function and then the required channel table can be        */
/*           selected with the function WCDP MS Channel Table File           */
/*           (confWCDPMSChTableFile).                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTable (ViSession instrSession,
                ViBoolean channelTable)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (channelTable))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:STAT %s\n", switchArr[channelTable]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table File                                      */
/* Purpose:  This function selects a predefined channel table file. Before   */
/*           using this command, the RECENT channel table must be switched on*/
/*           first with the function WCDP MS Channel Table                   */
/*           (confWCDPMSChTable).                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableFile (ViSession instrSession,
                ViString channelTableFile)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableFile, 8))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:SEL '%s'\n", channelTableFile);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table Name                                      */
/* Purpose:  This function selects an existing channel table or creates the  */
/*           name of a new channel table.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableName (ViSession instrSession,
                ViString channelTableName)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableName, 8))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:NAME '%s'\n", channelTableName);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table Copy                                      */
/* Purpose:  This function copies one channel table onto another one. The    */
/*           channel table to be copied is selected with function WCDP MS    */
/*           Channel Table Name (confWCDPMSChTableName).                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableCopy (ViSession instrSession,
                ViString channelTableName)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableName, 8))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:COPY '%s'\n", channelTableName);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table Delete                                    */
/* Purpose:  This function deletes the selected channel table.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableDelete (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:DEL\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table Comment                                   */
/* Purpose:  This function defines a comment for the selected channel table. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableComment (ViSession instrSession,
                ViString channelTableComment)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViString (channelTableComment, 128))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:COMM '%s'\n", channelTableComment);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table Data                                      */
/* Purpose:  This function defines the values of the selected channel table: */
/*               Pilot Length                                                */
/*               Code Class                                                  */
/*               Number of Active Channels                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableData (ViSession instrSession,
                ViInt32 codeClass, ViInt32 pilotLength, ViInt32 numChannels)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }
/*
    if (rsfsex_invalidViInt32Range (codeClass, , ))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (pilotLength, , ))
        return VI_ERROR_PARAMETER3;
*/
    if (rsfsex_invalidViInt32Range (numChannels, 0, 6))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CONF:WCDP:MS:CTAB:DATA %ld,%ld,%ld\n", pilotLength,
        codeClass, numChannels);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDP MS Channel Table Catalog                                   */
/* Purpose:  This function reads out the names of all channel tables stored  */
/*           on the harddisk.                                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMSChTableCatalog (ViSession instrSession,
                ViPInt32 nbOfTables, ViInt32 bufferSize,
                ViChar _VI_FAR catalogList[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 retCnt;
    ViChar   *buffer = VI_NULL,
             *p2buffer;

    if (bufferSize < 0)
        return VI_ERROR_PARAMETER3;
    if ((bufferSize > 0) && (catalogList == VI_NULL))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viWrite (instrSession, "*CLS;:CONF:WCDP:MS:CTAB:CAT?;*OPC?\n",
        35, &retCnt)) < 0)
        return rsfsex_status;

    if ((rsfsex_status = rsfsex_ReadDataUnknownLength(instrSession, &buffer, &retCnt)) < 0)
        return rsfsex_status;

    if ((p2buffer = strchr(buffer, ';')) == VI_NULL)
        p2buffer = buffer;

    *p2buffer = '\0';

        /* skip to end of first filename */
    if ((rsfsex_status = rsfsex_ParseCatalog(buffer, nbOfTables)) < VI_SUCCESS)
    {
        free(buffer);
        if (nbOfTables) *nbOfTables = 0;
        return rsfsex_status;
    }

    rsfsex_status = rsfsex_CopyStringBuffer(catalogList, buffer, bufferSize);

    free(buffer);

    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;

        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Stat Measurement Samples                                        */
/* Purpose:  This function sets the number of measurement points to be       */
/*           acquired for the statistical measurement functions.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confStatMeasSamples (ViSession instrSession,
                ViInt32 numSamples)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 and FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (numSamples, 100, 32768))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CALC:STAT:NSAM %ld\n", numSamples);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Stat Measurement Scaling                                        */
/* Purpose:  This function defines the lower (upper) limit for the Y-axis of */
/*           the diagram in statitistical measurements. Since probabilities  */
/*           are specified on the Y-axis, the entered numerical values are   */
/*           dimensionless.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confStatMeasScal (ViSession instrSession,
                ViReal64 lowerLimit, ViReal64 upperLimit)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 and FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViReal64Range (lowerLimit, 1.0e-6, 0.1))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (upperLimit, 1.0e-5, 1.0))
        return VI_ERROR_PARAMETER3;
    if (lowerLimit > upperLimit)
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    sprintf (buffer, ":CALC:STAT:SCAL:Y:LOW %.12f;:CALC:STAT:SCAL:Y:UPP %.12f\n",
        lowerLimit, upperLimit);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Stat Percent Marker                                             */
/* Purpose:  This function positions the marker in CCDFmeasurements to the   */
/*           selected percent value of the yaxis scaling (probability).      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confStatPercentMkr (ViSession instrSession,
                ViReal64 probability)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 and FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViReal64Range (probability, 0.0, 100.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CALC:MARK:Y:PERC %.12f\n", probability);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Total Power Nominal                                         */
/* Purpose:  This function selects the nominal power of the transmitter.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPNomPwr (ViSession instrSession,
                ViReal64 nominalPowerdBm)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViReal64Range (nominalPowerdBm, -100.0, 100.0))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:CDP:LIM:POW:NOM %.12f\n", nominalPowerdBm);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Limits Standard                                             */
/* Purpose:  This function switches the limit values to default values (ON)  */
/*           or to user-defined values (OFF).                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPLimStd (ViSession instrSession, 
                ViBoolean standardLimits)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (standardLimits))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:CDP:LIM:STAN %s\n", switchArr[standardLimits]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Limit Checking                                              */
/* Purpose:  This function to activates the limit checking (state on/off).   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPLimCheck (ViSession instrSession,
                ViBoolean limitChecking)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (limitChecking))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CALC:LIM:STAT %s\n", switchArr[limitChecking]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP User Limits                                                 */
/* Purpose:  This function sets the lower (upper) limit values for the CDP   */
/*           measurements.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confCDPUsrLimits (ViSession instrSession,
                ViBoolean lowerUpperLimits, ViReal64 totalPWRTolerance,
                ViReal64 pilotPWRRatio, ViReal64 pilotTimeAligment,
                ViReal64 frequencyError, ViReal64 CHTimeError,
                ViReal64 CHPhaseError, ViReal64 inactiveCHPWRRatio)
{
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViInt32     formatedBytes;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViBooleanRange (lowerUpperLimits))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (totalPWRTolerance, -200.0, 200.0))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (pilotPWRRatio, -200.0, 200.0))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViReal64Range (pilotTimeAligment, -1.0, 1.0))
        return VI_ERROR_PARAMETER5;
    if (rsfsex_invalidViReal64Range (frequencyError, -1.0e6, 1.0e6))
        return VI_ERROR_PARAMETER6;
    if (rsfsex_invalidViReal64Range (CHTimeError, -1.0, 1.0))
        return VI_ERROR_PARAMETER7;
    if (rsfsex_invalidViReal64Range (CHPhaseError, -1.0, 1.0))
        return VI_ERROR_PARAMETER8;
    if (rsfsex_invalidViReal64Range (inactiveCHPWRRatio, -200.0, 200.0))
        return VI_ERROR_INSTR_PARAMETER9;

    formatedBytes = sprintf (buffer, ":CONF:CDP:LIM:%s:POW:TOL %.12f;PRAT %.12f;"
                     ":CONF:CDP:LIM:%s:TIME:PAL %.12f;"
                     ":CONF:CDP:LIM:%s:ERR:CTIM %.12f;CPH %.12f;FREQ %.12f",
        lowerUpperLimitsArr[lowerUpperLimits], totalPWRTolerance, pilotPWRRatio,
        lowerUpperLimitsArr[lowerUpperLimits], pilotTimeAligment,
        lowerUpperLimitsArr[lowerUpperLimits], CHTimeError, CHPhaseError,
        frequencyError);
    if (lowerUpperLimits == VI_TRUE) /* Set upper limits */
        {
        formatedBytes += sprintf (buffer+formatedBytes, ";:CONF:CDP:LIM:UPP:POW:ICR %.12f",
            inactiveCHPWRRatio);
        }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Configure WCDPower Measurement                                  */
/* Purpose:  This function selects the WCDMA base station tests.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confWCDPMeas (ViSession instrSession,
                ViInt32 WCDPMeasurement)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (WCDPMeasurement, 0, 7))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:WCDP:MEAS %s\n", WCDPMeasurementArr[WCDPMeasurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: SEM Limit Line                                                  */
/* Purpose:  This function switches on or off the automatic selection of     */
/*           limit lines for spectrum emission mask measurements.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_confSEMLimitLine (ViSession instrSession,
                ViInt32 measMode, ViReal64 expectedPower)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 and FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (measMode, 0, 1))
        return VI_ERROR_PARAMETER2;

    if (measMode == 1)
        sprintf (buffer, ":CALC:LIM:ESP:MODE %s;:CALC:LIM:ESP:VAL %.12f\n",
            measModeSEMArr[measMode], expectedPower);
    else
        sprintf (buffer, ":CALC:LIM:ESP:MODE %s\n", measModeSEMArr[measMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker Search                                                   */
/* Purpose:  This functions is useful for peak/min. peak searching.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMarkSearch (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 searchMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (searchMode, 0, 8))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:MARK%ld:%s\n", window,markerNumber,
        mkrPosArr[searchMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker Search                                             */
/* Purpose:  This functions is useful for peak/min. delta marker peak        */
/*           searching.                                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actDMarkSearch (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 searchMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (searchMode, 0, 8))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:DELT%ld:%s\n", window, markerNumber,
        mkrPosArr[searchMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Marker To                                                       */
/* Purpose:  This function changes instrument parameters via currently active*/
/*           marker.                                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMarkTo (ViSession instrSession, ViInt32 window,
                ViInt32 markNumber, ViInt32 mkrFunction, ViInt32 trace)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (mkrFunction, 0, 6))
        return VI_ERROR_PARAMETER4;
    if (rsfsex_invalidViInt32Range (trace, 1, 4))
        return VI_ERROR_PARAMETER5;

    if (mkrFunction == 6)
        sprintf (buffer, ":CALC%ld:MARK%ld:TRAC %ld\n",
            window, markNumber, trace );
    else
        sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:%s\n", window, markNumber,
            mkrFunctionArr[mkrFunction]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Delta Marker To                                                 */
/* Purpose:  This command assigns the selected delta marker (1 to 4) to the  */
/*           indicated test curve.                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actDMarkTo (ViSession instrSession, ViInt32 window,
                ViInt32 markNumber, ViInt32 trace)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (trace, 1, 4))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:DELT%ld:TRAC %ld\n", window, markNumber, trace);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Delta Marker Value                                          */
/* Purpose:  This function gets delta marker values from the selected marker */
/*           position.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMarkDeltaValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 deltaMarker,
                ViPReal64 realValue, ViPReal64 imaginaryValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (deltaMarker, 0, 2))
        return VI_ERROR_PARAMETER4;

    switch (deltaMarker) {
        case 0:
            sprintf (buffer, "*CLS;:CALC%ld:DELT%ld:X?\n", window, markerNumber);
        break;
        case 1:
            sprintf (buffer, "*CLS;:CALC%ld:DELT%ld:X:REL?\n", window, markerNumber);
        break;
        case 2:
            sprintf (buffer, "*CLS;:CALC%ld:DELT%ld:Y?\n", window, markerNumber);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (deltaMarker == 1) {
        if (sscanf (buffer, "%le,%le", realValue, imaginaryValue) != 2)
            if (sscanf (buffer, "%le", realValue) != 1) {
                rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                return rsfsex_status;
        }
    }
    else {
        if (sscanf (buffer, "%le", realValue) != 1) {
            rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rsfsex_status;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Phase Noise Result                                          */
/* Purpose:  This function queries the result of the phase noise measurement.*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMPhaseNoiseResult (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViPReal64 noiseResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "*CLS;:CALC%ld:DELT%ld:FUNC:PNO:RES?\n", window, markerNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%le", noiseResult) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Marker Counter Value                                        */
/* Purpose:  This function gets frequency counter value from the marker      */
/*           position.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMarkCntValue (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViPReal64 markFreq)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:COUN:FREQ?\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%le", markFreq) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Marker Value                                                */
/* Purpose:  This function gets marker value from the selected marker        */
/*           position.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMarkValue (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViPReal64 realMarkValue,
                ViPReal64 imagMarkValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:Y?\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le,%le", realMarkValue, imagMarkValue) != 2) {
        if (sscanf (buffer, "%le", realMarkValue) != 1) {
            rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rsfsex_status;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get N dB Dow Marker Value                                       */
/* Purpose:  This function queries the frequency spacing (bandwidth) of the  */
/*           "N dB Down" markers or queries the frequencies of the "N dB     */
/*           Down" marker.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMarkNdBDValue (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean ndBDownQuery,
                ViReal64 _VI_FAR returnedValue[])
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (ndBDownQuery))
        return VI_ERROR_PARAMETER4;

    if (ndBDownQuery == VI_FALSE)
        sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:NDBD:RES?\n", window, markNumber);
    else
        sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:NDBD:FREQ?\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (ndBDownQuery == VI_TRUE) {
        if (sscanf (buffer, "%le,%le", &returnedValue[0], &returnedValue[1]) != 2)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    } 
    else {
        if (sscanf (buffer, "%le", &returnedValue[0]) != 1)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }
                      
    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Noise Marker Value                                          */
/* Purpose:  This function queries the result of the noise measurement.      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMarkNoiseValue (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViPReal64 noiseResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:NOIS:RES?\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", noiseResult) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Shape Factor Value                                          */
/* Purpose:  This function queries the result or frequencies of the shape    */
/*           factor measurement.                                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMarkShapeValue (ViSession instrSession,
                ViInt32 window, ViInt32 markNumber, ViBoolean shape,
                ViReal64 _VI_FAR shapeFactorValues[])
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViBooleanRange (shape))
        return VI_ERROR_PARAMETER4;

    if (shape == VI_FALSE)
        sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:SFAC:RES?\n", window, markNumber);
    else
        sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:SFAC:FREQ?\n", window, markNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (shape == VI_FALSE) {
        if (sscanf (buffer, "%le", &shapeFactorValues[0]) != 1) {
            rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rsfsex_status;
        }
    }
    else {
        if (sscanf (buffer, "%le,%le,%le,%le", &shapeFactorValues[0], &shapeFactorValues[1],
            &shapeFactorValues[2], &shapeFactorValues[3]) != 4) {
            rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rsfsex_status;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Marker Power Value                                          */
/* Purpose:  This function queries the results of the power measurement.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMarkPowerValue (ViSession instrSession,
                                               ViInt32 window, ViInt32 markNumber,
                                               ViInt32 chPowerType,
                                               ViReal64 powerValue[])
{
    ViUInt32 retCnt = 0, index = 0;
    ViChar buffer[BUFFER_SIZE];
    ViChar tmpBuf[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (chPowerType, 0, 4))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:POW:RES? %s\n", window,
        markNumber, channelPowArr[chPowerType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    while (sscanf (buffer, "%le,%[^\r\n]", &powerValue[index], tmpBuf) == 2) {
        sprintf (buffer, "%s", tmpBuf);
        index++;
    }

    if ((index < 7) && (powerValue[index] == 10.0))
        powerValue[index] = VI_NULL;

    index++;
    for (index; index < 7; index++)
        powerValue[index] = VI_NULL;

    if (!retCnt)
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Channel Power To Ref Value                                      */
/* Purpose:  This function sets the reference value to the currently measured*/
/*           channel power.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMMarkChPowToRef (ViSession instrSession,
                ViInt32 window)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    
    sprintf (buffer, ":SENS%ld:POW:ACH:REF:AUTO ONCE\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Adjust Channel Power Settings                                   */
/* Purpose:  This function selects and adjusts channel power settings.       */
/*           Optimises automatically the settings of the analyzer for the    */
/*           selected power measurement in conjunction with the selected     */
/*           standard. The instrument parameter, set by this function, are   */
/*           dependent of the selected standard. Following parameter may be  */
/*           changed: Number of Channels, Span, Resolution Bandwidth, Video  */
/*           Bandwidth, Detector.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMCPSet (ViSession instrSession, ViInt32 window,
                                      ViInt32 channelPowerType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (channelPowerType, 0, 5))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":SENS%ld:POW:ACH:PRES %s\n", window, channelPowArr[channelPowerType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Set Limit Lines Offset                                          */
/* Purpose:  This function sets the X and Y limit line offsets.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSetLimitLinesOffset (ViSession instrSession,
                ViInt32 window, ViReal64 XOffset, ViReal64 YOffset)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViReal64Range (XOffset, -100.0e9, 100.0e9))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViReal64Range (YOffset, -100.0e9, 100.0e9))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:LIM:CONT:OFFSET %.12f", window, XOffset);
    sprintf (buffer, "%s;:CALC%ld:LIM:UPP:OFFSET %.12f", buffer, window, YOffset);

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Limit Check Result                                          */
/* Purpose:  This function queries the result of the limit check.            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actLimitCheck (ViSession instrSession,
                ViInt32 window, ViInt32 limitLineNo, ViPInt32 checkResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (limitLineNo, 1, 8))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "*CLS;:CALC%ld:LIM%ld:FAIL?\n", window, limitLineNo);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%ld", checkResult) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Single Measurement                                           */
/* Purpose:  This function switches single measurement of carrier power on   */
/*           and off.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMSSingleMeas (ViSession instrSession,
                ViBoolean singleMeasurement)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (singleMeasurement))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:POW:SING %s\n", switchArr[singleMeasurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Single Measurement                                          */
/* Purpose:  This function switches single measurement of carrier power on   */
/*           and off.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSSingleMeas (ViSession instrSession,
                ViBoolean singleMeasurement)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (singleMeasurement))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:POW:SING %s\n", switchArr[singleMeasurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Clear Single Result                                          */
/* Purpose:  This function clears the table containing the single-step       */
/*           carrier power measurements.                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMSClrSingleRes (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, "CONF:MS:POW:SING:CLE\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Clear Single Result                                         */
/* Purpose:  This function clears the table containing the single-step       */
/*           carrier power measurements.                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSClrSingleRes (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, "CONF:BTS:POW:SING:CLE\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Limit (Power) Coupled                                        */
/* Purpose:  This function switches between user-defined (OFF) and           */
/*           standard-defined (ON) level values.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMSPowerCpl (ViSession instrSession,
                ViBoolean limit_Power_Coupled)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (limit_Power_Coupled))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:POW:COUP %s\n", switchArr[limit_Power_Coupled]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Limit (Power) Coupled                                       */
/* Purpose:  This function switches between user-defined (OFF) and           */
/*           standard-defined (ON) level values.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSPowerCpl (ViSession instrSession,
                ViBoolean limit_Power_Coupled)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (limit_Power_Coupled))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:POW:COUP %s\n", switchArr[limit_Power_Coupled]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Modulation Accuracy                                         */
/* Purpose:  This function selects measurement of the measurement accuracy of*/
/*           the base station or mobile.                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMModAccuracy (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, ":CONF:BURS:MACC:IMM\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Burst Limit Check                                           */
/* Purpose:  This function queries results of the carrier power measurement, */
/*           power vs. time measurement or total phase/frequency measurement.*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMBurstLimit (ViSession instrSession,
                ViInt32 burstCheck, ViPInt32 measuredValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (burstCheck, 0, 2))
        return VI_ERROR_PARAMETER2;

    switch (burstCheck) {
        case 0:
            sprintf (buffer, "*CLS;:CALC:LIM:BURS:PTEM?\n");
        break;
        case 1:
            sprintf (buffer, "*CLS;:CALC:LIM:BURS:POW?\n");
        break;
        case 2:
            sprintf (buffer, "*CLS;:CALC:LIM:BURS:PFER?\n");
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    switch (burstCheck) {
        case 0:
        case 1:
            sscanf (buffer, "%[^\r\n]", buffer);
            *measuredValue = rsfsex_statusToInt(buffer);
            if (*measuredValue == -1)
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        break;
        case 2:
            /*
               Convert instruments response to the currently used format:
                   PASSED ... 0
                   FAILED ... 1
            */
            sscanf (buffer, "%ld", measuredValue);
            *measuredValue = (*measuredValue == 1) ? 0 : 1;
        break;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Spectrum Limit Check                                        */
/* Purpose:  This function queries spectrum limit results.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMSpectrumLimit (ViSession instrSession,
                ViInt32 spectrumMeasMode, ViInt32 modulationRange,
                ViPInt32 resultValue, ViPInt32 numberofViolations)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (spectrumMeasMode, 0, 4))
        return VI_ERROR_PARAMETER2;

    if (spectrumMeasMode > 2)
        sprintf (buffer, "*CLS;:CALC:LIM:SPEC:%s?\n", spectrumMeasModeArr[spectrumMeasMode]);
    else {
        if (rsfsex_invalidViInt32Range (modulationRange, 0, 4))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, "*CLS;:CALC:LIM:SPEC:%s? %s\n", spectrumMeasModeArr[spectrumMeasMode],
            modRangeArr[modulationRange]);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    buffer[retCnt] = '\0';
    
    switch (spectrumMeasMode) {
        case 0: case 3:
            sscanf (buffer, "%[^\r\n]", buffer);
            *resultValue = rsfsex_statusToInt(buffer);
            if (*resultValue == -1)
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        break;
        default:
            if (sscanf (buffer, "%ld", numberofViolations) != 1) {
                rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                    return rsfsex_status;
            }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Spurious Limit Check                                        */
/* Purpose:  This function queries spurious limit measurement results.       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMSpuriousLimit (ViSession instrSession,
                ViBoolean spuriousResult, ViInt32 spuriousParameter,
                ViPInt32 resultValue, ViPInt32 numberofViolations)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (spuriousResult))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (spuriousParameter, 0, 3))
        return VI_ERROR_PARAMETER3;

    if (spuriousResult == VI_FALSE)
        sprintf (buffer, "*CLS;:CALC:LIM:SPUR? %s\n",
            limitSpurParamArr[spuriousParameter]);
    else
        sprintf (buffer, "*CLS;:CALC:LIM:SPUR:FAIL? %s\n",
            limitSpurParamArr[spuriousParameter]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (spuriousResult == VI_FALSE) {
        sprintf (buffer, "%[^\r\n]", buffer);
        *resultValue = rsfsex_statusToInt(buffer);
        if (*resultValue == -1)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }
    else {
        if (sscanf (buffer, "%ld", numberofViolations) != 1) {
            rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                return rsfsex_status;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Auto Adjust Ch Power Settings                                   */
/* Purpose:  This function optimises automatically the settings of the       */
/*           analyzer for the selected power measurement. One of the power   */
/*           measurements ( CP, ACP, ...) shall be selected before using this*/
/*           function by using actSAMCPSet().                                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMCPAdjust (ViSession instrSession, ViInt32 window)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":SENS%ld:POW:ACH:PRES ADJ\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: ACP Limit Checking                                              */
/* Purpose:  This function switches On or Off limit checking of ACP          */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMACPLimitCheckState (ViSession instrSession,
                ViInt32 window, ViBoolean state)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CALC%ld:LIM:ACP %s\n", window, switchArr[state]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get ACP Limit Check                                             */
/* Purpose:  This function queries result of the limit check for the         */
/*           first/second alternate or upper/lower adjacent channel when     */
/*           adjacent channel power measurement is performed.                */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMACPLimitCheck (ViSession instrSession,
                ViInt32 window, ViInt32 ACPResult,
                ViPInt32 firstResult, ViPInt32 secondResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE], first[10], second[10];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (ACPResult, 0, 2))
        return VI_ERROR_PARAMETER3;

    switch (ACPResult) {
        case 0:
            sprintf (buffer, "*CLS;:CALC%ld:LIM:ACP:ACH:RES?\n", window);
        break;
        case 1:
            sprintf (buffer, "*CLS;:CALC%ld:LIM:ACP:ALT1:RES?\n", window);
        break;
        case 2:
            sprintf (buffer, "*CLS;:CALC%ld:LIM:ACP:ALT2:RES?\n", window);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%[^,],%[^\r\n]", first, second) != 2) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rsfsex_status;
    }

    *firstResult = rsfsex_statusToInt(first);
    if (*firstResult == -1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    *secondResult = rsfsex_statusToInt(second);
    if (*secondResult == -1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Activated Limit Lines                                       */
/* Purpose:  This function queries the name of all activated limit lines. The*/
/*           names are output in alphabetical order. If no limit line is     */
/*           activated, an empty string will be output.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actLimitLinesAct (ViSession instrSession,
                ViInt32 bufferSize, ViChar _VI_FAR limitLineList[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 retCnt;
    ViChar   *buffer = VI_NULL;

    if (bufferSize < 0)
        return VI_ERROR_PARAMETER3;
    if ((bufferSize > 0) && (limitLineList == VI_NULL))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viWrite (instrSession, "*CLS;:CALC:LIM:ACT?;*OPC?\n", 26, &retCnt)) < 0)
        return rsfsex_status;
        
    if ((rsfsex_status = rsfsex_ReadDataUnknownLength(instrSession, &buffer, &retCnt)) < 0)
        return rsfsex_status;

    rsfsex_status = rsfsex_CopyStringBuffer(limitLineList, buffer, bufferSize);

    free(buffer);
    
    if ((rsfsex_status >= VI_SUCCESS) && (bufferSize != 0))
    {
        ViStatus tmpStatus = rsfsex_status;
        
        if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
            return rsfsex_status;
        rsfsex_status = tmpStatus;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Send Trigger                                                    */
/* Purpose:  This function triggers all actions waiting for a trigger event. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSendTrg (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, "*TRG\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Send Trigger and Wait for OPC                                   */
/* Purpose:  This function triggers all actions waiting for a trigger event  */
/*           and waits for operation completed (OPC) before return status    */
/*           code.                                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSendTrgWopc (ViSession instrSession, ViInt32 timeout)
{
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (timeout, 0, 600000))
        return VI_ERROR_PARAMETER2;

    rsfsex_status = rsfsex_waitOPC (instrSession, "*TRG;*OPC?\n", buffer, timeout);

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Abort                                                           */
/* Purpose:  This function aborts a current measurement and resets the       */
/*           trigger system.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actAbort (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, ":ABOR\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Copy Trace                                                      */
/* Purpose:  This function copies data from one trace to another. The second */
/*           operand designates the source, the first operand the destination*/
/*           of the data to be copied.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actSAMCopyTrace (ViSession instrSession, ViInt32 sourceTrace,
                ViInt32 destinationTrace)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (sourceTrace, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (destinationTrace, 0, 3))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":TRACE:COPY %s,%s\n", traceNamesArr[destinationTrace],
        traceNamesArr[sourceTrace]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Calibration                                                     */
/* Purpose:  This function initiates the instrument's calibration routines.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCalibration (ViSession instrSession,
                ViInt32 calType, ViInt32 timeout, ViPInt32 calResult)
{
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (calType, 0, 7))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (timeout, 0, 600000))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":CAL:%s?\n", calTypeArr[calType]);

    if ((rsfsex_status = rsfsex_waitOPC (instrSession, buffer, buffer, timeout)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%ld", calResult) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Calibration Correction                                          */
/* Purpose:  This function determines whether (ON) or not (OFF) the current  */
/*           calibration data are taken into consideration.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCalCorr (ViSession instrSession, ViBoolean calData)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (calData))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CAL:STAT %s\n", switchArr[calData]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Service Source                                                  */
/* Purpose:  This function supports instruments signal sources.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actServiceSource (ViSession instrSession,
                ViBoolean signalSource, ViBoolean noiseSrc)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (signalSource))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (noiseSrc))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":DIAG:SERV:INP:SEL %s;:DIAG:SERV:NSO %s\n", inputSrcArr[signalSource],
        switchArr[noiseSrc]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Initiate Hardcopy                                               */
/* Purpose:  This function starts a hardcopy output for selected device.     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actHCopy (ViSession instrSession, ViInt32 deviceNumber)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (deviceNumber, 1, 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":HCOP:IMM%ld\n", deviceNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Time and Date                                                   */
/* Purpose:  This function gets the instrument's internal clock or calendar. */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGetSystemTime (ViSession instrSession,
                ViBoolean timeDate, ViPInt32 hour, ViPInt32 minute, ViPInt32 second,
                ViPInt32 day, ViPInt32 month, ViPInt32 year)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    *hour = -1;
    *minute = -1;
    *second = -1;
    *year = -1;
    *month = -1;
    *day = -1;

    if (rsfsex_invalidViBooleanRange (timeDate))
        return VI_ERROR_PARAMETER2;

    if (timeDate) /* time == VI_TRUE */
        sprintf (buffer, "*CLS;:SYST:TIME?\n");
    else
        sprintf (buffer, "*CLS;:SYST:DATE?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (timeDate) /* time == VI_TRUE */ {
        if (sscanf (buffer, "%ld,%ld,%ld", hour, minute, second) != 3)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }
    else {
        if (sscanf (buffer, "%ld,%ld,%ld", year, month, day) != 3)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Memory Operations                                               */
/* Purpose:  The MMEMory (mass memory) subsystem function provides commands  */
/*           which allow for access to the storage media of the instrument   */
/*           and for storing and loading various instrument settings.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMemOp (ViSession instrSession,
                ViInt32 operation, ViString source, ViString destination)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (operation, 0, 14))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViString (source, 256))
        return VI_ERROR_PARAMETER3;

    switch (operation) {
        case 1: case 6:
            if (rsfsex_invalidViString (destination, 256))
                return VI_ERROR_PARAMETER4;
            sprintf (buffer, ":MMEM:%s'%s','%s'\n", operationMemArr[operation],
                     source, destination);
        break;
        default:
            sprintf (buffer, ":MMEM:%s'%s'\n", operationMemArr[operation], source);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Memory Select Items                                             */
/* Purpose:  This function add/remove settings to/from the list of partial   */
/*           datasets of a device setting to be stored/loaded. This function */
/*           is working in conjunction with function Memory Operations       */
/*           (rsfsex_actMemOp).                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMemSel (ViSession instrSession, ViInt32 itemSelector,
                ViBoolean itemState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (itemSelector, 0, 19))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (itemState))
        return VI_ERROR_PARAMETER3;

    if (itemSelector < 3)
        sprintf (buffer, ":MMEM:SEL:%s\n", itemSelectrArr[itemSelector]);
    else
        sprintf (buffer, ":MMEM:SEL:%s %s\n", itemSelectrArr[itemSelector],
                 switchArr[itemState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Vector Analyzer Mode                                            */
/* Purpose:  This function sets the vector analyzer operating modes.         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actVSAMMode (ViSession instrSession, ViInt32 window,
                ViBoolean setMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (setMode))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":INST%ld:SEL %s\n", window, vectorModeArr[setMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Analog Demod Meas To Ref                                        */
/* Purpose:  This function sets the current absolute measured values of the  */
/*           main modulation signal as reference values for the relative     */
/*           indication.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actVSAMSumRef (ViSession instrSession, ViInt32 window)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:MSUM:REF:AUTO ONCE\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Analog Demod Value                                          */
/* Purpose:  This function returns analog modulation measurement summary.    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actVSAMMarkerADemod (ViSession instrSession, ViInt32 window,
                ViInt32 modulType, ViInt32 parameter, ViPReal64 measuredValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (parameter, 0, 7))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    switch (parameter) {
        case 0: /* Pos PK */
            if (rsfsex_invalidViInt32Range (modulType, 0, 2))
                return VI_ERROR_PARAMETER3;
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:%s? PPE\n",
                window, modulTypeArr[modulType]);
        break;
        case 1: /* Neg PK */
            if (rsfsex_invalidViInt32Range (modulType, 0, 2))
                return VI_ERROR_PARAMETER3;
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:%s? MPE\n",
                window, modulTypeArr[modulType]);
        break;
        case 2: /* Aver PK */
            if (rsfsex_invalidViInt32Range (modulType, 0, 2))
                return VI_ERROR_PARAMETER3;
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:%s? MIDD\n",
                window, modulTypeArr[modulType]);
        break;
        case 3: /* RMS */
            if (rsfsex_invalidViInt32Range (modulType, 0, 2))
                return VI_ERROR_PARAMETER3;
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:%s? RMS\n",
                window, modulTypeArr[modulType]);
        break;
        case 4: /* SINAD */
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:SIN:RES?\n", window);
        break;
        case 5: /* audio freq */
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:AFR?\n", window);
        break;
        case 6: /* freq err */
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:FERR?\n", window);
        break;
        case 7: /* carr power */
            sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:ADEM:CARR?\n", window);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measuredValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Digital Demod Value                                         */
/* Purpose:  This function queries the error measurement results of digital  */
/*           demodulation.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actVSAMMarkerDDemod (ViSession instrSession,
                ViInt32 window, ViInt32 modMeas, ViPReal64 measuredValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (modMeas, 0, 19))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, "*CLS;:CALC%ld:MARK:FUNC:DDEM:RES? %s\n",
        window, digiModMeasArr[modMeas]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measuredValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Summary Marker Value                                        */
/* Purpose:  This function queries the results of the summary marker         */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actVSAMMarkerSumValue (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 summaryMarker,
                ViPReal64 measuredValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (summaryMarker, 0, 5))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10)) { /* available only with option FSE-B7 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:SUMM:%s:RES?\n", window, markerNumber,
        summaryMarkerArr[summaryMarker]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measuredValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Tracking Generator Mode                                         */
/* Purpose:  This function sets the tracking generator operating modes.      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actTrackMode (ViSession instrSession, ViInt32 window,
                ViBoolean setMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (setMode))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1E0)) { /* available only with option FSE-B8..B11 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":OUTP%ld:STAT %s\n", window, switchArr[setMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Tracking Generator Corr State                                   */
/* Purpose:  This function activates/deactivates normalization of the        */
/*           measurement results.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actTrackCorrState (ViSession instrSession,
                ViInt32 window, ViBoolean corrState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (corrState))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x3E0)) { /* available only with option FSE-B8..B12 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:CORR:STAT %s\n", window, switchArr[corrState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Tracking Generator Correction                                   */
/* Purpose:  This function calls the tracking generator calibrations.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actTrackCorr (ViSession instrSession, ViInt32 window,
                ViInt32 sourceCal, ViInt32 timeout)
{
    ViChar buffer[BUFFER_SIZE], instrResp[10];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (sourceCal, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (timeout, 0, 600000))
        return VI_ERROR_PARAMETER4;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x3E0)) { /* available only with option FSE-B8..B12 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (sourceCal == 3)
        sprintf (buffer, ":SENS%ld:CORR:REC;*OPC?\n", window);
    else
        sprintf (buffer, ":SENS%ld:CORR:METH %s;COLL %s;*OPC?\n", window, sourceCalArr[sourceCal],
            sourceCalCollArr[sourceCal]);

    if ((rsfsex_status = rsfsex_waitOPC (instrSession, buffer, instrResp, timeout)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: TV Demod Mode                                                   */
/* Purpose:  This function sets the TV demodulator operating modes.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actTVMode (ViSession instrSession, ViInt32 window,
                ViBoolean setMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (setMode))
        return VI_ERROR_PARAMETER3;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2)) { /* available only with option FSE-B3 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":SENS%ld:TV:STAT %s\n", window, switchArr[setMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: TV Trigger Source                                               */
/* Purpose:  This function sets the trigger sequence source to TV mode.      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actTVTriggerSrc (ViSession instrSession, ViInt32 window)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2)) { /* available only with option FSE-B3 */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":TRIG%ld:SEQ:SOUR TV\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM BTS Mode                                                    */
/* Purpose:  This function sets the GSM BTS operating mode.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMBTSMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, ":INST:SEL BGSM\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM MS Mode                                                     */
/* Purpose:  This function sets the GSM MS operating mode.                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMMSMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, ":INST:SEL MGSM\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Set ARFCN                                                   */
/* Purpose:  This function selects the number of the transmission channel of */
/*           the base station or this is used to search for the channel      */
/*           number of the transmission channel of the base station          */
/*           automatically (This requires only one channel to be active).    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSARFCN (ViSession instrSession, ViBoolean ARFCNMode,
                ViInt32 ARFCNValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (ARFCNMode))
        return VI_ERROR_PARAMETER2;

    if (ARFCNMode == VI_TRUE)
        sprintf (buffer, ":CONF:BTS:ARFC:AUTO ONCE\n");
    else {
        if (rsfsex_invalidViInt32Range (ARFCNValue, 0, 1023))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, ":CONF:BTS:ARFC %ld\n", ARFCNValue);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Set ARFCN                                                    */
/* Purpose:  This control selects automatically the transmission channel of  */
/*           the mobile or defines it manually.                              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMSARFCN (ViSession instrSession,
                ViBoolean ARFCNMode, ViInt32 ARFCNValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (ARFCNMode))
        return VI_ERROR_PARAMETER2;

    if (ARFCNMode == VI_TRUE)
        sprintf (buffer, ":CONF:MS:ARFC:AUTO ONCE\n");
    else {
        if (rsfsex_invalidViInt32Range (ARFCNValue, 0, 1023))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, ":CONF:MS:ARFC %ld\n", ARFCNValue);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Set Channel                                                 */
/* Purpose:  This function selects the slot number within a transmission     */
/*           frame of the base station. This function also couples the       */
/*           midamble (training sequence TSC_0 to 7) to the slot, i.e. if the*/
/*           slot number is changed the training sequence in the ON state is */
/*           automatically adapted.                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSChannel (ViSession instrSession,
                ViBoolean slotMode, ViInt32 slotNumber,
                ViBoolean TSCMode, ViInt32 TSCNumber)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (slotMode))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (TSCMode))
        return VI_ERROR_PARAMETER4;

    if (slotMode == VI_TRUE)
        sprintf (buffer, ":CONF:BTS:CHAN:SLOT:AUTO ONCE");
    else {
        if (rsfsex_invalidViInt32Range (slotNumber, 0, 7))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, ":CONF:BTS:CHAN:SLOT %ld", slotNumber);
    }

    if (TSCMode == VI_TRUE)
        sprintf (buffer, "%s;:CONF:BTS:CHAN:TSC:AUTO ON", buffer);
    else {
        if (rsfsex_invalidViInt32Range (TSCNumber, 0, 7))
            return VI_ERROR_PARAMETER5;
        sprintf (buffer, "%s;:CONF:BTS:CHAN:TSC %ld", buffer, TSCNumber);
    }

    sprintf (buffer, "%s\n", buffer);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Set Channel                                                  */
/* Purpose:  This function selects the midamble used by the mobile.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMSChannel (ViSession instrSession, ViInt32 midamble)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (midamble, 0, 7))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:CHAN:TSC %ld\n", midamble);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Trigger Adjust                                              */
/* Purpose:  This function defines the correction values for the time offset */
/*           between the frame trigger and the midamble of the slot selected.*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMTrgAdj (ViSession instrSession,
                ViInt32 triggerAdjust, ViReal64 frameSlotNum)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (triggerAdjust, 0, 3))
        return VI_ERROR_PARAMETER2;

    switch (triggerAdjust) {
        case 0: case 2:
            sprintf (buffer, ":TRIG:SEQ:SYNC:ADJ:%s\n",
                triggerAdjustArr[triggerAdjust]);
        break;
        default:
            if (rsfsex_invalidViReal64Range (frameSlotNum, -100.0e-6, 100.0))
                return VI_ERROR_PARAMETER3;
            sprintf (buffer, ":TRIG:SEQ:SYNC:ADJ:%s %.12f\n", triggerAdjustArr[triggerAdjust],
                frameSlotNum);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS Default Settings                                            */
/* Purpose:  This function selects the standard type according to which the  */
/*           base station will work.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSNetwork (ViSession instrSession,
                ViInt32 networkType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (networkType, 0, 9))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:%s\n", networkTypeBTSArr[networkType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: MS Default Settings                                             */
/* Purpose:  This function selects the standard type according to which the  */
/*           mobile will work.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actMSNetwork (ViSession instrSession,
                ViInt32 networkType)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (networkType, 0, 9))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:MS:%s\n", networkTypeMSArr[networkType]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: BTS TX Suppression                                              */
/* Purpose:  This function defines that an additional carrier suppression of */
/*           min. 20dB is taken into account for the measurement. If there is*/
/*           already suppression, a more sensitive setting of the instrument */
/*           is selected.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actBTSSupp (ViSession instrSession, ViBoolean suppState)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (suppState))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BTS:TXS %s\n", switchArr[suppState]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Burst Section                                               */
/* Purpose:  This function defined the burst section to be measured.         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMBurstSection (ViSession instrSession,
                ViInt32 burstSection)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (burstSection, 0, 3))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BURS:PTEM:SEL %s\n", burstSectionArr[burstSection]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Burst Measurement Mode                                      */
/* Purpose:  This function selects measuremet to be performed (carrier power,*/
/*           phase/frequency error, power vs. time).                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMBurstMeasMode (ViSession instrSession,
                ViInt32 measurementMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (measurementMode, 0, 2))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":CONF:BURS:%s\n", GSMBurstModeArr[measurementMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Spectrum Measurement Mode                                   */
/* Purpose:  This function selects measuremet to be performed (used to       */
/*           determine the power of the spectral contributions due to        */
/*           modulation switching - modulation spectrum, transient spectrum).*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMSpectMeasMode (ViSession instrSession,
                ViBoolean measurementMode)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (measurementMode))
        return VI_ERROR_PARAMETER2;

    if (measurementMode == VI_FALSE)
        sprintf (buffer, ":CONF:SPEC:MOD\n");
    else
        sprintf (buffer, ":CONF:SPEC:SWIT\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Spurious Measurement Mode                                   */
/* Purpose:  This function selects measuremet used for measuring the power of*/
/*           spurious emissions).                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actGSMSpurMeasMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, ":CONF:SPUR\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Receiver Mode                                                   */
/* Purpose:  This function sets the receiver operating mode.                 */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actRECMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":INST REC\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Run Scan                                                        */
/* Purpose:  In receiver mode this function initiates new scan measurement.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actRECRunScan (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":INIT2\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Hold Scan                                                       */
/* Purpose:  In receiver mode this function interrupts a current scan        */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actRECHoldScan (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":HOLD\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Stop Scan                                                       */
/* Purpose:  In receiver mode this function aborts a current measurement and */
/*           resets the trigger system.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actRECStopScan (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":ABOR\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Init Single Measurement                                         */
/* Purpose:  In receiver mode this function initiates single measurement.    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actRECInitSweep (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":INIT\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Continue Sweep                                                  */
/* Purpose:  In receiver mode this function continues the sweep from the     */
/*           current sweep position.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actRECContSweep (ViSession instrSession, ViInt32 window)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (window, 1, 2))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, ":INIT%ld:CONM\n", window);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDPower Mode                                                    */
/* Purpose:  This function sets the CDPower (Code Domain Power Measurement   */
/*           Mode) operating mode.                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCDPMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":INST CDP\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDPower MS Mode                                                */
/* Purpose:  This function sets the WCDPower MS operating mode.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actWCDPMSMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":INST:SEL MWCD\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Level Auto Adjust                                           */
/* Purpose:  This function is used for setting automatically the RF          */
/*           attenuation and IF gain to the level of the applied signal. The */
/*           instrument is to be switched to the ATTEN MANUAL mode so as to  */
/*           set the RF attenuation and IF gain separately to optimum values.*/
/*           This mode is maintained after changing from code-domain power   */
/*           measurements to the analyzer or vector analyzer modes.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCDPAutoAdj (ViSession instrSession, ViInt32 timeout)
{
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;
    
    if (timeout < 0)
        VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71 or FSIQK72 or FSIQK73. */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    if ((rsfsex_status = rsfsex_waitOPC (instrSession, ":SENS:CDP:LEV:ADJ;*OPC?\n",
        buffer, timeout)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: CDP Marker To                                                   */
/* Purpose:  This function changes instrument parameters via currently active*/
/*           marker.                                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCDPMarkTo (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 mkrFunction)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71, FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (mkrFunction, 0, 7))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, ":CALC%ld:MARK%ld:FUNC:%s\n", window, markerNumber,
        mkrCPDFunctionArr[mkrFunction]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get CDP Measurement                                             */
/* Purpose:  This function queries the measured and calculated code domain   */
/*           power values.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCDPMarkMeas (ViSession instrSession, 
                ViInt32 window, ViInt32 markerNumber, ViInt32 measurement,
                ViReal64 _VI_FAR measurementResult[], 
                ViPInt32 measurementResultCount)
{
    ViStatus          rsfsex_status = VI_SUCCESS;
    ViUInt32          retCnt = 0;
    ViChar            buffer[BUFFER_SIZE];
    rsfsex_instrRange instrPtr;
    ViInt32           count, scanItem;
    ViReal64          *p2data = measurementResult;

    if (measurementResultCount) *measurementResultCount = 0;
    
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x4000000)) { /* available only with option FSIQK71. */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (measurement, 0, 7))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:CDP:RES? %s\n", window, markerNumber,
        measurementCDPArr[measurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    do {
        buffer[retCnt] = '\0';
        if (retCnt > 0) retCnt--;
    } while (buffer[retCnt] == '\r' || buffer[retCnt] == '\n');
    
    strcat(buffer, ",");
    count = 1;
    while ((scanItem = sscanf (buffer, "%le,%[^\r\n]", p2data, buffer)) > 1)
        {
        count++;
        p2data++;
        }

    if (scanItem < 1)
    {
        count = 0;
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }

    if (measurementResultCount) *measurementResultCount = count;

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;
    
    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get WCDP Measurement                                            */
/* Purpose:  This function queries the measured and calculated results of the*/
/*           WCDMA code domain power measurement.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actWCDPMarkMeas (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 measurement,
                ViPReal64 measurementResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;    
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rsfsex_invalidViInt32Range (measurement, 0, 15))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:WCDP:RES? %s\n", window,
        markerNumber, measurementWCDPArr[measurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measurementResult) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get WCDP MS Measurement                                         */
/* Purpose:  This function queries the measured and calculated results of the*/
/*           WCDMA code domain power measurement.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actWCDPMSMarkMeas (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber, ViInt32 measurement,
                ViPReal64 measurementResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;    
    if (!(instrPtr -> option & 0x10000000)) { /* available only with option FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }
/*
    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;
*/
    if (rsfsex_invalidViInt32Range (measurement, 0, 15))
        return VI_ERROR_PARAMETER4;

    sprintf (buffer, "*CLS;:CALC:MARK:FUNC:WCDP:MS:RES? %s\n",
        measurementWCDPMSArr[measurement]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (measurement == 14) /* Channel Mapping */
        {
        if ((memchr (buffer, 'I', 1) == NULL) && (memchr (buffer, 'Q', 1) == NULL))
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        /* I .. 0.0, Q .. 1.0 */
        *measurementResult = (memchr (buffer, 'I', 1) != NULL) ? 0.0 : 1.0;
        }
    else  /* Other measurements */
        if (sscanf (buffer, "%le", measurementResult) != 1)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get CDP Crest Factor                                            */
/* Purpose:  This function queries the Crest factor in the time domain       */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actCDPMarkCrest (ViSession instrSession,
                ViInt32 window, ViInt32 markerNumber,
                ViPReal64 measurementResult)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;    
    if (!(instrPtr -> option & 0x1C000000)) { /* available only with option FSIQK71, FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if (rsfsex_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (markerNumber, 1, 4))
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, "*CLS;:CALC%ld:MARK%ld:FUNC:CREST?\n", window, markerNumber);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measurementResult) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: WCDPower Mode                                                   */
/* Purpose:  This function sets the WCDPower (Wide Code Domain Power         */
/*           Measurement Mode) operating mode.                               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_actWCDPMode (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x8000000)) { /* available only with option FSIQK72. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    sprintf (buffer, ":INST WCDP\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Trace Data                                                 */
/* Purpose:  This function reads out trace data from the instrument.         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadTrace (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 noofPoints,
                ViReal64 _VI_FAR traceData[])
{
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *exBuf = 0;
    ViReal32    *temp;
    ViInt32     lenLength, i = 0;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;
    ViReal64    *p2output = traceData;
    ViInt32     count = 0;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    if (rsfsex_invalidViInt32Range (sourceTrace, 0, 3))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM REAL,32;*CLS;:TRAC? %s\n", traceNamesArr[sourceTrace]);

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            
            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 2)))
                return VI_ERROR_ALLOC;
            /* Read exact number of bytes equal to number of points. */
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                return rsfsex_status;

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
        
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 1)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 1, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
        }

    /* Convert binary data into array of ViReal64 types. */
    count /= 4;
    /* Binary data byte order (MOTOROLA or INTEL). */
    rsfsex_SWAP_32(exBuf, count);
    /* Pointer to data */
    temp = (ViReal32*)(exBuf);
    for (i = 0; i < count; i++)
        *p2output++ = (ViReal64)*temp++;
    
    if (noofPoints) *noofPoints = count;

    if (exBuf) /* If not NULL pointer, then deallocate memory. */
        free (exBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Symbol Data                                                */
/* Purpose:  This function reads out symbol data from the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadSymbol (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 noofPoints,
                ViChar _VI_FAR symbolData[])
{
    ViUInt32    retCnt = 0;
    ViInt32     lenLength, i = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViPByte     pToData;
    ViChar      *rdBuf = 0;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    if (rsfsex_invalidViInt32Range (sourceTrace, 0, 3))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM UINT;*CLS;:TRAC? %s\n", traceNamesArr[sourceTrace]);

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;

            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
            
            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", noofPoints) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Read exact number of bytes equal to the number of points. */
        
            /* Alocate memory space */
            if (!(rdBuf = malloc (*noofPoints + 2)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, rdBuf, *noofPoints + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (rdBuf) free (rdBuf);
                return rsfsex_status;
                }

            /* Switch to On using of termination character. */
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
        
            /* Parse data header to get no_of_items */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", noofPoints) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            /* Allocate memory space */
            if (!(rdBuf = malloc (*noofPoints + 1)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, rdBuf, *noofPoints + 1, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (rdBuf) free (rdBuf);
                return rsfsex_status;
                }
        break;
    }

    /* Convert binary data into desired format. */
    pToData = (ViByte*)(rdBuf); /* Pointer to data */

    for (i = 0; i < *noofPoints; i++)
        symbolData[i] = pToData[i];

    if (rdBuf) /* If not NULL pointer, then deallocate memory. */
        free (rdBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Write Trace Data                                                */
/* Purpose:  This function writes trace data to the instrument.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataWriteTrace (ViSession instrSession,
                ViInt32 destinationTrace, ViInt32 noofPoints,
                ViReal64 _VI_FAR traceData[])
{
    ViUInt32    retCnt = 0;
    ViReal32    *temp;
    ViInt32     i = 0, num = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *exBuf;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB,
                endOut = VI_ASRL_END_NONE;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, &endOut)) < VI_SUCCESS)
        return rsfsex_status;

    if (rsfsex_invalidViInt32Range (destinationTrace, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (noofPoints, 0, 250000))
        return VI_ERROR_PARAMETER3;

    num = sprintf (buffer, "%ld", noofPoints*4);
    num = sprintf (buffer, ":FORM REAL,32;:TRAC %s, #%ld%ld",
                   traceNamesArr[destinationTrace], num, noofPoints*4);

    /* Alocate memory space */
    if (!(exBuf = malloc (num + noofPoints*4)))
        return VI_ERROR_ALLOC;

    strncpy (exBuf, buffer, num);
    /* Binary data byte order (MOTOROLA or INTEL). */
    rsfsex_SWAP_32(exBuf+num, noofPoints);
    /* Pointer to begining of data */
    temp = (ViReal32*)(exBuf+num);
    for (i = 0; i < noofPoints; i++)
        *temp++ = (ViReal32) *traceData++;
    num += (noofPoints*4);

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, VI_ASRL_END_NONE)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }

            /* Write binary data into instrument. */
            if ((rsfsex_status = viWrite (instrSession, exBuf, num, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, endOut);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }

            /* Switch to On using of termination character. */
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, endOut);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        
            /* Terminate data input. */
            if ((rsfsex_status = viPrintf (instrSession, "%s", "\n")) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, ":SYST:COMM:GPIB:SELF:RTER EOI\n",
                30, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            if ((rsfsex_status = viWrite (instrSession, exBuf, num, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            if ((rsfsex_status = viWrite (instrSession, ":SYST:COMM:GPIB:SELF:RTER LFEOI\n",
                32, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
        }

    if (exBuf) /* If not NULL pointer, then deallocate memory. */
        free (exBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Write Symbol Data                                               */
/* Purpose:  This function writes symbol data to the instrument.             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataWriteSymbol (ViSession instrSession,
                ViInt32 destinationTrace, ViInt32 noofPoints,
                ViString symbolData)
{
    ViUInt32    retCnt = 0;
    ViInt32     num = 0, i = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViPByte     pToData;
    ViChar      *wrtBuf;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB,
                endOut = VI_ASRL_END_NONE;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, &endOut)) < VI_SUCCESS)
        return rsfsex_status;

    if (rsfsex_invalidViInt32Range (destinationTrace, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViInt32Range (noofPoints, 0, 6400))
        return VI_ERROR_PARAMETER3;

    num = sprintf (buffer, "%ld", noofPoints);
    num = sprintf (buffer, ":FORM UINT;:TRAC %s,#%ld%ld",
                   traceNamesArr[destinationTrace], num, noofPoints);

    /* Alocate memory space */
    if (!(wrtBuf = malloc (num + noofPoints)))
        return VI_ERROR_ALLOC;

    strncpy (wrtBuf, buffer, num);

    pToData = (ViByte*)(wrtBuf+num); /* Pointer to data */

    for (i = 0; i < noofPoints; i++)
        *pToData++ = *symbolData++;

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, VI_ASRL_END_NONE)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }

            /* Write binary data into instrument. */
            if ((rsfsex_status = viWrite (instrSession, wrtBuf, (num + noofPoints),
                &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, endOut);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }

            /* Restore using of termination character. */
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_OUT, endOut);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);

            /* Terminate data input. */
            if ((rsfsex_status = viPrintf (instrSession, "%s", "\n")) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, ":SYST:COMM:GPIB:SELF:RTER EOI\n",
                30, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }
            if ((rsfsex_status = viWrite (instrSession, wrtBuf, (num + noofPoints), &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }
            if ((rsfsex_status = viWrite (instrSession, ":SYST:COMM:GPIB:SELF:RTER LFEOI\n",
                32, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (wrtBuf) free (wrtBuf);
                return rsfsex_status;
                }
        break;
    }
    
    if (wrtBuf) /* If not NULL pointer, then deallocate memory. */
        free (wrtBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Trace I/Q Data                                             */
/* Purpose:  This function will start a measurement and read I/Q trace data  */
/*           results.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadTraceIQ (ViSession instrSession,
                ViInt32 bufferSize, ViPInt32 noofPoints, ViReal64 _VI_FAR realPartsI[],
                ViReal64 _VI_FAR imaginaryPartsQ[], ViPReal64 mean, ViPReal64 peak)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *exBuf = 0;
    ViInt32     count = 0;
    ViInt32     lenLength, i = 0;
    ViUInt16    interface = VI_INTF_GPIB;
    ViReal32    *p2values = VI_NULL;
    ViInt32     getSignalPower = (!((mean == VI_NULL) && (peak == VI_NULL)));
    rsfsex_instrRange instrPtr;
    
    if (bufferSize < 0)
        return VI_ERROR_PARAMETER2;
    if (bufferSize > 0)
    {
    if (realPartsI == VI_NULL)
       return VI_ERROR_PARAMETER4;
    if (imaginaryPartsQ == VI_NULL)
        return VI_ERROR_PARAMETER5;
    }
    
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x2000000)) { /* available only with option FSIQB70. */
        return RSFSEX_ERROR_INSTRUMENT_OPTION;
    }

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    sprintf (buffer, ":FORM REAL,32;*CLS;:TRAC:IQ:%s?\n", (getSignalPower) ? "DME" : "DATA");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 2)))
                return VI_ERROR_ALLOC;
            /* Read exact number of bytes equal to number of points. */
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
        
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1)
            {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 4)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 4, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
    }

    if (count <= 4)
    {
        free (exBuf);
        return RSFSEX_ERROR_INSTRUMENT_IQ_OVERLOAD;
    }

    /* Convert binary data into array of ViReal64 types. */
    if (getSignalPower)
    {
        if (count < 8)
        {
            free (exBuf);
            return RSFSEX_ERROR_INSTRUMENT_IQ_OVERLOAD;
        }

        count -= 8;  /* last two values are mean and peak signal power */
        p2values = (ViReal32*)(exBuf + count);
    }

    count /= 4; /* number of I and Q samples */
    /* Binary data byte order (MOTOROLA or INTEL). */
    if (bufferSize > 0)
        rsfsex_SWAP_32(exBuf, (getSignalPower) ? (count + 2) : count);

    count /= 2; /* number of I or Q samples */

    if (bufferSize > 0)
        {
        ViInt32     loopCount   = count;
        ViReal64    *p2I        = realPartsI,
                    *p2Q        = imaginaryPartsQ;
        ViReal32    *tp2I,
                    *tp2Q;

        /* Pointer to I data */
        tp2I = (ViReal32*)(exBuf);
        /* pointer to Q data */
        tp2Q = tp2I + loopCount;
        
        loopCount = (bufferSize < loopCount) ? bufferSize : loopCount;

        /* number of points in one array I or Q */
        for (i = 0; (i < loopCount); i++)
            {
            *p2I++ = (ViReal64)*tp2I++;
            *p2Q++ = (ViReal64)*tp2Q++;
            }
        
        if (noofPoints)
            *noofPoints = loopCount;
        }

    if (mean != VI_NULL)
        {
        *mean = (ViReal64)*p2values;
        }
    if (peak != VI_NULL)
        {
        p2values++;
        *peak = (ViReal64)*p2values;
        }
    if (exBuf) /* If not NULL pointer, then deallocate memory. */
        free (exBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;
    
    if (count > bufferSize)
        rsfsex_status = count;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read CdmaOne Trace Data                                         */
/* Purpose:  This function reads trace data out of the instrument. In case of*/
/*           CDP Measurement only trace 1 can be read out. Independently of  */
/*           the display mode (CDP, CDP Ratio, Error Summary, etc.)          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadTraceCdmaOne (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 noofValues,
                ViReal64 _VI_FAR traceData[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (sourceTrace, 0, 0)) /* Trace 1 only */
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr->option & 0x4000000)) { /* available only with option FSIQK71. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if ((rsfsex_status = rsfsex_dataReadTrace (instrSession, 0, noofValues,
        traceData)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read WCDMA Trace Data                                           */
/* Purpose:  This function reads trace data out of the instrument. Only      */
/*           TRACE1 or TRACE2 can be queried depending on the display mode   */
/*           (CODE PWR ABSOLUTE / RELATIVE , CHANNEL TABLE (TRACE1), RESULT  */
/*           SUMMARY (TRACE2), POWER VS SLOT (TRACE2), SYMBOL EVM (TRACE2),  */
/*           PK CODE DOMAIN ERR and MODULATION ACCURACY (TRACE2), SYMBOL     */
/*           CONST (TRACE2) and BITSTREAM (TRACE2)).                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadTraceWCDMA (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 noofValues,
                ViReal64 _VI_FAR traceData[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if (rsfsex_invalidViInt32Range (sourceTrace, 0, 1))
        return VI_ERROR_PARAMETER2;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if ((rsfsex_status = rsfsex_dataReadTrace (instrSession, sourceTrace,
        noofValues, traceData)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read ABIT Stream Data                                           */
/* Purpose:  This function reads trace data out of the instrument. ABITstream*/
/*           can be set only if WCDP Measurement Mode (confWCDPMeasMode),    */
/*           item  5 - CDP Bit Stream is selected (in the lower bitstream    */
/*           window). This function returns the bitstreams of all 15 slots   */
/*           one after the other.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadABIT (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 noofPoints,
                ViReal64 _VI_FAR traceData[])
{
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *exBuf = 0;
    ViReal32    *temp;
    ViInt32     lenLength, i = 0;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;
    ViReal64    *p2output = traceData;
    ViInt32     count = 0;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    sprintf (buffer, ":FORM REAL,32;*CLS;:TRAC? ABIT\n");

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            
            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 2)))
                return VI_ERROR_ALLOC;
            /* Read exact number of bytes equal to number of points. */
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                return rsfsex_status;

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
        
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 1)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 1, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
    }

    /* Convert binary data into array of ViReal64 types. */
    count /= 4;
    /* Binary data byte order (MOTOROLA or INTEL). */
    rsfsex_SWAP_32(exBuf, count);
    /* Pointer to data */
    temp = (ViReal32*)(exBuf);
    for (i = 0; i < count; i++)
        *p2output++ = (ViReal64)*temp++;
    
    if (noofPoints) *noofPoints = count;

    if (exBuf) /* If not NULL pointer, then deallocate memory. */
        free (exBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read WCDP Trace Data                                            */
/* Purpose:  This function reads trace data out of the instrument. Data can  */
/*           be queried depending on the display mode (PWCDP, CTABLE).       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadTraceWCDP (ViSession instrSession,
                ViInt32 sourceTrace, ViPInt32 noofPoints,
                ViReal64 _VI_FAR traceData[])
{
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *exBuf = 0;
    ViReal32    *temp = 0;
    ViInt32     lenLength, i = 0;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;
    ViReal64    *p2output = traceData;
    ViInt32     count = 0;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if (!(instrPtr -> option & 0x18000000)) { /* available only with option FSIQK72 or FSIQK73. */
        rsfsex_status = RSFSEX_ERROR_INSTRUMENT_OPTION;
        return rsfsex_status;
    }

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    if (rsfsex_invalidViInt32Range (sourceTrace, 0, 1))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":FORM REAL,32;*CLS;:TRAC? %s\n", (sourceTrace == 0) ? "PWCD" : "CTAB");

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            
            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 2)))
                return VI_ERROR_ALLOC;
            /* Read exact number of bytes equal to number of points. */
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                return rsfsex_status;

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
        
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                return rsfsex_status;
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", &count) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            /* Allocate memory space */
            if (!(exBuf = malloc (count + 1)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, exBuf, count + 1, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
    }

    /* Convert binary data into array of ViReal64 types. */
    count /= 4;
    /* Binary data byte order (MOTOROLA or INTEL). */
    rsfsex_SWAP_32(exBuf, count);
    /* Pointer to data */
    temp = (ViReal32*)(exBuf);
    for (i = 0; i < count; i++)
        *p2output++ = (ViReal64)*temp++;
    
    if (noofPoints) *noofPoints = count;

    if (exBuf) /* If not NULL pointer, then deallocate memory. */
        free (exBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Receiver Data                                              */
/* Purpose:  This function is possible to use only as a query for single     */
/*           measurements in the receiver mode. The values of all activated  */
/*           detectors are transferred separated by commas in the following  */
/*           order: POS, RMS, AVER, QPE. For inactive detectors, the value   */
/*           and the comma are omitted at the position(s) in question.       */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadReceiver (ViSession instrSession,
                ViPReal64 firstDetector, ViPReal64 secondDetector,
                ViPReal64 thirdDetector, ViPReal64 fourthDetector)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    *firstDetector = 0.0;
    *secondDetector = 0.0;
    *thirdDetector = 0.0;
    *fourthDetector = 0.0;
    
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    sprintf (buffer, "*CLS;:TRAC? SING\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le%*1s%le%*1s%le%*1s%le", firstDetector, secondDetector,
        thirdDetector, fourthDetector) < 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Scan Data                                                  */
/* Purpose:  This function returns the trace points data. This function is   */
/*           only possible to use in form of a query during scan             */
/*           measurements. The number of transmitted measurement results     */
/*           depends on the scan settings.                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadScan (ViSession instrSession,
                ViPInt32 noofPoints, ViChar _VI_FAR statusData[],
                ViPInt32 traceStatus, ViReal64 _VI_FAR trace1[],
                ViReal64 _VI_FAR trace2[], ViReal64 _VI_FAR trace3[],
                ViReal64 _VI_FAR trace4[])
{
    ViUInt32    retCnt = 0;
    ViInt32     lenLength = 0, T1 = 0, T2 = 0, T3 = 0, T4 = 0, i = 0;
    ViReal32    *temp = 0; ViInt32 *p2data = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViChar      *exBuf = 0;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;
    rsfsex_instrRange instrPtr;

    /* Initial settings. */
    *noofPoints = 0;
    statusData[0] = '\0';
    *traceStatus = 0;
    
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (!statusData)
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":FORM REAL,32;*CLS;:TRAC? SCAN\n");

    /* Returns an array of measurement results.  Size of this array
    must be at least 1.5 MB (1500000 Bytes).

    Note:

    Structure of data:
    - 4 byte: trace status:
     bit 0 to 9 subscan
     bit 10: last block of subscan
     Bit 11: last block of last subscan of scan
     Bit 12: last of all blocks (for multiple scans after the last
    scan)
    - 4 bytes:number n of the transmitted measurement results of a
    trace
    - 4 byte:trace1 active (0/1)
    - 4 byte:trace2 active (0/1)
    - 4 byte:trace3 active (0/1)
    - 4 byte:trace4 active (0/1)
    - n*4 bytes:measurement results of trace 1 if trace 1 is active
    - n*4 bytes:measurement results of trace 2 if trace 2 is active
    - n*4 bytes:measurement results of trace 3 if trace 3 is active
    - n*4 bytes:measurement results of trace 4 if trace 4 is active
    - n*1 byte:status information per measurement result:
      bit 0: underrange trace1
      bit 1: underrange trace2
      bit 2: underrange trace3
      bit 3: underrange trace4
      bit 4: overrange trace1 to trace4

    Where n is number of results. */

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Support. */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0) {
                if (viWrite (instrSession, "*CLS\n", 5, &retCnt) < 0)
                    return rsfsex_status;
                return rsfsex_status;
            }

            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", noofPoints) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
        
            /* Allocate memory space */
            if (!(exBuf = malloc (*noofPoints + 2)))
                return VI_ERROR_ALLOC;
            /* Read exact number of bytes equal to number of points. */
            if ((rsfsex_status = viRead (instrSession, exBuf, *noofPoints + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }

            /* Switch to On using of termination character. */
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0) {
                if (viWrite (instrSession, "*CLS\n", 5, &retCnt) < 0)
                    return rsfsex_status;
                return rsfsex_status;
            }
        
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                return rsfsex_status;

            /* Get header info. */
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                return rsfsex_status;
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", noofPoints) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            /* Allocate memory space */
            if (!(exBuf = malloc (*noofPoints + 1)))
                return VI_ERROR_ALLOC;
            if ((rsfsex_status = viRead (instrSession, exBuf, *noofPoints + 1, &retCnt)) < 0)
                {
                /* If not NULL pointer, then deallocate memory. */
                if (exBuf) free (exBuf);
                return rsfsex_status;
                }
        break;
    }

    /* Get data info. */
    p2data = (ViInt32*)(exBuf);

    /* Binary data byte order (MOTOROLA or INTEL). */
    rsfsex_SWAP_32(exBuf, 2);

    *traceStatus = (ViInt32)*p2data++;
    *noofPoints = (ViInt32)*p2data++;
    T1 = (ViInt32)*p2data++;
    T2 = (ViInt32)*p2data++;
    T3 = (ViInt32)*p2data++;
    T4 = (ViInt32)*p2data++;

    /* Get trace data. */
    if (T1 || T2 || T3 || T4) {
        /* Pointer to data of first active trace. */
        temp = (ViReal32*)(exBuf+24);
        /* Trace 1 */
        if (T1)
        {
            /* Binary data byte order (MOTOROLA or INTEL). */
            rsfsex_SWAP_32(exBuf+24, *noofPoints);
            for (i = 0; i < *noofPoints; i++)
                *trace1++ = (ViReal64)*temp++;
        }
        else
            trace1 = memset (trace1, 0, 8*(*noofPoints));
        /* Trace 2 */
        if (T2)
        {
            /* Binary data byte order (MOTOROLA or INTEL). */
            rsfsex_SWAP_32(exBuf+24+4*(*noofPoints)*(T1), *noofPoints);
            for (i = 0; i < *noofPoints; i++)
                *trace2++ = (ViReal64)*temp++;
        }
        else
            trace2 = memset (trace2, 0, 8*(*noofPoints));
        /* Trace 3 */
        if (T3)
        {
            /* Binary data byte order (MOTOROLA or INTEL). */
            rsfsex_SWAP_32(exBuf+24+4*(*noofPoints)*(T1+T2), *noofPoints);
            for (i = 0; i < *noofPoints; i++)
                *trace3++ = (ViReal64)*temp++;
        }
        else
            trace3 = memset (trace3, 0, 8*(*noofPoints));
        /* Trace 4 */
        if (T4)
        {
            /* Binary data byte order (MOTOROLA or INTEL). */
            rsfsex_SWAP_32(exBuf+24+4*(*noofPoints)*(T1+T2+T3), *noofPoints);
            for (i = 0; i < *noofPoints; i++)
                *trace4++ = (ViReal64)*temp++;
        }
        else
            trace4 = memset (trace4, 0, 8*(*noofPoints));
    }
    else {
        trace1 = memset (trace1, 0, 8*(*noofPoints));
        trace2 = memset (trace2, 0, 8*(*noofPoints));
        trace3 = memset (trace3, 0, 8*(*noofPoints));
        trace4 = memset (trace4, 0, 8*(*noofPoints));
    }

    /* Remove header and remaining data - move pointer to status data. */
    statusData = memmove (statusData,
        exBuf+24+4*(*noofPoints)*(T1+T2+T3+T4), *noofPoints);

    statusData[*noofPoints] = '\0';

    if (exBuf) /* If not NULL pointer, then deallocate memory. */
        free (exBuf);

    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Status Data                                                */
/* Purpose:  This function returns the status data. This function is only    */
/*           possible to use in form of a query during scan measurements.    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadStatus (ViSession instrSession,
                ViPInt32 noofPoints, ViChar _VI_FAR statusData[])
{
    ViUInt32    retCnt = 0;
    ViInt32     lenLength = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    /* available only with FSE? or ESIB */
    if ((instrPtr -> instrVer < 15) || (instrPtr -> instrVer > 19))
        return RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL;

    if (!statusData)
        return VI_ERROR_PARAMETER3;

    sprintf (buffer, ":FORM UINT,8;*CLS;:TRAC? STAT\n");

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;

            /* Switch to Off using of termination character. */
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE)) < 0)
                return rsfsex_status;
            if ((rsfsex_status =  viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE)) < 0)
                return rsfsex_status;

            /* Parse binary data header. */
            if ((rsfsex_status = viRead (instrSession, buffer, 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            buffer[retCnt] = '\0';
            if (sscanf (buffer, "#%1d", &lenLength) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
        
            /* Get number of points. */
            if ((rsfsex_status = viRead (instrSession, buffer, lenLength, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }
        
            buffer[retCnt] = '\0';
            if (sscanf (buffer, "%ld", noofPoints) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
        
            /* Read exact number of bytes equal to number of points. */
            if ((rsfsex_status = viRead (instrSession, statusData, *noofPoints + 2, &retCnt)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rsfsex_status;
                }

            /* Switch to On using of termination character. */
            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);

            statusData[*noofPoints] = 0;
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
                return rsfsex_status;
            /* At least 252 kB (252000 Bytes) buffer is required. */        
            if ((rsfsex_status = viRead (instrSession, statusData, DATA_BUFFER_SIZE * 2, &retCnt)) < 0)
                return rsfsex_status;
            /* Get header info. */
            buffer[retCnt] = '\0';
            if (sscanf (statusData, "#%1d", &lenLength) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

            strncpy (buffer, (statusData+2), lenLength);
            buffer[lenLength] = '\0';

            if (sscanf (buffer, "%ld", noofPoints) != 1) {
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;;
            }
            /* Remove header - move pointer to data. */
            statusData = memmove (statusData, statusData+lenLength+2, *noofPoints);
        break;
    }
    
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Burst Values                                               */
/* Purpose:  This function starts the measurement of the phase and frequency */
/*           error of the base station or mobile and reads out the average of*/
/*           the RMS-measurement of the phase error taken over the selected  */
/*           number of bursts.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadBurst (ViSession instrSession,
                ViBoolean phaseFreqError, ViBoolean resultType,
                ViBoolean measResult, ViPReal64 measuredValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (phaseFreqError))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (measResult))
        return VI_ERROR_PARAMETER4;

    if (phaseFreqError == VI_FALSE) {
        if (rsfsex_invalidViBooleanRange (resultType))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, "*CLS;:READ:BURS:%s:%s:%s?\n", phaseFreqErrorArr[phaseFreqError],
            burstResultTypeArr[resultType], burstMeasResultArr[measResult]);
    }
    else
        sprintf (buffer, "*CLS;:READ:BURS:%s:%s?\n", phaseFreqErrorArr[1],
            burstMeasResultArr[measResult]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measuredValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Burst Status Values                                        */
/* Purpose:  This function starts the measurement of the phase and frequency */
/*           error of the base station or mobile and reads out the status of */
/*           the RMS (peak) measurement of the phase (frequency) error taken */
/*           over the selected number of bursts.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadBurstStatus (ViSession instrSession,
                ViBoolean phaseFreqError, ViBoolean resultType,
                ViPInt32 statusValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (phaseFreqError))
        return VI_ERROR_PARAMETER2;

    if (phaseFreqError == VI_FALSE) {
        if (rsfsex_invalidViBooleanRange (resultType))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, "*CLS;:READ:BURS:%s:%s:STAT?\n", phaseFreqErrorArr[phaseFreqError],
            burstResultTypeArr[resultType]);
    }
    else
        sprintf (buffer, "*CLS;:READ:BURS:%s:STAT?\n", phaseFreqErrorArr[1]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%ld", statusValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Burst MACC Values                                          */
/* Purpose:  This function starts the selected measurement of the modulation */
/*           accuracy of the base station or mobile and reads out the result */
/*           of the measurement for the selected number of bursts.           */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadBurstMACC (ViSession instrSession,
                ViInt32 MACCMeasurement, ViPInt32 status,  
                ViPReal64 average, ViPReal64 maximum)
{
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViBoolean   fetch = VI_FALSE;

    if (rsfsex_invalidViInt32Range (MACCMeasurement, 0, 4))
        return VI_ERROR_PARAMETER2;

    if (status)
        {
        sprintf (buffer, "*CLS;:READ:BURS:MACC:%s:STAT?\n", MACCMeasurementArr[MACCMeasurement]);

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%ld", status) != 1)
            {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
        fetch = VI_TRUE;
        }

    if (average)
    {
        sprintf (buffer, "*CLS;:%s:BURS:MACC:%s:AVER?\n", (fetch) ? "FETC" : "READ", MACCMeasurementArr[MACCMeasurement]);

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%le", average) != 1)
            {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }
        fetch = VI_TRUE;
        }

    if (maximum)
    {
        sprintf (buffer, "*CLS;:%s:BURS:MACC:%s:MAX?\n", (fetch) ? "FETC" : "READ",  MACCMeasurementArr[MACCMeasurement]);

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%le", maximum) != 1)
            {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

        }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: GSM Burst Reference Meas                                        */
/* Purpose:  This function starts the premeasurement and as a result provides*/
/*           the measured level in dBm.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadBurstRef (ViSession instrSession,
                ViPReal64 referenceLevel)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, "*CLS;:READ:BURST:REF?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", referenceLevel) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Burst Power                                                */
/* Purpose:  This function starts the measurement of the carrier output power*/
/*           of the base station or mobile and reads out the result.         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadPower (ViSession instrSession,
                ViInt32 powerMeasMode, ViPReal64 staticPowerCtrl,
                ViPReal64 dynamicPowerCtrl, ViPReal64 ratLevel,
                ViPReal64 actLevel, ViPReal64 delta, ViPInt32 status)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE], out1st[10];
    ViInt32 instr = 0;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (powerMeasMode, 0, 3))
        return VI_ERROR_PARAMETER2;

    /* ----------------------
        Function preconditions

            4: GSM BTS analysis
            5: GSM MS analysis
            
            Single measurement must be switched to "OFF"
    */

    if ((rsfsex_status = viWrite (instrSession, ":INST:NSEL?\n", 12, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%ld", &instr) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if ((instr < 4) || (instr > 5))
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    sprintf (buffer, ":CONF:POW:SING:STAT?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (strncmp (buffer, "0", 1) != 0)
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;
    /* ---------------------- */

    sprintf (buffer, "*CLS;:READ:BURS:POW%s?\n", powerMeasModeArr[powerMeasMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le,%le,%le,%le,%le,%[^\r\n]", staticPowerCtrl,
        dynamicPowerCtrl, ratLevel, actLevel, delta, out1st) != 6) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    /* PASSED = 0, FAILED = 1, FINISHED = 6 */

     *status = rsfsex_statusToInt(out1st);
     if (*status == -1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
     
    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Burst Power Individual                                     */
/* Purpose:  This function starts the measurement of the carrier output power*/
/*           of the base station or mobile and reads out the result.         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadPowerInd (ViSession instrSession,
                ViInt32 powerMeasMode, ViReal64 _VI_FAR staticPowerCtrl[],
                ViReal64 _VI_FAR dynamicPowerCtrl[], ViReal64 _VI_FAR ratLevel[],
                ViReal64 _VI_FAR actLevel[], ViReal64 _VI_FAR RBW[],
                ViInt32 _VI_FAR ARFCN[], ViReal64 _VI_FAR CF[],
                ViReal64 _VI_FAR attenuation[], ViInt32 _VI_FAR no_ofBursts[],
                ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViUInt32 retCnt = 0;
       ViChar buffer[BUFFER_SIZE_MEDIUM], tmpBuf[BUFFER_SIZE_MEDIUM], out1st[10];
    ViInt32 instr = 0;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (powerMeasMode, 0, 3))
        return VI_ERROR_PARAMETER2;

    /* ----------------------
        Function preconditions

            4: GSM BTS analysis
            5: GSM MS analysis
            
            Single measurement must be switched to "ON"
    */

    if ((rsfsex_status = viWrite (instrSession, ":INST:NSEL?\n", 12, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%ld", &instr) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if ((instr < 4) || (instr > 5))
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    sprintf (buffer, ":CONF:POW:SING:STAT?");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;

    if (strncmp (buffer, "1", 1) != 0)
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    /* ---------------------- */

    *cnt = 0;

    sprintf (buffer, "*CLS;:READ:BURS:POW%s?\n", powerMeasModeArr[powerMeasMode]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;

    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%le,%le,%le,%le,%le,%ld,%le,%le,%ld,%[^,],%[^\r\n]",
                &staticPowerCtrl[*cnt], &dynamicPowerCtrl[*cnt], &ratLevel[*cnt],
                &actLevel[*cnt], &RBW[*cnt], &ARFCN[*cnt], &CF[*cnt],
                &attenuation[*cnt], &no_ofBursts[*cnt], out1st, tmpBuf)) {
            case 11:
                status[*cnt] = rsfsex_statusToInt(out1st);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%le,%le,%le,%le,%le,%ld,%le,%le,%ld,%[^\r\n]",
                            &staticPowerCtrl[*cnt], &dynamicPowerCtrl[*cnt],
                            &ratLevel[*cnt], &actLevel[*cnt], &RBW[*cnt],
                            &ARFCN[*cnt], &CF[*cnt], &attenuation[*cnt],
                            &no_ofBursts[*cnt], out1st) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                status[*cnt] = rsfsex_statusToInt(out1st);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Spectrum                                                   */
/* Purpose:  This function provides the commands for starting measurements in*/
/*           the GSM BTS (option FSE-K11) and GSM MS (option FSE-K10)        */
/*           Analyzer mode, which are used to measure the power of the       */
/*           spectral components due to modulation and switching (modulation */
/*           spectrum, transient spectrum), and for reading out the results  */
/*           subsequently.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadSpectrum (ViSession instrSession,
                ViBoolean spectrumMeasMode, ViInt32 _VI_FAR index[],
                ViReal64 _VI_FAR startFreq[], ViReal64 _VI_FAR stopFreq[],
                ViReal64 _VI_FAR levels[], ViReal64 _VI_FAR limits[],
                ViInt32 _VI_FAR absRel[], ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE_MEDIUM], tmpBuf[BUFFER_SIZE_MEDIUM];
    ViChar      out1st[10], out2nd[10];
    
    if (rsfsex_invalidViBooleanRange (spectrumMeasMode))
        return VI_ERROR_PARAMETER2;
    if (cnt == VI_NULL)
        return VI_ERROR_INSTR_PARAMETER10;
    *cnt = 0;

    if (spectrumMeasMode == VI_TRUE)
        sprintf (buffer, "*CLS;:READ:SPEC:MOD?\n");
    else
        sprintf (buffer, "*CLS;:READ:SPEC:SWIT?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^,],%[^\r\n]",
                &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                &limits[*cnt], out1st, out2nd, tmpBuf)) {
            case 8:
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^\r\n]",
                        &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                        &limits[*cnt], out1st, out2nd) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Spurious                                                   */
/* Purpose:  This function provides the commands for starting measurements in*/
/*           the GSM BTS (option FSE-K11) and GSM MS (option FSE-K10)        */
/*           Analyzer mode, which are used to measure the power of spurious  */
/*           emissions, and for reading out the results subsequently. The    */
/*           measurement is performed in the currently set frequency range.  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataReadSpurious (ViSession instrSession,
                ViInt32 _VI_FAR index[], ViReal64 _VI_FAR startFreq[],
                ViReal64 _VI_FAR stopFreq[], ViReal64 _VI_FAR levels[],
                ViReal64 _VI_FAR limits[], ViInt32 _VI_FAR absRel[],
                ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE_MEDIUM], tmpBuf[BUFFER_SIZE_MEDIUM];
    ViChar out1st[10], out2nd[10];
    ViStatus rsfsex_status = VI_SUCCESS;
    
    if (cnt == VI_NULL)
        return VI_ERROR_INSTR_PARAMETER9;
    *cnt = 0;

    sprintf (buffer, "*CLS;:READ:SPURIOUS:ALL?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^,],%[^\r\n]",
                &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                &limits[*cnt], out1st, out2nd, tmpBuf)) {
            case 8:
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^\r\n]",
                            &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                            &limits[*cnt], out1st, out2nd) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Burst Values                                              */
/* Purpose:  This function is used for reading out results of measurements in*/
/*           the GSM BTS (option FSE-K11) or GSM MS (option FSE-K10) Analyzer*/
/*           mode, which are performed on individual bursts (Phase/Frequency */
/*           Error) without starting the measurement by themselves.          */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchBurst (ViSession instrSession,
                ViBoolean phaseFreqError, ViBoolean resultType,
                ViBoolean measResult, ViPReal64 measuredValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (phaseFreqError))
        return VI_ERROR_PARAMETER2;
    if (rsfsex_invalidViBooleanRange (measResult))
        return VI_ERROR_PARAMETER4;

    if (phaseFreqError == VI_FALSE) {
        if (rsfsex_invalidViBooleanRange (resultType))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, "*CLS;:FETC:BURS:%s:%s:%s?\n", phaseFreqErrorArr[phaseFreqError],
            burstResultTypeArr[resultType], burstMeasResultArr[measResult]);
    }
    else
        sprintf (buffer, "*CLS;:FETC:BURS:%s:%s?\n", phaseFreqErrorArr[1],
            burstMeasResultArr[measResult]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le", measuredValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Burst Status Values                                       */
/* Purpose:  This function reads out the status of the RMS (peak) measurement*/
/*           of the phase (frequency) error taken over the selected number of*/
/*           bursts.                                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchBurstStatus (ViSession instrSession,
                ViBoolean phaseFreqError, ViBoolean resultType,
                ViPInt32 statusValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (phaseFreqError))
        return VI_ERROR_PARAMETER2;

    if (phaseFreqError == VI_FALSE) {
        if (rsfsex_invalidViBooleanRange (resultType))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, "*CLS;:FETC:BURS:%s:%s:STAT?\n", phaseFreqErrorArr[phaseFreqError],
            burstResultTypeArr[resultType]);
    }
    else
        sprintf (buffer, "*CLS;:FETC:BURS:%s:STAT?\n", phaseFreqErrorArr[1]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%ld", statusValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Burst MACC Values                                         */
/* Purpose:  This function reads the selected measurement of the modulation  */
/*           accuracy of the base station or mobile for the selected number  */
/*           of bursts.                                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchBurstMACC (ViSession instrSession,
                ViInt32 MACCMeasurement, ViPInt32 status,  
                ViPReal64 average, ViPReal64 maximum)
{
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE];
    ViStatus    rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (MACCMeasurement, 0, 4))
        return VI_ERROR_PARAMETER2;

    if (status)
        {
        sprintf (buffer, "*CLS;:FETC:BURS:MACC:%s:STAT?\n", MACCMeasurementArr[MACCMeasurement]);

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%ld", status) != 1)
            {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

        }
    if (average)
        {
        sprintf (buffer, "*CLS;:FETC:BURS:MACC:%s:AVER?\n", MACCMeasurementArr[MACCMeasurement]);

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%le", average) != 1)
            {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

        }
    if (maximum)
        {
        sprintf (buffer, "*CLS;:FETC:BURS:MACC:%s:MAX?\n", MACCMeasurementArr[MACCMeasurement]);

        if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;
        if (sscanf (buffer, "%le", maximum) != 1)
            {
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

        }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Burst Power                                               */
/* Purpose:  This function reads out the results of all individual steps or  */
/*           result of the last step performed during the measurement of the */
/*           output power of the base station or mobile.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchPower (ViSession instrSession,
                ViBoolean resultMode, ViReal64 _VI_FAR staticPowerCtrl[],
                ViReal64 _VI_FAR dynamicPowerCtrl[], ViReal64 _VI_FAR ratLevel[],
                ViReal64 _VI_FAR actLevel[], ViReal64 _VI_FAR delta[],
                ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE_MEDIUM], tmpBuf[BUFFER_SIZE_MEDIUM];
    ViChar out1st[10];
    ViInt32 instr = 0;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (resultMode))
        return VI_ERROR_PARAMETER2;
    if (cnt == VI_NULL)
        return VI_ERROR_INSTR_PARAMETER9;

    /* ----------------------
        Function preconditions

            4: GSM BTS analysis
            5: GSM MS analysis
            
            Single measurement must be switched to "OFF"
    */
    if ((rsfsex_status = viWrite (instrSession, ":INST:NSEL?\n", 12, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%ld", &instr) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if ((instr < 4) || (instr > 5))
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    sprintf (buffer, ":CONF:POW:SING:STAT?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;

    if (strncmp (buffer, "0", 1) != 0)
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;
    /* ---------------------- */

    *cnt = 0;        

    if (resultMode == VI_FALSE)
        sprintf (buffer, "*CLS;:FETC:BURS:POW?\n");
    else
        sprintf (buffer, "*CLS;:FETC:BURS:POW:ALL?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%le,%le,%le,%le,%le,%[^,],%[^\r\n]",
                &staticPowerCtrl[*cnt], &dynamicPowerCtrl[*cnt],
                &ratLevel[*cnt], &actLevel[*cnt], &delta[*cnt],
                out1st, tmpBuf)) {
            case 7:
                status[*cnt] = rsfsex_statusToInt(out1st);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%le,%le,%le,%le,%le,%[^\r\n]",
                            &staticPowerCtrl[*cnt], &dynamicPowerCtrl[*cnt],
                            &ratLevel[*cnt], &actLevel[*cnt], &delta[*cnt],
                            out1st) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                status[*cnt] = rsfsex_statusToInt(out1st);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Burst Power Individual                                    */
/* Purpose:  This function reads out the results of all individual steps or  */
/*           result of the last step performed during the measurement of the */
/*           output power of the base station or mobile.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchPowerInd (ViSession instrSession,
                ViBoolean resultMode, ViReal64 _VI_FAR staticPowerCtrl[],
                ViReal64 _VI_FAR dynamicPowerCtrl[], ViReal64 _VI_FAR ratLevel[],
                ViReal64 _VI_FAR actLevel[], ViReal64 _VI_FAR RBW[],
                ViInt32 _VI_FAR ARFCN[], ViReal64 _VI_FAR CF[],
                ViReal64 _VI_FAR attenuation[], ViInt32 _VI_FAR no_ofBursts[],
                ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE_MEDIUM], tmpBuf[BUFFER_SIZE_MEDIUM];
    ViChar out1st[10];
    ViInt32 instr = 0;
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (resultMode))
        return VI_ERROR_PARAMETER2;
    if (cnt == VI_NULL)
        return VI_ERROR_INSTR_PARAMETER9;

    /* ----------------------
        Function preconditions

            4: GSM BTS analysis
            5: GSM MS analysis
            
            Single measurement must be switched to "ON"
    */

    if ((rsfsex_status = viWrite (instrSession, ":INST:NSEL?\n", 12, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%ld", &instr) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if ((instr < 4) || (instr > 5))
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;

    sprintf (buffer, ":CONF:POW:SING:STAT?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;

    if (strncmp (buffer, "1", 1) != 0)
        return RSFSEX_ERROR_INSTRUMENT_CONFLICT;
    /* ---------------------- */

    *cnt = 0;        

    if (resultMode == VI_FALSE)
        sprintf (buffer, "*CLS;:FETC:BURS:POW?\n");
    else
        sprintf (buffer, "*CLS;:FETC:BURS:POW:ALL?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;

    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%le,%le,%le,%le,%le,%ld,%le,%le,%ld,%[^,],%[^\r\n]",
                &staticPowerCtrl[*cnt], &dynamicPowerCtrl[*cnt], &ratLevel[*cnt],
                &actLevel[*cnt], &RBW[*cnt], &ARFCN[*cnt], &CF[*cnt],
                &attenuation[*cnt], &no_ofBursts[*cnt], out1st, tmpBuf)) {
            case 11:
                status[*cnt] = rsfsex_statusToInt(out1st);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%le,%le,%le,%le,%le,%ld,%le,%le,%ld,%[^\r\n]",
                            &staticPowerCtrl[*cnt], &dynamicPowerCtrl[*cnt],
                            &ratLevel[*cnt], &actLevel[*cnt], &RBW[*cnt],
                            &ARFCN[*cnt], &CF[*cnt], &attenuation[*cnt],
                            &no_ofBursts[*cnt], out1st) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                status[*cnt] = rsfsex_statusToInt(out1st);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Spectrum                                                  */
/* Purpose:  This function reads out results of measurements in the GSM BTS  */
/*           (FSE-K11) or GSM MS (FSE-K10) Analyzer mode, used to measure the*/
/*           power of the spectral contributions due to modulation and       */
/*           switching (modulation spectrum, transient spectrum) without     */
/*           first restarting a new measurement.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchSpectrum (ViSession instrSession,
                ViBoolean spectrumMeasMode, ViInt32 modRange,
                ViInt32 _VI_FAR index[], ViReal64 _VI_FAR startFreq[],
                ViReal64 _VI_FAR stopFreq[], ViReal64 _VI_FAR levels[],
                ViReal64 _VI_FAR limits[], ViInt32 _VI_FAR absRel[],
                ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE_MEDIUM], tmpBuf[BUFFER_SIZE_MEDIUM];
    ViChar out1st[10], out2nd[10];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (spectrumMeasMode))
        return VI_ERROR_PARAMETER2;
    if (cnt == VI_NULL)
        return VI_ERROR_INSTR_PARAMETER11;
    
    *cnt = 0;

    if (spectrumMeasMode == VI_FALSE)
        sprintf (buffer, "*CLS;:FETC:SPEC:SWIT?\n");
    else {
        if (rsfsex_invalidViInt32Range (modRange, 0, 4))
            return VI_ERROR_PARAMETER3;
        sprintf (buffer, "*CLS;:FETC:SPEC:MOD? %s\n", modRangeArr[modRange]);
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^,],%[^\r\n]",
                &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                &limits[*cnt], out1st, out2nd, tmpBuf)) {
            case 8:
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^\r\n]",
                            &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                            &limits[*cnt], out1st, out2nd) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Spectrum Reference                                        */
/* Purpose:  This function reads out the result of the spectrum              */
/*           premeasurement. Reported values are measured level, level       */
/*           corrected by means of the bandwidth and bandwidth.              */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchSpectrumRef (ViSession instrSession,
                ViBoolean spectrumMeasMode, ViPReal64 measuredLevel,
                ViPReal64 correctedLevel, ViPReal64 bandwidth)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViBooleanRange (spectrumMeasMode))
        return VI_ERROR_PARAMETER2;
    
    if (spectrumMeasMode == VI_FALSE)
        sprintf (buffer, "*CLS;:FETC:SPEC:SWIT:REF?\n");
    else
        sprintf (buffer, "*CLS;:FETC:SPEC:MOD:REF?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le,%le,%le", measuredLevel, correctedLevel,
        bandwidth) != 3)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch PTemplate Reference                                       */
/* Purpose:  This function reads out the result of the Power versus Time     */
/*           measurement. Reported values are measured level, level corrected*/
/*           by means of the bandwidth and bandwidth.                        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchPTemRef (ViSession instrSession,
                ViPReal64 measuredLevel, ViPReal64 correctedLevel,
                ViPReal64 bandwidth)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    sprintf (buffer, "*CLS;:FETC:PTEM:REF?\n");

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%le,%le,%le", measuredLevel, correctedLevel,
        bandwidth) != 3)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Fetch Spurious                                                  */
/* Purpose:  This function reads out results of measurements in the GSM BTS  */
/*           (FSE-K11) or GSM MS (FSE-K10) Analyzer mode which are used to   */
/*           determine spurious emissions, without first restarting a new    */
/*           measurement.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_dataFetchSpurious (ViSession instrSession,
                ViInt32 spuriousParameter, ViInt32 _VI_FAR index[],
                ViReal64 _VI_FAR startFreq[], ViReal64 _VI_FAR stopFreq[],
                ViReal64 _VI_FAR levels[], ViReal64 _VI_FAR limits[],
                ViInt32 _VI_FAR absRel[], ViInt32 _VI_FAR status[], ViPInt32 cnt)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt32    retCnt = 0;
    ViChar      buffer[BUFFER_SIZE_MEDIUM],
                tmpBuf[BUFFER_SIZE_MEDIUM];
    ViChar      out1st[10],
            out2nd[10];

    if (rsfsex_invalidViInt32Range (spuriousParameter, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (cnt == VI_NULL)
        return VI_ERROR_INSTR_PARAMETER10;
    *cnt = 0;

    sprintf (buffer, "*CLS;:FETCH:SPURIOUS:ALL? %s\n", limitSpurParamArr[spuriousParameter]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_checkBeforeRead (instrSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE_MEDIUM, &retCnt)) < 0)
        return rsfsex_status;
    buffer[retCnt] = '\0';

    while (retCnt != 0) {
        switch (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^,],%[^\r\n]",
                &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                &limits[*cnt], out1st, out2nd, tmpBuf)) {
            case 8:
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                retCnt = sprintf (buffer, "%s", tmpBuf);
                (*cnt)++;
            break;
            case (-1):
                if (sscanf (buffer, "%ld,%le,%le,%le,%le,%[^,],%[^\r\n]",
                    &index[*cnt], &startFreq[*cnt], &stopFreq[*cnt], &levels[*cnt],
                    &limits[*cnt], out1st, out2nd) < 0)
                {
                    return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }
                absRel[*cnt] = rsfsex_absRelToInt(out1st);
                status[*cnt] = rsfsex_statusToInt(out2nd);
                (*cnt)++;
                retCnt = 0;
            break;
            default:
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    }

    return rsfsex_status;
}

/*****************************************************************************/
/*-------- INSERT USER-CALLABLE INSTRUMENT-DEPENDENT ROUTINES HERE ----------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Instrument Options                                              */
/* Purpose:  This function returns the instrument version and the list       */
/*           of options which the instrument is equipped with.               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_OPTList (ViSession instrSession, ViChar optionsList[],
                         ViChar instrumentVersion[])
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < VI_SUCCESS)
        return rsfsex_status;

    if ((rsfsex_status = viWrite (instrSession, "*OPT?\n", 6, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%[^\r\n]", optionsList) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    sprintf (instrumentVersion, "%s", instrVersionList[instrPtr -> instrVer]);

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Set Preset Compatibility                                        */
/* Purpose:  This Function sets the preset compatibility between different   */
/*           models.                                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_setPresetCompatibility (ViSession instrSession,
                                                 ViInt32 compMode)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];
    ViInt32     bytes;

    if (rsfsex_invalidViInt32Range (compMode, 0, 1))
        return VI_ERROR_PARAMETER2;

    bytes = sprintf(buffer, ":SYST:PRES:COMP %s\n", (compMode) ? "FSE" : "OFF");

    if ((rsfsex_status = viWrite (instrSession, buffer, bytes, VI_NULL)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Firmware Update                                                 */
/* Purpose:  This function starts a firmware update using the files in the   */
/*           set directory.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_firmwareUpdate (ViSession instrSession,
                ViString setDirectory)
{
    ViUInt32 retCnt = 0;
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];

    if (!setDirectory)
        return VI_ERROR_PARAMETER2;

    sprintf(buffer, ":SYST:FIRM:UPD '%s'\n", setDirectory);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = rsfsex_sysStatus (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Set Status Register                                             */
/* Purpose:  This Function sets the Enable, NTransition, and PTransition bits*/
/*           of the Main, Power, Limit, Left Margin, and Sync status         */
/*           questionable registers.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_setStatusRegister (ViSession instrSession, ViInt32 registerOper,
                ViInt32 selStatusReg, ViInt32 enable, ViInt32 PTransition,
                ViInt32 NTransition)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (registerOper, 0, 2))
        return VI_ERROR_PARAMETER2;

    switch (registerOper) {
        case 0:
            sprintf (buffer, ":STAT:PRES\n");
        break;
        case 1:
            if (rsfsex_invalidViInt32Range (selStatusReg, 0, 7))
                return VI_ERROR_PARAMETER3;
            if (rsfsex_invalidViInt32Range (enable, 0, 65535))
                return VI_ERROR_PARAMETER4;
            if (rsfsex_invalidViInt32Range (PTransition, 0, 65535))
                return VI_ERROR_PARAMETER5;
            if (rsfsex_invalidViInt32Range (NTransition, 0, 65535))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":STAT:QUES%s:ENAB %ld;PTR %ld;NTR %ld\n",
                selStatusRegArr[selStatusReg], enable, PTransition, NTransition);
        break;
        case 2:
            if (rsfsex_invalidViInt32Range (enable, 0, 65535))
                return VI_ERROR_PARAMETER4;
            if (rsfsex_invalidViInt32Range (PTransition, 0, 65535))
                return VI_ERROR_PARAMETER5;
            if (rsfsex_invalidViInt32Range (NTransition, 0, 65535))
                return VI_ERROR_PARAMETER6;
            sprintf (buffer, ":STAT:OPER:ENAB %ld;PTR %ld;NTR %ld\n",
                enable, PTransition, NTransition);
        break;
    }

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Get Status Register                                             */
/* Purpose:  This function contains the commands for the querying status     */
/*           reporting system.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_getStatusRegister (ViSession instrSession,
                ViInt32 statusReg, ViPInt32 registerValue)
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if (rsfsex_invalidViInt32Range (statusReg, 0, 18))
        return VI_ERROR_PARAMETER2;

    sprintf (buffer, ":STAT:%s?\n", statusRegArr[statusReg]);

    if ((rsfsex_status = viWrite (instrSession, buffer, strlen (buffer), &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%ld", registerValue) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: State Checking                                                  */
/* Purpose:  This function switches ON/OFF state checking of the instrument  */
/*           (reading of the Standard Event Register and checking it for     */
/*           error). Nearly all driver function are using state checking.    */
/*           Switch this function to ON when debug your application. For     */
/*           better bus throughput and instruments performance switch it OFF.*/
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_errorCheckState (ViSession instrSession, ViBoolean state)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < VI_SUCCESS)
        return rsfsex_status;

    instrPtr -> errorChecking = state;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Write To Instrument                                             */
/* Purpose:  This function writes a command string to the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_writeInstrData (ViSession instrSession,
                ViString writeBuffer)
{
    ViStatus rsfsex_status = VI_SUCCESS;

    if ((rsfsex_status = viPrintf (instrSession, "%s\n", writeBuffer)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Read Instrument Buffer                                          */
/* Purpose:  This function reads the output buffer of the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_readInstrData (ViSession instrSession,
                ViInt32 numberBytesToRead, ViChar _VI_FAR readBuffer[],
                ViPInt32 numBytesRead)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt32    retCount;
    
    if (numBytesRead)
        *numBytesRead = 0L;

    if ((rsfsex_status = viRead (instrSession, readBuffer, numberBytesToRead,
        &retCount)) < 0)
        return rsfsex_status;
    
    readBuffer[retCount] = '\0'; 
    
    if (numBytesRead)
        *numBytesRead = (ViInt32)retCount;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_reset (ViSession instrSession)
{
    ViUInt32 retCnt = 0;
    ViStatus rsfsex_status = VI_SUCCESS;

    /*  Initialize the instrument to a known state.  */
    if ((rsfsex_status = viWrite (instrSession, "*RST;*CLS\n", 10, &retCnt)) < 0)
        return rsfsex_status;   

    if ((rsfsex_status = rsfsex_defaultInstrSetup (instrSession)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Self Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_self_test (ViSession instrSession, ViPInt32 testResult,
                    ViChar _VI_FAR testMessage[])
{
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if ((rsfsex_status = rsfsex_waitOPC (instrSession, "*TST?\n", buffer, 60000)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%hd", testResult) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (*testResult == 0)
        sprintf (testMessage, "Self-Test Passed.");
    else
        sprintf (testMessage, "Self-Test Failed.");

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_error_query (ViSession instrSession, ViPInt32 errCode,
                    ViChar _VI_FAR errMessage[])
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if ((rsfsex_status = viWrite (instrSession, ":SYST:ERR?\n", 11, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%ld,\"%[^\"]", errCode, errMessage) < 2)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_error_message (ViSession instrSession, ViStatus statusCode,
                    ViChar _VI_FAR errMessage[])
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViInt32 i;
    static rsfsex_tStringValPair statusDescArray[] = {
        {VI_WARN_NSUP_ID_QUERY,     "WARNING: ID Query not supported"},
        {VI_WARN_NSUP_RESET,        "WARNING: Reset not supported"},
        {VI_WARN_NSUP_SELF_TEST,    "WARNING: Self-test not supported"},
        {VI_WARN_NSUP_ERROR_QUERY,  "WARNING: Error Query not supported"},
        {VI_WARN_NSUP_REV_QUERY,    "WARNING: Revision Query not supported"},
        {VI_ERROR_PARAMETER1,   "ERROR: Parameter 1 out of range"},
        {VI_ERROR_PARAMETER2,   "ERROR: Parameter 2 out of range"},
        {VI_ERROR_PARAMETER3,   "ERROR: Parameter 3 out of range"},
        {VI_ERROR_PARAMETER4,   "ERROR: Parameter 4 out of range"},
        {VI_ERROR_PARAMETER5,   "ERROR: Parameter 5 out of range"},
        {VI_ERROR_PARAMETER6,   "ERROR: Parameter 6 out of range"},
        {VI_ERROR_PARAMETER7,   "ERROR: Parameter 7 out of range"},
        {VI_ERROR_PARAMETER8,   "ERROR: Parameter 8 out of range"},
        {VI_ERROR_FAIL_ID_QUERY,"ERROR: Identification query failed"},
        {VI_ERROR_INV_RESPONSE, "ERROR: Interpreting instrument response"},
        {VI_ERROR_INSTR_FILE_OPEN,    "ERROR: Opening the specified file"},
        {VI_ERROR_INSTR_FILE_WRITE,   "ERROR: Writing to the specified file"},
        {VI_ERROR_INSTR_INTERPRETING_RESPONSE, "ERROR: Interpreting the instrument's response"},
        {VI_ERROR_INSTR_PARAMETER9 ,  "ERROR: Parameter 9 out of range"},
        {VI_ERROR_INSTR_PARAMETER10,  "ERROR: Parameter 10 out of range"},
        {VI_ERROR_INSTR_PARAMETER11,  "ERROR: Parameter 11 out of range"},
        {VI_ERROR_INSTR_PARAMETER12,  "ERROR: Parameter 12 out of range"},
        {VI_ERROR_INSTR_PARAMETER13,  "ERROR: Parameter 13 out of range"},
        {VI_ERROR_INSTR_PARAMETER14,  "ERROR: Parameter 14 out of range"},
        {VI_ERROR_INSTR_PARAMETER15,  "ERROR: Parameter 15 out of range"},
        {VI_ERROR_INSTR_PARAMETER16,  "ERROR: Parameter 16 out of range"},
        {VI_ERROR_INSTR_PARAMETER17,  "ERROR: Parameter 17 out of range"},
        {VI_ERROR_TMO,                "ERROR: Operation timed out"},
        {RSFSEX_ERROR_INSTRUMENT_ERROR,  "ERROR: Instrument status error"},
        {RSFSEX_ERROR_INSTRUMENT_OPTION, "ERROR: Option not installed"},
        {RSFSEX_ERROR_INSTRUMENT_CONFLICT, "ERROR: Conflict with setup parameters"},
        {RSFSEX_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE, "ERROR: Data are not available"},
        {RSFSEX_ERROR_INSTRUMENT_PRESELECTOR, "ERROR: Preselector is not available."},
        {RSFSEX_ERROR_INSTRUMENT_NSUP_MODEL, "ERROR: Function does not supports currently used instrument."},
        {RSFSEX_ERROR_INSTRUMENT_IQ_OVERLOAD, "ERROR: Overload. Instrument does not return I/Q values."},
        {VI_NULL, VI_NULL}
    };

    rsfsex_status = viStatusDesc (instrSession, statusCode, errMessage);
    if (rsfsex_status == VI_WARN_UNKNOWN_STATUS) {
        for (i = 0; statusDescArray[i].stringName; i++) {
            if (statusDescArray[i].stringVal == statusCode) {
                sprintf (errMessage, "%s", statusDescArray[i].stringName);
                return (VI_SUCCESS);
            }
        }
        sprintf (errMessage, "Unknown Error 0x%.8X", statusCode);
        return (VI_WARN_UNKNOWN_STATUS);
    }

    rsfsex_status = VI_SUCCESS;
    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE];
    ViStatus rsfsex_status = VI_SUCCESS;

    if ((rsfsex_status = viWrite (instrSession, "*IDN?\n", 6, &retCnt)) < 0)
        return rsfsex_status;

    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%*[^,],%*[^,],%*[^,],%[^\r\n]", instrRev) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    sprintf (driverRev, "%s", RSFSEX_REVISION);

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rsfsex_close (ViSession instrSession)
{
    rsfsex_instrRange instrPtr;
    ViUInt32 retCnt = 0;
    ViSession rmSession;
    ViUInt16 interface = VI_INTF_GPIB;
    ViStatus rsfsex_status = VI_SUCCESS;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_RM_SESSION,
        &rmSession)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Port. Go to local mode. */
            if ((rsfsex_status = viWrite (instrSession, "@LOC\n", 5, &retCnt)) < 0)
                return rsfsex_status;
        break;
#ifdef VI_INTF_TCPIP
        case VI_INTF_TCPIP: /* RSIB Interface. Go to local mode. */
            if ((rsfsex_status = viSetAttribute (instrSession, RS_ATTR_RSIB_SRE, 0)) < 0)
                return rsfsex_status;
        break;
#endif
        }

    if (instrPtr != NULL)
        free (instrPtr);

    rsfsex_status = viClose (instrSession);
    viClose (rmSession);

    return rsfsex_status;
}

/*****************************************************************************/
/*= UTILITY ROUTINES (Non-Exportable Functions) =============================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Delay
/* Purpose : With a call to rsfsex_delay, the current program is suspended
/*           from execution for the number of seconds specified by the
/*           argument seconds. rsfsex_delay is accurate to a millisecond.
/*           This function is platform independent.
/*===========================================================================*/
void rsfsex_delay (ViReal64 numberOfSeconds)
{
  clock_t StartTime = clock();
  
  while ((((double)(clock() - StartTime))/CLOCKS_PER_SEC) < (numberOfSeconds));

  return;
}

/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean                          */
/* Purpose:  This function checks a Boolean to see if it is equal to VI_TRUE */
/*           or VI_FALSE. If the value is out of range, the return value is  */
/*           VI_TRUE, otherwise the return value is VI_FALSE.                */
/*===========================================================================*/
ViBoolean rsfsex_invalidViBooleanRange (ViBoolean val)
{
    return (ViBoolean)(((val != VI_FALSE && val != VI_TRUE) ? VI_TRUE : VI_FALSE));
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rsfsex_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (ViBoolean)(((val < min || val > max) ? VI_TRUE : VI_FALSE));
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViBoolean rsfsex_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (ViBoolean)(((val < min || val > max) ? VI_TRUE : VI_FALSE));
}

/*===========================================================================*/
/* Function: Initialize Clean Up                                             */
/* Purpose:  This function is used only by the rsfsex_init function.  When   */
/*           an error is detected this function is called to close the       */
/*           open resource manager and instrument object sessions and to     */
/*           set the instrSession that is returned from rsfsex_init to       */
/*           VI_NULL.                                                        */
/*===========================================================================*/
ViStatus rsfsex_initCleanUp (ViSession openRMSession,
                    ViPSession openInstrSession, ViStatus currentStatus)
{
    rsfsex_instrRange instrPtr;

    if (viGetAttribute (*openInstrSession, VI_ATTR_USER_DATA, &instrPtr) >= 0)
        if (instrPtr != NULL)
            free (instrPtr);

    viClose (*openInstrSession);
    viClose (openRMSession);
    *openInstrSession = VI_NULL;

    return currentStatus;
}

/*===========================================================================*/
/* Function: Check String                                                    */
/* Purpose:  This function checks a string value to see if it is             */
/*           of a defined length and initialized.                            */
/*===========================================================================*/
ViBoolean rsfsex_invalidViString (ViString val, ViUInt32 maxLength)
{
    if (val)
        {
        if (strlen (val) > maxLength)
            return VI_TRUE;
        else
            return VI_FALSE;
        }

    return VI_TRUE;
}

/*===========================================================================*/
/* Function: ABS/REL To Integer                                              */
/* Purpose:  Convert string patterns to the integer.                         */
/*===========================================================================*/
ViInt32 rsfsex_absRelToInt(ViChar buff[])
{
    ViInt32 index = 0;

    /* ABS = 0, REL = 1 */

    for ( index = 0; absRelArr[index]; index++ )
        if (!strcmp(buff, absRelArr[index]))
            break;

    /* If not found string returns -1. */
    if (!absRelArr[index]) return -1;

    return index;
}

/*===========================================================================*/
/* Function: Status To Integer                                               */
/* Purpose:  Convert string patterns to the integer.                         */
/*===========================================================================*/
ViInt32 rsfsex_statusToInt(ViChar buff[])
{
    ViInt32 index = 0;

    /* "PASSED","FAILED","MARGIN","EXC","ABORT","RUNNING","FINISHED" */

    for ( index = 0; statusArr[index]; index++ )
        if (!strcmp(buff, statusArr[index]))
            break;

    /* If not found string returns -1. */
    if (!statusArr[index]) return -1;

    return index;
}

/*===========================================================================*/
/* Function: Swap 32bit Integer                                              */
/* Purpose:  Byte order for binary transfers depends on MOTOROLA or INTEL    */
/*           formats.                                                        */
/*===========================================================================*/
void rsfsex_SWAP_32(unsigned char *data, long points)
{
    /* MOTOROLA (byte order 0123) or INTEL (byte order 3210). */
    unsigned int    word = 0x1122;
    unsigned char   *p2word = (unsigned char*)&word;

    if (*p2word == 0x11) /* MOTOROLA format */
    {
       unsigned char    src[4];
       long             *p2data = (long*)data;
       int              idx;

       for (idx = 0; idx < points; idx++, p2data++)
          {
              *((long *)src) = *(p2data);
              ((unsigned char *)(p2data))[0] =  ((unsigned char*)(src))[3];
              ((unsigned char *)(p2data))[1] =  ((unsigned char*)(src))[2];
              ((unsigned char *)(p2data))[2] =  ((unsigned char*)(src))[1];
              ((unsigned char *)(p2data))[3] =  ((unsigned char*)(src))[0];
          }
    }
    
   return;
}

/******************************************************************************
 * Function: Read Data With Unknown length
 * Description: This function allocate buffer and read data from the instrument
 * WARNING:  You must deallocate buffer, if any pointer has been returned.
 *           This function does not work correctly, when you read bin data via
 *           serial interface
 *****************************************************************************/
static ViStatus rsfsex_ReadDataUnknownLength(ViSession instrSession, ViChar **outBuffer, ViUInt32 *count)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 actSize, retCnt = 0;
    ViChar   *buffer = VI_NULL, *p2buffer;
    
    *outBuffer = VI_NULL;
    if (count) *count = 0;
    
    /* Allocate Buffer */
    actSize = BUFFER_SIZE;
    buffer = (ViChar *)calloc(actSize, sizeof(ViChar));
    if (buffer == VI_NULL) return VI_ERROR_ALLOC;

    p2buffer = buffer;
    do
        {
        if ((rsfsex_status = viRead (instrSession, p2buffer, BUFFER_SIZE, &retCnt)) < 0)
            {
            free(buffer);
            return rsfsex_status;
            }
        if (retCnt == BUFFER_SIZE) /* Buffer was small, reallocate it */
        {
            actSize += BUFFER_SIZE;
            buffer = (ViChar *)realloc(buffer, actSize);
            if (buffer == VI_NULL) return VI_ERROR_ALLOC;
            p2buffer = buffer + (actSize - BUFFER_SIZE); /* Set pointer to end of data in rallocated buffer */
        }
        else
        {
            *(p2buffer+retCnt) = '\0'; /* For sure set end of string on the end of data */
        }
       } while (rsfsex_status == 0x3FFF0006); /* if buffer was small, continue with next read */ 
    
    *outBuffer = buffer;
    if (count) *count = (actSize - BUFFER_SIZE) + retCnt;
    
    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Parse Catlog List                                               */
/* Purpose:  Parse Catalog List returned from instrument and removes from it */
/*           all unneeded parameters from this list.                         */
/*===========================================================================*/
static ViStatus rsfsex_ParseCatalog(ViChar *catalogList, ViInt32 *nbFiles)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViChar  *buffer   = catalogList,
            *p2begin  = VI_NULL,
            *p2buffer = VI_NULL,
            *p2end    = VI_NULL;
    ViInt32 i = 0;
    
    if (*buffer != '\0')
    {
        sscanf(buffer, "%*ld,%*ld,%[^\r\n]", buffer);

        p2buffer = strchr(buffer, ',');
        p2end = p2buffer;
        for (i = 0; p2buffer; i++)
        {
            p2buffer++; /* skip ',' character */
            p2end++;
            p2begin = strchr(p2end, ',');
            if (p2begin)
                p2begin++;                 
            else
                break;
            if (*p2begin == '\0') break;   /* The last length is missing */

            p2begin = strchr(p2begin, ',');/* Skip file length */
            if (p2begin)
                p2begin++;
            else
                {
                *(p2buffer-1) = '\0'; /*  remove last comma */
                break;
                }

            p2end = strchr(p2begin, ',');  /* End of response */
            if (p2end == NULL)
            {
               *(p2buffer-1) = '\0'; /*  remove last comma */
                break;
            }
            memmove(p2buffer, p2begin, p2end - p2begin + 1);  /* ',' or '\0' will copy too */
            p2buffer = strchr(p2buffer, ',');
        }
        
        i += 1;
    }
    
    if (nbFiles) *nbFiles = i;
    
    if (p2buffer == VI_NULL)
    {
        buffer[0] = '\0';
    }
    else if (*(p2buffer-1))
    {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
    }
    
    /* Remove space on the begin of the buffer */
    if (buffer[0] == ' ')
        memmove(buffer, buffer + 1, strlen(buffer));

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Copy String Buffer                                              */
/* Purpose:  The function copies bufferSize - 1 bytes from input into        */
/*           output buffer. If the bufferSize == 0, function returns required*/
/*           buffer length. If you pass a negative number, the function      */
/*           copies the value to the buffer regardless of the number of bytes*/
/*           in the value.                                                   */
/*===========================================================================*/
static ViStatus rsfsex_CopyStringBuffer(ViChar *output, const ViChar *input, ViInt32 bufferSize)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViInt32  actualSize = strlen(input) + 1;
    
    /* Prepare return values */
    if (bufferSize == 0)
    {
        rsfsex_status = actualSize;
    }
    else 
    {
        if (actualSize > bufferSize)
        {
            rsfsex_status = actualSize;
            actualSize = bufferSize;
        }
        memcpy(output, input, actualSize-1);
        output[actualSize-1] = '\0';
    }
    return rsfsex_status;
}

/*****************************************************************************/
/*------------------ INSTRUMENT-DEPENDENT UTILITY ROUTINES ------------------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Default Instrument Setup                                        */
/* Purpose:  This function sends a default setup to the instrument.  This    */
/*           function is called by the rsfsex_reset operation and by the     */
/*           rsfsex_init function if the reset option has not been           */
/*           selected.  This function is useful for configuring any          */
/*           instrument settings that are required by the rest of the        */
/*           instrument driver functions such as turning headers ON or OFF   */
/*           or using the long or short form for commands, queries, and data.*/
/*===========================================================================*/
ViStatus rsfsex_defaultInstrSetup (ViSession instrSession)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViUInt32 retCnt = 0;
    ViChar buffer[BUFFER_SIZE], optsList[1024], version[20];
    ViInt32 index;
    rsfsex_instrRange instrPtr;

    /* Determine if the structure has been initialized for the current VISA  */
    /* Session and malloc if it has not.                                     */
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < VI_SUCCESS)
        return rsfsex_status;

    if (instrPtr == NULL)
        instrPtr = malloc (sizeof (struct rsfsex_statusDataRanges));

    instrPtr -> errorChecking = VI_TRUE;
    strcpy (instrPtr -> instrDriverRevision, RSFSEX_REVISION);

    if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_USER_DATA,
        (ViUInt32)instrPtr)) < VI_SUCCESS)
        return rsfsex_status;

    /* Check what options are available and what instr model we have. */

    if ((rsfsex_status = viWrite (instrSession, "*IDN?\n", 6, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;
    if (sscanf (buffer, "%*[^,],%[^,]", version) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    for ( index = 0; instrVersionList[index]; index++ )
        if (!strncmp (version, instrVersionList[index], strlen(instrVersionList[index])))
            break;

    /* Instr Model names:

        0   FSEA 20
        1   FSEA 30
        2   FSEB 20
        3   FSEB 30
        4   FSEM 20
        5   FSEM 21
        6   FSEM 30
        7   FSEM 31
        8   FSEK 20
        9   FSEK 21
        10  FSEK 30
        11  FSEK 31
        12  FSIQ 3
        13  FSIQ 7
        14  FSIQ 26
        15  ESI 7
        16  ESI 26
        17  ESI 40
        18  FSE? 7
        19  FSE? 22
        20  FSIG 3
        21  FSIG 13
        22  FSIQ 40
        23  UNKNOWN (This value is not fixed to this position. List can be extended.)

    */

    /* If string is not found return UNKNOWN as model name. */
    if (!instrVersionList[index]) index--;

    instrPtr -> instrVer = index;
    instrPtr -> preselector = 0;

    /* Check if preselector is conected */
    if ((instrPtr -> instrVer == 18) || (instrPtr -> instrVer == 19)) {
        if ((rsfsex_status = rsfsex_waitOPC (instrSession, ":INP:PRES?\n", buffer, 1000)) < 0)
            instrPtr -> preselector = 0;
        else /* Preselector Available. */
            instrPtr -> preselector = 1;
    }

    instrPtr -> option = 0;
    
    if ((rsfsex_status = viWrite (instrSession, "*OPT?\n", 6, &retCnt)) < 0)
        return rsfsex_status;
    if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
        return rsfsex_status;

    if (sscanf (buffer, "%[^\r\n]", optsList) != 1) {
        rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        return rsfsex_status;
    }

    /* Supported Instrumet options:

        0   FSE-B2    0x1      
        1   FSE-B3    0x2      
        2   FSE-B4    0x4      
        3   FSE-B5    0x8      
        4   FSE-B7    0x10     
        5   FSE-B8    0x20     
        6   FSE-B9    0x40     
        7   FSE-B10   0x80     
        8   FSE-B11   0x100    
        9   FSE-B12   0x200    
        10  FSE-B15   0x400    
        11  FSE-B16   0x800    
        12  FSE-B17   0x1000   
        13  FSE-B18   0x2000   
        14  FSE-B19   0x4000   
        15  FSE-B21   0x8000   
        16  FSE-B22   0x10000  
        17  FSE-B23   0x20000
        18  ESI-B1    0x40000
        19  FSE-B13   0x80000
        20  FSE-K10   0x100000
        21  FSE-K11   0x200000
        22  FSE-K12   0x400000
        23  FSE-K20   0x800000
        24  FSE-K21   0x1000000
        25  FSIQB70   0x2000000
        26  FSIQK71   0x4000000
        27  FSIQK72   0x8000000
        28  FSIQK73   0x10000000

    */
    {
    ViChar *p2option;
    ViChar  option[256];
    for (index = 0; optionsList[index]; index++)
        {
         strcpy(option, optionsList[index]);
         p2option = optsList;
         while ((p2option = strstr(p2option, option)) != VI_NULL)
            {
                if (strchr(p2option, ',')) /* the last option */
                    strcat(option, ",");
                if (!strncmp(p2option, option, strlen(option)))
                    instrPtr -> option |= (1 << index);
                p2option++;
            }
        }
    }
    /* Default Instrument Setup String - Data Format */
    if ((rsfsex_status = viWrite (instrSession, "*CLS;*ESE 60\n", 13, &retCnt)) < 0)
        return rsfsex_status;

    return rsfsex_status;
}

/*=========================================================================*/
/* Function: Status                                                        */
/* Purpose:  This function reads the system status byte.                   */
/*=========================================================================*/
ViStatus rsfsex_sysStatus (ViSession instrSession)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViChar rdBuf[BUFFER_SIZE];
    ViUInt32 retCnt = 0;
    ViInt32 esrByte;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < VI_SUCCESS)
        return rsfsex_status;

    if (instrPtr -> errorChecking) { /* Is Error Checking Enabled? */
        /*--------------- Read the Standard Event Register --------------------*/
        if ((rsfsex_status = viWrite (instrSession, "*ESR?\n", 6, &retCnt)) < 0)
            return rsfsex_status;
        if ((rsfsex_status = viRead (instrSession, rdBuf, BUFFER_SIZE, &retCnt)) < 0)
            return rsfsex_status;

        if (sscanf (rdBuf, "%ld", &esrByte) != 1) {
            rsfsex_status = VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            return rsfsex_status;
        }

        /*---------------- Check if any error or message bit was asserted -------*/
        if ((esrByte & 0x3C) != 0)
            rsfsex_status = RSFSEX_ERROR_INSTRUMENT_ERROR;
        else
           rsfsex_status = VI_SUCCESS;
    }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Wait for OPC                                                    */
/* Purpose:  This function sends a command to the instrument and waits until */
/*           the instrument response is available (queries MAV in STB).      */
/*===========================================================================*/
ViStatus rsfsex_waitOPC (ViSession instrSession, ViPString command,
                ViPString instrResp, ViInt32 timeout)
{
    ViStatus    rsfsex_status = VI_SUCCESS;
    ViUInt16    interface = VI_INTF_GPIB;
    ViChar      buffer[BUFFER_SIZE];
    ViInt32     oldTimeout = 0;
    ViInt16     response = 0;
    ViInt32     counter = 0;
    ViInt32     retCnt;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < 0)
            return rsfsex_status;
    
    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial interface */
            if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &oldTimeout)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, timeout)) < 0)
                return rsfsex_status;
            if ((rsfsex_status = viQueryf (instrSession, "%s", "%[^\r\n]", command, instrResp)) < 0) {
                viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, oldTimeout);
                return rsfsex_status;
            }
            if ((rsfsex_status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, oldTimeout)) < 0)
                return rsfsex_status;
        break;
        default: /* Default case */
            if ((rsfsex_status = viWrite (instrSession, command, strlen (command), &retCnt)) < 0)
                return rsfsex_status;

            while (!(response & 0x10)) { /* (queries MAV in STB) */

                if ((rsfsex_status = viReadSTB (instrSession, &response)) < 0)
                    return rsfsex_status;

                rsfsex_delay(0.005);
                counter+= 5;
                if (counter >= timeout)
                    return VI_ERROR_TMO;
            }

            if ((rsfsex_status = viRead (instrSession, buffer, BUFFER_SIZE, &retCnt)) < 0)
                return rsfsex_status;

            if (sscanf (buffer, "%[^\r\n]", instrResp) != 1)
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        break;
        }

    return rsfsex_status;
}

/*===========================================================================*/
/* Function: Check STB Before Read                                           */
/* Purpose:  This is a utility function which checks Error/Event Queue bit of*/
/*           status byte. Call this function before read result of query     */
/*           command. When error occurs, this function returns error code    */
/*           RSFSEX_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE. Prior to calling    */
/*           this function is necessary to clear STB.                        */
/*===========================================================================*/
ViStatus rsfsex_checkBeforeRead (ViSession instrSession)
{
    ViStatus rsfsex_status = VI_SUCCESS;
    ViInt16 response = 0;
    ViInt32 counter = 0, timeout = 0;
    ViUInt16 interface = VI_INTF_GPIB;
    rsfsex_instrRange instrPtr;

    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)) < VI_SUCCESS)
        return rsfsex_status;
    if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface)) < VI_SUCCESS)
        return rsfsex_status;

    /* Is Error Checking Enabled? */
    if (instrPtr -> errorChecking)
        {
        /* Interface specific operations */
        switch (interface)
            {
            case VI_INTF_ASRL: /* Serial interface */

                /* Not supported */

            break;
            default: /* Default case */
                if ((rsfsex_status = viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &timeout)) < VI_SUCCESS)
                    return rsfsex_status;

                /* Result of reading STB must be zero. Initial settings */

                do {
                    if ((rsfsex_status = viReadSTB (instrSession, &response)) < 0)
                        return rsfsex_status;

                    rsfsex_delay (0.005);
                    counter += 5;
                    if (counter >= timeout)
                        return VI_ERROR_TMO;
                /* Wait until STB is non zero value. */
                } while (!response);

                /* Check STB for errors. */

                counter = 0;

                do {
                    if ((rsfsex_status = viReadSTB (instrSession, &response)) < 0)
                        return rsfsex_status;

                    rsfsex_delay (0.005);
                    counter += 5;
                    if (counter >= timeout)
                        return VI_ERROR_TMO;
                /* Wait while STB is non zero value. Only Error/Event Queue
                   and MAV bits are taken into consideration. */
                } while (!(response & 0x14));

                /* (check Error/Event Queue bit in STB) */
                return (response & 0x4) ?  RSFSEX_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE : rsfsex_status;
            }
        }

    return rsfsex_status;
}

/*****************************************************************************/
/*=== END INSTRUMENT DRIVER SOURCE CODE =====================================*/
/*****************************************************************************/
